"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["6809"],{31036:function(i){i.exports=JSON.parse('{"title":"Gestore strumenti","subtitle":"Controlla tutti i tuoi strumenti in UN UNICO posto.","filters":{"all":"Tutti","active":"Attivi","disabled":"Disattivati","notInstalled":"Non installati"},"back":"Torna alla panoramica degli strumenti","breadcrumb":{"home":"Home","toolManager":"Gestore strumenti"},"tools":{"build":{"title":"Costruisci","items":{"core":{"title":"Editor core"},"pro":{"title":"Editor pro","features":{"themeBuilder":"Costruttore di temi","popups":"Popup","commerce":"Commercio","savedTemplates":"Modelli salvati","templateCategories":"Categorie di modelli","starterTemplates":"Modelli di avvio (modelli di siti web)","customFonts":"Font personalizzati","customIcons":"Icone personalizzate","customCode":"Codice personalizzato","customCss":"CSS personalizzato"}},"ai":{"title":"AI agentica"}}},"optimize":{"title":"Ottimizza","items":{"accessibility":{"title":"Accessibilit\xe0"},"io":{"title":"Ottimizzazione immagini"}}},"manage":{"title":"Gestisci","items":{"email":{"title":"Deliverability email"}}}},"actions":{"add":"Aggiungi","update":"Aggiorna","activate":"Attiva","deactivate":"Disattiva","migrateToOne":"Migra a uno","updateRequired":"Aggiornamento richiesto","confirmAdd":{"title":"Aggiungi strumento","msg":"Sei sicuro di voler aggiungere questo strumento? Questo aggiunger\xe0 lo strumento al tuo account e potrai usarlo nei tuoi progetti.","ok":"Aggiungi","cancel":"Annulla"},"confirmActivate":{"title":"Sei sicuro di voler attivare {name}? ","msg":"Attivando...","ok":"Attiva","cancel":"Annulla"},"confirmDeactivate":{"title":"Sei sicuro di voler disattivare {name}? ","msg":"Disattivando...","ok":"Disattiva","cancel":"Non ora"}},"showMoreFeatures":"Mostra pi\xf9 funzionalit\xe0","hideMoreFeatures":"Nascondi pi\xf9 funzionalit\xe0","noToolsFound":"Nessuno strumento corrisponde alla ricerca","noToolsFoundDescription":"Prova a modificare i filtri.","updateRequiredTooltip":"I plugin aggiornati hanno nuove funzionalit\xe0 e correzioni per far s\xec che il tuo sito funzioni in modo sicuro e fluido."}')}}]);