.et-db #et-boc .et-l .et_pb_with_border.et_pb_posts_nav span.nav-next a,.et-db #et-boc .et-l .et_pb_with_border.et_pb_posts_nav span.nav-previous a{border:0 solid #333}.et-db #et-boc .et-l .et_pb_posts_nav.nav-single:after{clear:both;display:block;content:""}.et-db #et-boc .et-l .et_pb_posts_nav a{display:inline-block}.et-db #et-boc .et-l .et_pb_posts_nav .meta-nav,.et-db #et-boc .et-l .et_pb_posts_nav .nav-label,.et-db #et-boc .et-l .et_pb_posts_nav .nav-next,.et-db #et-boc .et-l .et_pb_posts_nav .nav-previous{position:relative}