/*! For license information please see mixpanel.js.LICENSE.txt */
!function(){"use strict";var e={"./packages/packages/libs/mixpanel/src/use-mixpanel.ts":function(e,n,r){r.r(n),r.d(n,{getMixpanel:function(){return getMixpanel},trackEvent:function(){return trackEvent},useMixpanel:function(){return useMixpanel}});const useMixpanel=()=>{const{dispatchEvent:e,config:n}=getMixpanel();return{dispatchEvent:e,config:n}},trackEvent=e=>{const{dispatchEvent:n}=getMixpanel();n?.(e.eventName,e)},getMixpanel=()=>{const e=window.elementorCommon?.eventsManager||{};return{dispatchEvent:e.dispatchEvent?.bind(e),config:e.config}}}},n={};function __webpack_require__(r){var t=n[r];if(void 0!==t)return t.exports;var i=n[r]={exports:{}};return e[r](i,i.exports,__webpack_require__),i.exports}__webpack_require__.d=function(e,n){for(var r in n)__webpack_require__.o(n,r)&&!__webpack_require__.o(e,r)&&Object.defineProperty(e,r,{enumerable:!0,get:n[r]})},__webpack_require__.o=function(e,n){return Object.prototype.hasOwnProperty.call(e,n)},__webpack_require__.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})};var r={};!function(){__webpack_require__.r(r),__webpack_require__.d(r,{getMixpanel:function(){return e.getMixpanel},trackEvent:function(){return e.trackEvent},useMixpanel:function(){return e.useMixpanel}});var e=__webpack_require__("./packages/packages/libs/mixpanel/src/use-mixpanel.ts")}(),(window.elementorV2=window.elementorV2||{}).mixpanel=r}(),window.elementorV2.mixpanel?.init?.();
//# sourceMappingURL=mixpanel.js.map