.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_rating{word-wrap:break-word}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_rating .star-rating span.rating{display:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_rating .et-pb-icon{font-size:16px}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_rating .woocommerce-review-link{vertical-align:text-bottom;line-height:1.7em}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_rating .woocommerce-product-rating{margin-bottom:0}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_rating .woocommerce-product-rating .star-rating{float:none;display:inline-block;margin:0}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_rating.et_pb_wc_rating_layout_stacked .woocommerce-review-link{float:none;display:block}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_rating.et_pb_wc_rating_no_rating .star-rating,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_rating.et_pb_wc_rating_no_reviews .woocommerce-review-link{display:none}