.et-db #et-boc .et-l .et-db #et-boc .et-l .et_overlay{z-index:-1;position:absolute;top:0;left:0;display:block;width:100%;height:100%;background:hsla(0,0%,100%,.9);opacity:0;pointer-events:none;transition:all .3s;border:1px solid #e5e5e5;box-sizing:border-box;-webkit-backface-visibility:hidden;backface-visibility:hidden;-webkit-font-smoothing:antialiased}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_overlay:before{color:#2ea3f2;content:"\E050";position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);font-size:32px;transition:all .4s}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_portfolio_image,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_shop_image{position:relative;display:block}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_has_overlay:not(.et_pb_image):hover .et_overlay,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_portfolio_image:hover .et_overlay,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_shop_image:hover .et_overlay{z-index:3;opacity:1}.et-db #et-boc .et-l .et-db #et-boc .et-l #ie7 .et_overlay,.et-db #et-boc .et-l .et-db #et-boc .et-l #ie8 .et_overlay{display:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_module.et_pb_has_overlay{position:relative}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_module.et_pb_has_overlay .et_overlay,.et-db #et-boc .et-l .et-db #et-boc .et-l article.et_pb_has_overlay{border:none}