!function(e,n){"object"==typeof exports&&"undefined"!=typeof module?n(exports):"function"==typeof define&&define.amd?define(["exports"],n):n((e=e||self).da={})}(this,(function(e){"use strict";var n="undefined"!=typeof window&&window.flatpickr!==undefined?window.flatpickr:{l10ns:{}},a={weekdays:{shorthand:["søn","man","tir","ons","tors","fre","lør"],longhand:["søndag","mandag","tirsdag","onsdag","torsdag","fredag","lørdag"]},months:{shorthand:["jan","feb","mar","apr","maj","jun","jul","aug","sep","okt","nov","dec"],longhand:["januar","februar","marts","april","maj","juni","juli","august","september","oktober","november","december"]},ordinal:function(){return"."},firstDayOfWeek:1,rangeSeparator:" til ",weekAbbreviation:"uge",time_24hr:!0};n.l10ns.da=a;var r=n.l10ns;e.Danish=a,e["default"]=r,Object.defineProperty(e,"__esModule",{value:!0})}));