@media (min-width:981px){.et_pb_gutter.et_pb_gutters2 #left-area{width:77.25%}.et_pb_gutter.et_pb_gutters2 #sidebar{width:22.75%}.et_pb_gutters2.et_right_sidebar #left-area{padding-right:3%}.et_pb_gutters2.et_left_sidebar #left-area{padding-left:3%}.et_pb_gutter.et_pb_gutters2.et_right_sidebar #main-content .container:before{right:22.75%!important}.et_pb_gutter.et_pb_gutters2.et_left_sidebar #main-content .container:before{left:22.75%!important}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column{margin-right:3%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_4_4,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_4_4{width:100%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_4_4 .et_pb_module,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_4_4 .et_pb_module{margin-bottom:1.5%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_3_4,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_3_4{width:74.25%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_3_4 .et_pb_module,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_3_4 .et_pb_module{margin-bottom:2.02%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_2_3,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_2_3{width:65.667%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_2_3 .et_pb_module,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_2_3 .et_pb_module{margin-bottom:2.284%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_3_5,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_3_5{width:58.8%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_3_5 .et_pb_module,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_3_5 .et_pb_module{margin-bottom:2.551%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_1_2,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_1_2{width:48.5%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_1_2 .et_pb_module,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_1_2 .et_pb_module{margin-bottom:3.093%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_2_5,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_2_5{width:38.2%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_2_5 .et_pb_module,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_2_5 .et_pb_module{margin-bottom:3.927%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_1_3,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_1_3{width:31.3333%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_1_3 .et_pb_module,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_1_3 .et_pb_module{margin-bottom:4.787%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_1_4,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_1_4{width:22.75%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_1_4 .et_pb_module,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_module{margin-bottom:6.593%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_1_5,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_1_5{width:17.6%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_1_5 .et_pb_module,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_module{margin-bottom:8.523%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_1_6,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_1_6{width:14.1667%}.et-db #et-boc .et-l .et_pb_gutters2.et_pb_row .et_pb_column_1_6 .et_pb_module,.et_pb_gutters2.et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_module{margin-bottom:10.588%}.et_pb_gutters2 .et_full_width_page.woocommerce-page ul.products li.product{width:22.75%;margin-right:3%;margin-bottom:3%}.et_pb_gutters2.et_left_sidebar.woocommerce-page #main-content ul.products li.product,.et_pb_gutters2.et_right_sidebar.woocommerce-page #main-content ul.products li.product{width:30.64%;margin-right:4.04%}}