.et-db #et-boc .et-l #comment-wrap{padding-top:75px}.et-db #et-boc .et-l .comment-body{position:relative;padding:0 110px 0 100px;margin-bottom:48px;min-height:87px}.et-db #et-boc .et-l .comment_avatar{left:0;position:absolute;top:7px}.et-db #et-boc .et-l .comment_avatar img{display:block;height:auto;max-width:100%;width:auto}.et-db #et-boc .et-l .comment_postinfo{margin-bottom:8px}.et-db #et-boc .et-l span.fn,.et-db #et-boc .et-l span.fn a{color:#000;font-weight:700;text-decoration:none;font-size:16px;display:inline-block}.et-db #et-boc .et-l span.comment_date{color:#000;font-size:14px;font-weight:300}.et-db #et-boc .et-l .comment_area .comment-reply-link{position:absolute;top:7px;right:0;display:block}.et-db #et-boc .et-l .comment-reply-link:hover,.et-db #et-boc .et-l .form-submit:hover{text-decoration:none}.et-db #et-boc .et-l .comment .children{margin-left:100px;padding-left:0!important}.et-db #et-boc .et-l #comment-wrap li.comment.depth-5 article{padding-right:0}.et-db #et-boc .et-l .comment #respond{margin:-30px 0 0}.et-db #et-boc .et-l #respond{padding-top:17px}.et-db #et-boc .et-l #commentform{padding-bottom:50px}.et-db #et-boc .et-l #commentform input[type=email],.et-db #et-boc .et-l #commentform input[type=text],.et-db #et-boc .et-l #commentform input[type=url]{width:47%}.et-db #et-boc .et-l #commentform textarea{width:100%;box-sizing:border-box;-moz-box-sizing:border-box;-webkit-box-sizing:border-box}.et-db #et-boc .et-l #commentform input[type=email],.et-db #et-boc .et-l #commentform input[type=text],.et-db #et-boc .et-l #commentform input[type=url],.et-db #et-boc .et-l #commentform textarea{padding:12px;color:#999;line-height:1em;background-color:#eee;font-size:18px;border-width:0}.et-db #et-boc .et-l .form-submit{text-align:right}.et-db #et-boc .et-l .form-submit .et_pb_button{display:inline-block;cursor:pointer;color:#2ea3f2}.et-db #et-boc .et-l #reply-title small{display:block;font-size:14px;font-weight:400}@media (max-width:767px){.et-db #et-boc .et-l #comment-wrap li.comment article{padding-right:0}.et-db #et-boc .et-l .comment-body{padding:0 0 0 100px}.et-db #et-boc .et-l .comment-reply-link{position:relative!important;float:right;bottom:-10px;top:auto!important}.et-db #et-boc .et-l #commentform input[type=email],.et-db #et-boc .et-l #commentform input[type=text],.et-db #et-boc .et-l #commentform input[type=url]{width:100%;box-sizing:border-box;margin-left:0}.et-db #et-boc .et-l .comment .children{margin-left:50px}}@media (max-width:479px){.et-db #et-boc .et-l .comment_avatar img{max-width:50%}.et-db #et-boc .et-l .comment-body{padding:0 0 0 50px}.et-db #et-boc .et-l .comment .children{margin-left:25px}.et-db #et-boc .et-l a.comment-reply-link.et_pb_button{font-size:15px}.et-db #et-boc .et-l a.comment-reply-link.et_pb_button:after{font-size:25px}}