"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["758"],{60229:function(e){e.exports=JSON.parse('{"title":"Gestor de ferramentas","subtitle":"Controle todas as suas ferramentas num S\xd3 lugar.","filters":{"all":"Todas","active":"Ativas","disabled":"Desativadas","notInstalled":"N\xe3o instaladas"},"back":"Voltar \xe0 vis\xe3o geral das ferramentas","breadcrumb":{"home":"In\xedcio","toolManager":"Gestor de ferramentas"},"tools":{"build":{"title":"Criar","items":{"core":{"title":"Editor principal"},"pro":{"title":"Editor profissional","features":{"themeBuilder":"Construtor de temas","popups":"Pop-ups","commerce":"Com\xe9rcio","savedTemplates":"Modelos guardados","templateCategories":"Categorias de modelos","starterTemplates":"Modelos iniciais (modelos de website)","customFonts":"Tipos de letra personalizados","customIcons":"\xcdcones personalizados","customCode":"C\xf3digo personalizado","customCss":"CSS personalizado"}},"ai":{"title":"IA Agente"}}},"optimize":{"title":"Otimizar","items":{"accessibility":{"title":"Acessibilidade"},"io":{"title":"Otimiza\xe7\xe3o de imagem"}}},"manage":{"title":"Gerir","items":{"email":{"title":"Capacidade de entrega de email"}}}},"actions":{"add":"Adicionar","update":"Atualizar","activate":"Ativar","deactivate":"Desativar","migrateToOne":"Migrar para um","updateRequired":"Atualiza\xe7\xe3o necess\xe1ria","confirmAdd":{"title":"Adicionar ferramenta","msg":"Tem certeza de que deseja adicionar esta ferramenta? Isso adicionar\xe1 a ferramenta \xe0 sua conta e poder\xe1 us\xe1-la nos seus projetos.","ok":"Adicionar","cancel":"Cancelar"},"confirmActivate":{"title":"Tem certeza de que deseja ativar {name}? ","msg":"Ao ativar...","ok":"Ativar","cancel":"Cancelar"},"confirmDeactivate":{"title":"Tem certeza de que deseja desativar {name}? ","msg":"Ao desativar...","ok":"Desativar","cancel":"Agora n\xe3o"}},"showMoreFeatures":"Mostrar mais funcionalidades","hideMoreFeatures":"Ocultar mais funcionalidades","noToolsFound":"Nenhuma ferramenta correspondeu \xe0 pesquisa","noToolsFoundDescription":"Tente ajustar os seus filtros.","updateRequiredTooltip":"Os plugins atualizados t\xeam novas funcionalidades e corre\xe7\xf5es para que o seu site funcione de forma segura e fluida."}')}}]);