"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["2189"],{76032:function(e){e.exports=JSON.parse('{"onBoardingInstall":{"title":"Welcome to\\nElementor one!","description":"We will install all of the Elementor capabilities.\\nIf you don\'t want to install now please deselect them.","skip":"Skip","continue":"Continue","installAndContinue":"Install and continue","duringInstallation":"During installation, we\u2019ll update any tools that require it.","tools":{"additionalBetaTools":"Additional beta tools","editorCore":{"title":"Editor Core","description":"Create pixel-perfect websites with a drag & drop interface"},"editorPro":{"title":"Editor Pro","description":"Build your entire site with professional tools"},"imageOptimizer":{"title":"Image optimization","description":"Compress and optimize images to boost performance"},"accessibility":{"title":"Accessibility","description":"Find and fix accessibility issues across your site"},"siteMailer":{"title":"Site mailer","description":"Ensure your site emails reach the inbox - not spam"},"ai":{"title":"Angie - Native AI for WordPress","description":"Turn ideas into pages, blocks, and features with native AI "},"installed":"Already installed","singleSub":"Single subscription","updateRequired":"Update required","updateRequiredTooltip":"Will be automatically updated to the latest version","beta":"Beta"}},"siteIdentity":{"activeTheme":"Active theme:","getHelloElementor":"Get Hello Elementor","goToSiteSetup":"Go to site setup","editSite":"Edit site","editSiteMenu":{"addPage":"Add a page","addBlogPost":"Add a blog post","createHeader":"Create a header","createFooter":"Create a footer"},"helloThemeInstalled":"Hello Elementor theme installed successfully","helloThemeInstallationFailed":"Hello Elementor theme installation failed","helloThemeActivationFailed":"Hello Elementor theme activation failed","helloThemeActivated":"Hello Elementor theme activated successfully"},"capabilities":{"greeting":"Let\'s start building.","filters":{"all":"All","featured":"Featured","create":"Create","optimize":"Optimize","manage":"Manage"},"toolManager":"Tool manager","addForFreeButton":"Add for free","openButton":"Open","goProButton":"Upgrade","inProgressButton":"In progress","learnMore":{"upgrade":"Upgrade","install":"Install","open":"Open"}},"toolManager":{"title":"Control all your tools in ONE place."}}')}}]);