.et-db #et-boc .et-l .product{word-wrap:break-word}@media (max-width:980px){.et-db #et-boc .et-l .et_pb_woo_custom_button_icon .et_pb_custom_button_icon.et_pb_button:after{content:attr(data-icon-tablet)}}@media (max-width:767px){.et-db #et-boc .et-l .et_pb_woo_custom_button_icon .et_pb_custom_button_icon.et_pb_button:after{content:attr(data-icon-phone)}}.et-db #et-boc .et-l .et-dynamic-content-woo a{color:inherit!important;font-family:inherit;font-weight:inherit;font-style:inherit;font-size:inherit;letter-spacing:inherit;line-height:inherit;text-align:inherit;text-shadow:inherit}.woocommerce-page #content input.button:hover .et_pb_widget li a:hover{color:#2ea3f2}.woocommerce.et_pb_pagebuilder_layout div.product div.summary{margin-bottom:0}.et_pb_pagebuilder_layout .rfq_form_wrap:after{content:" ";display:block;visibility:hidden;clear:both;height:0;font-size:0}@media (min-width:981px){.woocommerce-page:not(.et-tb-has-template) .et_pb_shop ul.products li.product:not(.first){clear:none}}@media (min-width:768px) and (max-width:980px){.woocommerce-page ul.products li.product:nth-child(n){margin:0 7.5% 7.5% 0!important;width:28.333%!important;clear:none;float:left!important}.woocommerce-page ul.products li.product:nth-child(3n){margin-right:0!important}.woocommerce-page ul.products li.product:nth-child(3n+1){clear:both}}@media (max-width:767px){.woocommerce-page ul.products li.product:nth-child(n){margin:0 9.5% 9.5% 0!important;width:45.25%!important;clear:none}.woocommerce-page ul.products li.product:nth-child(2n){margin-right:0!important}.woocommerce-page ul.products li.product:nth-child(odd){clear:both}}@media (max-width:479px){.woocommerce-page ul.products li.product:nth-child(n){margin:0 0 11.5%!important;width:100%!important}}