.et-db #et-boc .et-l .et-db #et-boc .et-l .et_post_gallery{padding:0!important;line-height:1.7!important;list-style:none!important}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_gallery_item{float:left;width:28.353%;margin:0 7.47% 7.47% 0}.et-db #et-boc .et-l .et-db #et-boc .et-l .blocks-gallery-item,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_gallery_item{padding-left:0!important}.et-db #et-boc .et-l .et-db #et-boc .et-l .blocks-gallery-item:before,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_gallery_item:before{display:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_gallery_item:nth-child(3n){margin-right:0}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_gallery_item:nth-child(3n+1){clear:both}