.et-db #et-boc .et-l .et_pb_space{box-sizing:content-box;height:23px}.et-db #et-boc .et-l .et_pb_divider_hidden{margin-bottom:0!important}.et-db #et-boc .et-l .et_pb_divider_internal{display:inline-block;width:100%}.et-db #et-boc .et-l .et_pb_divider{margin:0 0 30px;position:relative}.et-db #et-boc .et-l .et_pb_divider:before{content:"";width:100%;height:1px;border-top:1px solid rgba(0,0,0,.1);position:absolute;left:0;top:0;z-index:10}.et-db #et-boc .et-l .et_pb_divider:after,.et-db #et-boc .et-l .et_pb_space:after{content:"";display:table}.et-db #et-boc .et-l .et_pb_divider_position_bottom:before{top:auto!important;bottom:0!important}.et-db #et-boc .et-l .et_pb_divider_position_center:before{top:50%!important}@media (max-width:980px){.et-db #et-boc .et-l .et_pb_divider_position_top_tablet:before{top:0!important;bottom:auto!important}.et-db #et-boc .et-l .et_pb_divider_position_bottom_tablet:before{top:auto!important;bottom:0!important}.et-db #et-boc .et-l .et_pb_divider_position_center_tablet:before{top:50%!important}.et-db #et-boc .et-l .et_pb_space.et-hide-mobile{display:none}}@media (max-width:767px){.et-db #et-boc .et-l .et_pb_divider_position_top_phone:before{top:0!important;bottom:auto!important}.et-db #et-boc .et-l .et_pb_divider_position_bottom_phone:before{top:auto!important;bottom:0!important}.et-db #et-boc .et-l .et_pb_divider_position_center_phone:before{top:50%!important}}.ie .et_pb_divider{overflow:visible}