.ai_helper_blog_generator_form_row {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  gap: 20px;
}
.ai_helper_blog_generator_form_row:nth-child(even):not(:last-child) {
  margin-bottom: 2em;
}
.ai_helper_blog_generator_form_row .ai_helper_blog_generator_form_label {
  -webkit-flex-basis: 100%;
  -ms-flex-basis: 100%;
  flex-basis: 100%;
  font-weight: bold;
  border-bottom: 1px solid #ccc;
  padding-bottom: 5px;
  margin-bottom: 10px;
}
.ai_helper_blog_generator_form_row .ai_helper_blog_generator_form_field {
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
}
.ai_helper_blog_generator_form_row .ai_helper_blog_generator_form_field:first-child {
  -webkit-flex-basis: 45%;
  -ms-flex-basis: 45%;
  flex-basis: 45%;
}
.ai_helper_blog_generator_form_row.ai_helper_blog_generator_form_row_media {
  margin-top: -1em;
}

.ai_helper_blog_generator_form_field {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.ai_helper_blog_generator_form_field > label {
  min-width: 88px;
}
.ai_helper_blog_generator_form_field input[type="number"] {
  width: 60px;
}
.ai_helper_blog_generator_form_field.ai_helper_blog_generator_form_field_media {
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  position: relative;
  --trx-addons-media-selector-width: 100px;
}
.ai_helper_blog_generator_form_field.ai_helper_blog_generator_form_field_media .trx_addons_media_selector_preview {
  display: block;
  margin-bottom: 0;
  max-width: none;
  width: var(--trx-addons-media-selector-width);
  height: var(--trx-addons-media-selector-width);
}
.ai_helper_blog_generator_form_field.ai_helper_blog_generator_form_field_media .trx_addons_media_selector_preview .trx_addons_media_selector_preview_image {
  position: relative;
  z-index: 2;
  display: block;
  width: var(--trx-addons-media-selector-width);
  height: var(--trx-addons-media-selector-width);
  overflow: hidden;
  border-radius: 3px;
  border: 1px solid #ccc;
}
.ai_helper_blog_generator_form_field.ai_helper_blog_generator_form_field_media .trx_addons_media_selector_preview img {
  width: 100%;
  height: 100%;
  object-fit: cover;
}
.ai_helper_blog_generator_form_field.ai_helper_blog_generator_form_field_media #ai_helper_blog_generator_content_image_button {
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  display: block;
  width: var(--trx-addons-media-selector-width);
  height: var(--trx-addons-media-selector-width);
  background-image: url(../../../../../../css/images/no-image.jpg);
  background-size: cover;
  background-position: center;
  background-repeat: no-repeat;
  border: 1px solid #ccc;
  border-radius: 3px;
  padding: 0;
}

/*# sourceMappingURL=blog-generator.css.map */
