.et-db #et-boc .et-l .et_pb_section{position:relative;background-color:#fff;background-position:50%;background-size:100%;background-size:cover}.et-db #et-boc .et-l .et_pb_section--absolute,.et-db #et-boc .et-l .et_pb_section--fixed{width:100%}.et-db #et-boc .et-l .et_pb_section.et_section_transparent{background-color:transparent}.et-db #et-boc .et-l .et_pb_fullwidth_section{padding:0}.et-db #et-boc .et-l .et_pb_fullwidth_section>.et_pb_module:not(.et_pb_post_content):not(.et_pb_fullwidth_post_content) .et_pb_row{padding:0!important}.et-db #et-boc .et-l .et_pb_inner_shadow{box-shadow:inset 0 0 7px rgba(0,0,0,.07)}.et-db #et-boc .et-l .et_pb_bottom_inside_divider,.et-db #et-boc .et-l .et_pb_top_inside_divider{display:block;background-repeat-y:no-repeat;height:100%;position:absolute;pointer-events:none;width:100%;left:0;right:0}.et-db #et-boc .et-l .et_pb_bottom_inside_divider.et-no-transition,.et-db #et-boc .et-l .et_pb_top_inside_divider.et-no-transition{transition:none!important}.et-db #et-boc .et-l .et-fb .section_has_divider.et_fb_element_controls_visible--child>.et_pb_bottom_inside_divider,.et-db #et-boc .et-l .et-fb .section_has_divider.et_fb_element_controls_visible--child>.et_pb_top_inside_divider{z-index:1}.et-db #et-boc .et-l .et_pb_section_video:not(.et_pb_section--with-menu){overflow:hidden;position:relative}.et-db #et-boc .et-l .et_pb_column>.et_pb_section_video_bg{z-index:-1}.et-db #et-boc .et-l .et_pb_section_video_bg{visibility:visible;position:absolute;top:0;left:0;width:100%;height:100%;overflow:hidden;display:block;pointer-events:none;transition:display .3s}.et-db #et-boc .et-l .et_pb_section_video_bg.et_pb_section_video_bg_hover,.et-db #et-boc .et-l .et_pb_section_video_bg.et_pb_section_video_bg_phone,.et-db #et-boc .et-l .et_pb_section_video_bg.et_pb_section_video_bg_tablet,.et-db #et-boc .et-l .et_pb_section_video_bg.et_pb_section_video_bg_tablet_only{display:none}.et-db #et-boc .et-l .et_pb_section_video_bg .mejs-controls,.et-db #et-boc .et-l .et_pb_section_video_bg .mejs-overlay-play{display:none!important}.et-db #et-boc .et-l .et_pb_section_video_bg embed,.et-db #et-boc .et-l .et_pb_section_video_bg iframe,.et-db #et-boc .et-l .et_pb_section_video_bg object,.et-db #et-boc .et-l .et_pb_section_video_bg video{max-width:none}.et-db #et-boc .et-l .et_pb_section_video_bg .mejs-video{left:50%;position:absolute;max-width:none}.et-db #et-boc .et-l .et_pb_section_video_bg .mejs-overlay-loading{display:none!important}.et-db #et-boc .et-l .et_pb_social_network_link .et_pb_section_video{overflow:visible}.et-db #et-boc .et-l .et_pb_section_video_on_hover:hover>.et_pb_section_video_bg{display:none}.et-db #et-boc .et-l .et_pb_section_video_on_hover:hover>.et_pb_section_video_bg_hover,.et-db #et-boc .et-l .et_pb_section_video_on_hover:hover>.et_pb_section_video_bg_hover_inherit{display:block}@media (min-width:981px){.et-db #et-boc .et-l .et_pb_section{padding:4% 0}body.et_pb_pagebuilder_layout.et_pb_show_title .post-password-required .et-db #et-boc .et-l .et_pb_section,body:not(.et_pb_pagebuilder_layout) .post-password-required .et-db #et-boc .et-l .et_pb_section{padding-top:0}.et-db #et-boc .et-l .et_pb_fullwidth_section{padding:0}.et-db #et-boc .et-l .et_pb_section_video_bg.et_pb_section_video_bg_desktop_only{display:block}}@media (max-width:980px){.et-db #et-boc .et-l .et_pb_section{padding:50px 0}body.et_pb_pagebuilder_layout.et_pb_show_title .post-password-required .et-db #et-boc .et-l .et_pb_section,body:not(.et_pb_pagebuilder_layout) .post-password-required .et-db #et-boc .et-l .et_pb_section{padding-top:0}.et-db #et-boc .et-l .et_pb_fullwidth_section{padding:0}.et-db #et-boc .et-l .et_pb_section_video_bg.et_pb_section_video_bg_tablet{display:block}.et-db #et-boc .et-l .et_pb_section_video_bg.et_pb_section_video_bg_desktop_only{display:none}}@media (min-width:768px){.et-db #et-boc .et-l .et_pb_section_video_bg.et_pb_section_video_bg_desktop_tablet{display:block}}@media (min-width:768px) and (max-width:980px){.et-db #et-boc .et-l .et_pb_section_video_bg.et_pb_section_video_bg_tablet_only{display:block}}@media (max-width:767px){.et-db #et-boc .et-l .et_pb_section_video_bg.et_pb_section_video_bg_phone{display:block}.et-db #et-boc .et-l .et_pb_section_video_bg.et_pb_section_video_bg_desktop_tablet{display:none}}