@media (max-width: 1279px) {
  /* Controls -> Simple */
  .sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_next,
  .sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_prev {
    width: 40px;
    height: 40px;
    line-height: 40px;
    text-align: center;
  }
  .sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_next:before,
  .sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_prev:before {
    font-size: 22px;
  }
}
@media (max-width: 1023px) {
  .sc_slider_controls.sc_slider_controls_simple.slider_pagination_style_title .slider_pagination_wrap .slider_pagination_bullet {
    font-size: 1.2em;
  }
  .sc_slider_controls.sc_slider_controls_simple.slider_pagination_style_title .slider_pagination_wrap .slider_pagination_bullet + .slider_pagination_bullet {
    margin-top: 15px !important;
  }
}

/*# sourceMappingURL=qw-extension.responsive.css.map */
