.et-db #et-boc .et-l .et_pb_widget{float:left;max-width:100%;word-wrap:break-word}.et-db #et-boc .et-l .et_pb_widget a{text-decoration:none;color:#666}.et-db #et-boc .et-l .et_pb_widget li a:hover{color:#82c0c7}.et-db #et-boc .et-l .et_pb_widget ol li,.et-db #et-boc .et-l .et_pb_widget ul li{margin-bottom:.5em}.et-db #et-boc .et-l .et_pb_widget ol li ol li,.et-db #et-boc .et-l .et_pb_widget ul li ul li{margin-left:15px}.et-db #et-boc .et-l .et_pb_widget select{width:100%;height:28px;padding:0 5px}.et-db #et-boc .et-l .et_pb_widget_area .et_pb_widget a{color:inherit}.et-db #et-boc .et-l .et_pb_bg_layout_light .et_pb_widget li a{color:#666}.et-db #et-boc .et-l .et_pb_bg_layout_dark .et_pb_widget li a{color:inherit}