.image-optimization-deactivation-modal {
	display: none;
}

.image-optimization-deactivation-content {
	padding: 20px;
}

/* Thickbox auto-height adjustments */
#TB_window.image-optimization-feedback-thickbox {
	height: auto !important;
	max-height: 90vh;
	overflow: auto;
	top: 50% !important;
	left: 50% !important;
	transform: translate(-50%, -50%) !important;
	margin: 0 !important;
	width: 600px !important;
	border-radius: 8px;
	box-shadow: 0 10px 30px rgb(0, 0, 0, 0.3);
}

.image-optimization-feedback-thickbox #TB_ajaxContent {
	overflow: visible;
	padding: 0;
}

.image-optimization-feedback-thickbox #TB_title {
	padding: 5px;
	display: flex;
	flex-direction: row;
}

.image-optimization-feedback-thickbox #TB_closeWindowButton .tb-close-icon {
	box-shadow: none !important;
}

.image-optimization-feedback-thickbox #TB_ajaxWindowTitle {
	font-size: 14px;
	letter-spacing: 1px;
}

.image-optimization-deactivation-content h3 {
	margin-top: 0;
	color: #23282d;
	font-size: 18px;
	font-weight: 600;
}

.image-optimization-deactivation-content p {
	color: #666;
	margin-bottom: 20px;
}

.image-optimization-feedback-options {
	margin-bottom: 20px;
}

.image-optimization-feedback-option {
	margin-bottom: 15px;
}

.image-optimization-feedback-option > label {
	display: flex;
	align-items: center;
	cursor: pointer;
	color: #23282d;
	margin-bottom: 8px;
}

.image-optimization-feedback-option input[type="radio"] {
	margin-right: 8px;
}

.image-optimization-feedback-text-field {
	margin-left: 24px;
	margin-top: 8px;
}

.text-field-hidden {
	display: none;
}

.image-optimization-feedback-text-field label {
	display: block;
	font-size: 12px;
	color: #666;
	margin-bottom: 4px;
}

.image-optimization-feedback-text-field input,
.image-optimization-feedback-text-field textarea {
	width: 100%;
	padding: 6px 8px;
	border: 1px solid #ddd;
	border-radius: 3px;
	font-size: 13px;
	resize: vertical;
}

.image-optimization-feedback-text-field input:focus,
.image-optimization-feedback-text-field textarea:focus {
	border-color: #0073aa;
	box-shadow: 0 0 0 1px #0073aa;
	outline: none;
}

.image-optimization-deactivation-buttons {
	display: flex;
	flex-direction: row-reverse;
	justify-content: space-between;
	gap: 10px;
	border-block-start: 1px solid #e1e1e1;
	padding-top: 20px;
}

.image-optimization-btn {
	padding: 8px 16px;
	border: none;
	background: none;
	text-decoration: none;
	border-radius: 3px;
	cursor: pointer;
	font-size: 13px;
	font-weight: 600;
	color: #c0c0c0;
	transition: all 0.3s ease;
}

.image-optimization-btn:hover {
	background: none;
	color: #000;
}

.image-optimization-btn-primary {
	background: rgb(240, 171, 252);
	border-color: rgb(240, 171, 252);
	color: #000;
	font-weight: 600;
	transition: all 0.3s ease;
}

.image-optimization-btn-primary:hover {
	background: #e881fa;
	border-color: #e881fa;
	color: #000;
}

.image-optimization-btn:focus {
	box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgb(30, 140, 190, 0.8);
	outline: none;
}
