.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image:hover .meta{z-index:3;opacity:1}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio{margin:0;position:relative;overflow:hidden}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_overlay{border:none;pointer-events:auto}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_carousel_group{display:none;float:left;width:100%;position:relative}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_carousel_group.active,.et-db #et-boc .et-l .et_pb_fullwidth_portfolio.et_pb_fullwidth_portfolio_grid .et_pb_carousel_group{display:block}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_items{width:100%;position:relative;overflow:hidden;left:0;top:0}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_item{float:left;margin:0;height:0;width:20%;position:relative}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image{position:relative;overflow:hidden;width:100%;height:100%;margin:0}.et-db #et-boc .et-l .et_pb_with_border .et_pb_portfolio_image,.et-db #et-boc .et-l .et_pb_with_border .et_pb_portfolio_item{border:0 solid #333}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image img{max-width:100%;height:inherit;min-height:100%;min-width:100%}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image.landscape img{height:100%}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image.portrait img{width:100%}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image:hover .et_overlay,.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image:hover .meta{z-index:3;opacity:1}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image .et_overlay:before{top:45%;transition:all .4s}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image:hover .et_overlay:before{top:33%}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio.et_pb_bg_layout_dark .et_pb_portfolio_image .et_overlay{background:rgba(0,0,0,.6)}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio.et_pb_bg_layout_dark .meta p{color:#fff}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image .meta{position:absolute;opacity:0;z-index:-1;top:0;left:0;width:100%;height:100%;transition:all .3s;box-sizing:border-box;-webkit-backface-visibility:hidden;backface-visibility:hidden;-webkit-transform:translateZ(0)}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_title,.et-db #et-boc .et-l .et_pb_fullwidth_portfolio h2.et_pb_portfolio_title{text-align:center;margin:30px 0;position:relative}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image .et_pb_module_header,.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image h3,.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image p{display:block;position:relative;float:left;z-index:5;width:100%;text-align:center;transition:all .3s;box-sizing:border-box;-webkit-backface-visibility:hidden;backface-visibility:hidden;-webkit-transform:translateZ(0)}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image .et_pb_module_header,.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image h3{margin-top:40%;padding:0 5px}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image .et_overlay+p.post-meta{position:absolute;top:50%;left:0;width:100%;transform:translateY(-50%)}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image:hover .et_pb_module_header,.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_portfolio_image:hover h3{margin-top:35%}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio:hover .et-pb-arrow-prev{left:22px;opacity:1}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio:hover .et-pb-arrow-next{right:22px;opacity:1}.et-db #et-boc .et-l .et_pb_fullwidth_portfolio .et_pb_no_results .entry{height:285.75px;display:flex;flex-direction:column;justify-content:center}@media (max-width:980px){.et-db #et-boc .et-l .et_pb_bg_layout_light_tablet.et_pb_fullwidth_portfolio .et_pb_portfolio_image .et_overlay{background:hsla(0,0%,100%,.9)}.et-db #et-boc .et-l .et_pb_bg_layout_light_tablet.et_pb_fullwidth_portfolio .meta p{color:#666}.et-db #et-boc .et-l .et_pb_bg_layout_dark_tablet.et_pb_fullwidth_portfolio .et_pb_portfolio_image .et_overlay{background:rgba(0,0,0,.6)}.et-db #et-boc .et-l .et_pb_bg_layout_dark_tablet.et_pb_fullwidth_portfolio .meta p{color:#fff}}@media (max-width:767px){.et-db #et-boc .et-l .et_pb_bg_layout_light_phone.et_pb_fullwidth_portfolio .et_pb_portfolio_image .et_overlay{background:hsla(0,0%,100%,.9)}.et-db #et-boc .et-l .et_pb_bg_layout_light_phone.et_pb_fullwidth_portfolio .meta p{color:#666}.et-db #et-boc .et-l .et_pb_bg_layout_dark_phone.et_pb_fullwidth_portfolio .et_pb_portfolio_image .et_overlay{background:rgba(0,0,0,.6)}.et-db #et-boc .et-l .et_pb_bg_layout_dark_phone.et_pb_fullwidth_portfolio .meta p{color:#fff}}