.et-db #et-boc .et-l .et_pb_widget_area_left{border-right:1px solid rgba(0,0,0,.1);padding-right:30px}.et-db #et-boc .et-l .et_pb_widget_area_right{border-left:1px solid rgba(0,0,0,.1);padding-left:30px}.et-db #et-boc .et-l .et_pb_sidebar_no_border{border:none;padding:0}.et-db #et-boc .et-l .et_pb_widget_area ul{list-style:none!important;padding:0!important;line-height:inherit!important}@media (max-width:980px){.et-db #et-boc .et-l .et_pb_bg_layout_dark_tablet .et_pb_widget li a{color:inherit}.et-db #et-boc .et-l .et_pb_widget_area_left{padding-right:0;border-right:none}.et-db #et-boc .et-l .et_pb_widget_area_right{padding-left:0;border-left:none}.et-db #et-boc .et-l .et_pb_column .et_pb_widget{margin:0 5.5% 7.5% 0;width:47.25%;clear:none;float:left}.et-db #et-boc .et-l .et_pb_column .et_pb_widget:nth-child(2n){margin-right:0}.et-db #et-boc .et-l .et_pb_column .et_pb_widget:nth-child(odd){clear:both}.et-db #et-boc .et-l .et_pb_row_1-2_1-4_1-4>.et_pb_column.et_pb_column_1_4 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-2_1-6_1-6_1-6>.et_pb_column.et_pb_column_1_6 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-4_1-4>.et_pb_column.et_pb_column_1_4 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-4_1-4_1-2>.et_pb_column.et_pb_column_1_4 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-5_1-5_3-5>.et_pb_column.et_pb_column_1_5 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-6_1-6_1-6>.et_pb_column.et_pb_column_1_6 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-6_1-6_1-6_1-2>.et_pb_column.et_pb_column_1_6 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-6_1-6_1-6_1-6>.et_pb_column.et_pb_column_1_6 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_3-5_1-5_1-5>.et_pb_column.et_pb_column_1_5 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_4col>.et_pb_column.et_pb_column_1_4 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_5col>.et_pb_column.et_pb_column_1_5 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_6col>.et_pb_column.et_pb_column_1_6 .et_pb_widget{margin:0 0 11.5%;width:100%}}@media (max-width:767px){.et-db #et-boc .et-l .et_pb_column .et_pb_widget{margin-right:0;width:100%}}@media (max-width:479px){.et-db #et-boc .et-l .et_pb_column .et_pb_widget{margin-right:0;margin-bottom:11.5%;width:100%}.et-db #et-boc .et-l .et_pb_row_1-2_1-4_1-4>.et_pb_column.et_pb_column_1_4 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-2_1-6_1-6_1-6>.et_pb_column.et_pb_column_1_6 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-4_1-4>.et_pb_column.et_pb_column_1_4 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-4_1-4_1-2>.et_pb_column.et_pb_column_1_4 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-5_1-5_3-5>.et_pb_column.et_pb_column_1_5 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-6_1-6_1-6>.et_pb_column.et_pb_column_1_6 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-6_1-6_1-6_1-2>.et_pb_column.et_pb_column_1_6 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_1-6_1-6_1-6_1-6>.et_pb_column.et_pb_column_1_6 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_3-5_1-5_1-5>.et_pb_column.et_pb_column_1_5 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_4col>.et_pb_column.et_pb_column_1_4 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_5col>.et_pb_column.et_pb_column_1_5 .et_pb_widget,.et-db #et-boc .et-l .et_pb_row_6col>.et_pb_column.et_pb_column_1_6 .et_pb_widget{margin:0 0 11.5%;width:100%}}.et_pb_no_sidebar_vertical_divider .et_pb_widget_area_left{border-right:none}.et_pb_no_sidebar_vertical_divider .et_pb_widget_area_right{border-left:none}