<?php

return [
	'Continue Editing'               => esc_html__( 'Continue Editing', 'Divi' ),
	'Start Over'                     => esc_html__( 'Start Over', 'Divi' ),
	'Edit Image'                     => esc_html__( 'Edit Image', 'Divi' ),
	'Modify'                         => esc_html__( 'Modify', 'Divi' ),
	'Extend'                         => esc_html__( 'Extend', 'Divi' ),
	'Upscale'                        => esc_html__( 'Upscale', 'Divi' ),
	'Enhance'                        => esc_html__( 'Enhance', 'Divi' ),
	'Upscale Image'                  => esc_html__( 'Upscale Image', 'Divi' ),
	'Image Scale'                    => esc_html__( 'Image Scale', 'Divi' ),
	'$imageScaleHelp'                => esc_html__( 'Choose how many times bigger you want your upscaled image to be.', 'Divi' ),
	'Image Dimensions'               => esc_html__( 'Image Dimensions', 'Divi' ),
	'$imageDimensionsHelp'           => esc_html__( 'Your image will be upscaled to the size defined here.', 'Divi' ),
	'Width'                          => esc_html__( 'Width', 'Divi' ),
	'Height'                         => esc_html__( 'Height', 'Divi' ),
	'Reset'                          => esc_html__( 'Reset', 'Divi' ),
	'Generate Modified Image'        => esc_html__( 'Generate Modified Image', 'Divi' ),
	'Image Fill Description'         => esc_html__( 'Image Fill Description', 'Divi' ),
	'Background Fill Description'    => esc_html__( 'Background Fill Description', 'Divi' ),
	'$imageFillDescriptionHelp'      => esc_html__( 'Tell Divi AI how you would like to change the image. Your changes will be applied to the area you select using the Image Selection or Image Sketch interface.', 'Divi' ),
	'Background Fill Description'    => esc_html__( 'Background Fill Description', 'Divi' ),
	'$backgroundFillDescriptionHelp' => esc_html__( 'Tell Divi AI how you would like it to fill in the blank area of your expanded image.', 'Divi' ),
	'Canvas Size'                    => esc_html__( 'Canvas Size', 'Divi' ),
	'$canvasSizeHelp'                => esc_html__( 'Choose the size of your new image. Blank areas of the canvas outside the bounds of your original image will be filled in with AI.', 'Divi' ),
	'Extend Image'                   => esc_html__( 'Extend Image', 'Divi' ),
	'Use selection as reference'     => esc_html__( 'Use selection as reference', 'Divi' ),
	'Brush Size'                     => esc_html__( 'Brush Size', 'Divi' ),
	'Paintbrush Size'                => esc_html__( 'Paintbrush Size', 'Divi' ),
	'Brush Blur'                     => esc_html__( 'Brush Blur', 'Divi' ),
	'Brush Color'                    => esc_html__( 'Brush Color', 'Divi' ),
	'Paint Color'                    => esc_html__( 'Paint Color', 'Divi' ),
	'Select All'                     => esc_html__( 'Select All', 'Divi' ),
	'Image Selection'                => esc_html__( 'Image Selection', 'Divi' ),
	'Image Sketch'                   => esc_html__( 'Image Sketch', 'Divi' ),
	'$selectAreaDesc'                => esc_html__( 'Paint over the area of the image that you would like to modify', 'Divi' ),
	'$sketchAreaDesc'                => esc_html__( 'Modify the reference image with a loose sketch', 'Divi' ),
	'Modification Strength'          => esc_html__( 'Modification Strength', 'Divi' ),
	'$modificationStrengthHelp'      => esc_html__( 'The higher the modification strength, the more power your prompt has to modify the original image. Reducing the strength will result in more minimal changes.', 'Divi' ),
	'Reference Content'              => esc_html__( 'Reference Content', 'Divi' ),
	'$referenceContentHelp'          => esc_html__( 'Use your original image as reference in the selected area. Changes will be more seamlessly integrated into the modified image.', 'Divi' ),
	'Enhancements'                   => esc_html__( 'Enhancements', 'Divi' ),
	'$enhancementsHelp'              => esc_html__( 'Select your desired enhancements. Your image will be sent back through Divi AI and re-imagined to achieve the desired result.', 'Divi' ),
	'Harmonize And Remove Artifacts' => esc_html__( 'Harmonize And Remove Artifacts', 'Divi' ),
	'Increase Saturation '           => esc_html__( 'Increase Saturation ', 'Divi' ),
	'Increase Contrast'              => esc_html__( 'Increase Contrast', 'Divi' ),
	'Increase Detail'                => esc_html__( 'Increase Detail', 'Divi' ),
	'Enhancement Strength'           => esc_html__( 'Enhancement Strength', 'Divi' ),
	'$enhancementStrengthHelp'       => esc_html__( 'The higher the enhancement strength, the more power is given to Divi AI to re-imagine the original image. A higher strength will increase the enhancement effect, but it will also result in greater changes to the original subject matter.', 'Divi' ),
	'Enhance Image'                  => esc_html__( 'Enhance Image', 'Divi' ),
	'Modification Type'              => esc_html__( 'Modification Type', 'Divi' ),
	'Modify Element'                 => esc_html__( 'Modify Element', 'Divi' ),
	'Add Element'                    => esc_html__( 'Add Element', 'Divi' ),
	'$modificationTypeHelp'          => esc_html__( 'To modify or add to an element that already exists in the image, choose Modify Element. To add something brand new and unrelated to the original image, choose Add Element.', 'Divi' ),
	'$backgroundImageRequired'       => esc_html__( 'Background image URL or base64 string is required.', 'Divi' ),
	'$imageRequired'                 => esc_html__( 'Image URL or base64 string is required.', 'Divi' ),
	'$imageSelectionRequired'        => esc_html__( 'Before generating a new image, you must paint the area of the image you want to modify.', 'Divi' ),
	'$imageSketchRequired'           => esc_html__( 'Before generating a new image, you must make a rough sketch of the object you want to add.', 'Divi' ),
	'$imageExtendRequired'           => esc_html__( 'Before generating a new image, you must extend the image canvas using the draggable anchors.', 'Divi' ),
	'$imageUpscaleRequired'          => esc_html__( 'Maximum canvas size is 8192px', 'Divi' ),
];
