.sc_chat {
  --trx-addons-ai-helper-chat-fields-border-radius: 6px;
  --trx-addons-ai-helper-chat-button-border-radius: 6px;
  --trx-addons-ai-helper-chat-button-abs-margin: 4px;
  --trx-addons-ai-helper-chat-tags-border-radius: 3px;
  --trx-addons-ai-helper-chat-attachment-button-border-radius: 6px;
  --trx-addons-ai-helper-chat-attachment-items-border-radius: 0px;
  --trx-addons-ai-helper-chat-attachments-clear-border-radius: 0px;
  --trx-addons-ai-helper-chat-items-border-radius: 12px;
  --trx-addons-ai-helper-chat-items-icon-size: 3em;
  --trx-addons-ai-helper-chat-items-icon-border-radius: 50%;
  --trx-addons-ai-helper-chat-content-border-radius: var(--trx-addons-ai-helper-chat-fields-border-radius);
  --trx-addons-ai-helper-chat-message-border-radius: var(--trx-addons-ai-helper-chat-fields-border-radius);
  --trx-addons-ai-helper-popup-offset-x: 2em;
  --trx-addons-ai-helper-popup-offset-y: 2em;
  --trx-addons-ai-helper-popup-button-size: 3em;
  --trx-addons-ai-helper-popup-button-border-radius: 50px;
}
.sc_chat a {
  text-decoration: none;
}
.sc_chat [data-tooltip-text] {
  position: relative;
  cursor: pointer;
}

.sc_chat_content {
  width: 100%;
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-content-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-chat-content-border-radius);
  border-radius: var(--trx-addons-ai-helper-chat-content-border-radius);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  background-color: #fff;
  overflow: hidden;
}
body.wp-admin .sc_chat_content {
  border: 1px solid #ddd;
}

.sc_chat_form {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  position: relative;
}
.sc_chat_form.sc_chat_form_loading:after {
  content: ' ';
  display: block;
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  z-index: 100;
  background-color: transparent;
}

.sc_chat_form_inner {
  width: 100%;
  max-width: 100%;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.sc_chat_form_field_prompt_label {
  display: block;
  width: 100%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  padding: 1.5em 2em;
  background-color: #000;
  color: #fff;
  font-weight: bold;
  position: relative;
}
.sc_chat_form_field_prompt_label h1, .sc_chat_form_field_prompt_label h2, .sc_chat_form_field_prompt_label h3, .sc_chat_form_field_prompt_label h4, .sc_chat_form_field_prompt_label h5, .sc_chat_form_field_prompt_label h6, .sc_chat_form_field_prompt_label p {
  margin: 0;
}
.sc_chat_form_field_prompt_label .sc_chat_form_title {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  width: 63%;
}
.sc_chat_form_field_prompt_label .sc_chat_form_title .sc_chat_form_title_image {
  max-height: 1.5em;
  width: auto;
  margin-right: 0.5em;
}
.sc_chat_form_field_prompt_label .sc_chat_form_title .sc_chat_form_title_svg {
  width: 1.5em;
  height: 1.5em;
  line-height: 1.5em;
  text-align: center;
  margin-right: 0.5em;
}
.sc_chat_form_field_prompt_label .sc_chat_form_title .sc_chat_form_title_svg svg {
  -webkit-transition: fill 0.3s ease;
  -ms-transition: fill 0.3s ease;
  transition: fill 0.3s ease;
}
.sc_chat_form_field_prompt_label .sc_chat_form_title .sc_chat_form_title_icon {
  font-size: 1.5em;
  margin-right: 0.5em;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.sc_chat_form_field_prompt_label .sc_chat_form_start_new {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  position: absolute;
  z-index: 1;
  top: 50%;
  right: 1em;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  max-width: 37%;
  padding: 0.5em 1em;
  color: #fff;
  text-decoration: none;
  text-align: right;
  cursor: pointer;
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
}
:where(.sc_chat:not(.trx_addons_customizable)) .sc_chat_form_field_prompt_label .sc_chat_form_start_new {
  font-weight: bold;
}
.sc_chat_form_field_prompt_label .sc_chat_form_start_new:hover {
  color: rgba(255, 255, 255, 0.7);
}
.sc_chat_form_field_prompt_label .sc_chat_form_start_new .sc_chat_form_start_new_image {
  max-height: 1.5em;
  width: auto;
  margin-left: 0.5em;
}
.sc_chat_form_field_prompt_label .sc_chat_form_start_new .sc_chat_form_start_new_svg {
  width: 1.5em;
  height: 1.5em;
  line-height: 1.5em;
  text-align: center;
  margin-left: 0.5em;
}
.sc_chat_form_field_prompt_label .sc_chat_form_start_new .sc_chat_form_start_new_svg svg {
  -webkit-transition: fill 0.3s ease;
  -ms-transition: fill 0.3s ease;
  transition: fill 0.3s ease;
}
.sc_chat_form_field_prompt_label .sc_chat_form_start_new .sc_chat_form_start_new_icon {
  font-size: 1.25em;
  margin-left: 0.5em;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}

.sc_chat_form_field_prompt {
  width: 100%;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  padding: 2em;
}
.sc_chat_form_field_prompt .sc_chat_form_field_inner {
  position: relative;
  width: 100%;
}
.sc_chat_form_field_prompt input[type="text"] {
  width: 100%;
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-fields-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-chat-fields-border-radius);
  border-radius: var(--trx-addons-ai-helper-chat-fields-border-radius);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  padding-right: 9em;
  text-overflow: ellipsis;
}
body.wp-admin .sc_chat_form_field_prompt input[type="text"] {
  padding-top: 1em;
  padding-bottom: 1em;
  padding-left: 1.5em;
  padding-right: 7em;
}
.sc_chat_with_attachments .sc_chat_form_field_prompt input[type="text"] {
  padding-left: 3.3em;
}
.sc_chat_form_field_prompt .sc_chat_form_field_upload_attachments_label,
.sc_chat_form_field_prompt .sc_chat_form_field_upload_attachments_field {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  position: absolute;
  z-index: 1;
  top: var(--trx-addons-ai-helper-chat-button-abs-margin);
  right: auto;
  bottom: var(--trx-addons-ai-helper-chat-button-abs-margin);
  left: var(--trx-addons-ai-helper-chat-button-abs-margin);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-attachment-button-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-chat-attachment-button-border-radius);
  border-radius: var(--trx-addons-ai-helper-chat-attachment-button-border-radius);
  -webkit-transition: background-color 0.3s ease, color 0.3s ease;
  -ms-transition: background-color 0.3s ease, color 0.3s ease;
  transition: background-color 0.3s ease, color 0.3s ease;
  width: 2.7em;
  cursor: pointer;
}
.sc_chat_form_field_prompt .sc_chat_form_field_upload_attachments_field {
  opacity: 0;
}
.sc_chat_form_field_prompt .sc_chat_form_field_upload_attachments_list {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  margin-top: 0.75em;
  gap: 0.75em;
}
.sc_chat_form_field_prompt .sc_chat_form_field_upload_attachments_list_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  gap: 0.5em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-attachment-items-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-chat-attachment-items-border-radius);
  border-radius: var(--trx-addons-ai-helper-chat-attachment-items-border-radius);
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  font-size: 0.8em;
  max-width: 10em;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.sc_chat_form_field_prompt .sc_chat_form_field_upload_attachments_list_item_icon {
  display: inline-block;
  vertical-align: middle;
  width: 25px;
  height: 32px;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  background-size: contain;
  background-repeat: no-repeat;
  background-position: center;
}
.sc_chat_form_field_prompt .sc_chat_form_field_upload_attachments_list_item_name {
  display: none;
  vertical-align: middle;
  overflow: hidden;
  text-overflow: ellipsis;
}
.sc_chat_form_field_prompt .sc_chat_form_field_upload_attachments_list_clear {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  gap: 0.3em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-attachments-clear-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-chat-attachments-clear-border-radius);
  border-radius: var(--trx-addons-ai-helper-chat-attachments-clear-border-radius);
  font-size: 0.8em;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  margin-left: 1em;
}
.sc_chat_form_field_prompt .sc_chat_form_field_upload_attachments_list_clear_icon {
  display: inline-block;
  vertical-align: middle;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease, border-color 0.3s ease;
}
.sc_chat_form_field_prompt .sc_chat_form_field_upload_attachments_list_clear_name {
  display: inline-block;
  vertical-align: middle;
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  position: absolute;
  z-index: 1;
  top: var(--trx-addons-ai-helper-chat-button-abs-margin);
  right: var(--trx-addons-ai-helper-chat-button-abs-margin);
  bottom: var(--trx-addons-ai-helper-chat-button-abs-margin);
  left: auto;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-button-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-chat-button-border-radius);
  border-radius: var(--trx-addons-ai-helper-chat-button-border-radius);
  -webkit-transition: background-color 0.3s ease, color 0.3s ease;
  -ms-transition: background-color 0.3s ease, color 0.3s ease;
  transition: background-color 0.3s ease, color 0.3s ease;
  max-width: 50%;
  overflow: hidden;
  padding: 0 2em;
  background-color: #38bb7a;
  color: #fff;
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button.sc_chat_form_field_prompt_button_with_icon {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button:not(.sc_chat_form_field_prompt_button_disabled):hover {
  background-color: #32a86e;
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button .sc_chat_form_field_prompt_button_image {
  max-height: 1.25em;
  width: auto;
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button .sc_chat_form_field_prompt_button_svg {
  width: 1.25em;
  height: 1.25em;
  line-height: 1.25em;
  text-align: center;
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button .sc_chat_form_field_prompt_button_svg svg {
  -webkit-transition: fill 0.3s ease;
  -ms-transition: fill 0.3s ease;
  transition: fill 0.3s ease;
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button .sc_chat_form_field_prompt_button_icon {
  font-size: 1.25em;
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button .sc_chat_form_field_prompt_button_image + .sc_chat_form_field_prompt_button_text,
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button .sc_chat_form_field_prompt_button_svg + .sc_chat_form_field_prompt_button_text,
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button .sc_chat_form_field_prompt_button_icon + .sc_chat_form_field_prompt_button_text {
  margin-left: 0.5em;
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button .sc_chat_form_field_prompt_button_text {
  white-space: nowrap;
}
.sc_chat_form_field_prompt .sc_chat_form_field_prompt_button_disabled {
  background-color: #e4f7ed;
  color: #aaa;
  cursor: default;
}

.sc_chat_form_field_tags {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 100%;
  padding: 0 2em;
}
.sc_chat_form_field_tags.sc_chat_form_field_tags_before {
  padding-top: 2em;
}
.sc_chat_form_field_tags.sc_chat_form_field_tags_before + .sc_chat_form_field_prompt {
  padding-top: 1em;
}
.sc_chat_form_field_tags.sc_chat_form_field_tags_after {
  padding-bottom: 2em;
}
.sc_chat_form_align_left .sc_chat_form_field_tags {
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}
.sc_chat_form_align_right .sc_chat_form_field_tags {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}

.sc_chat_form_field_tags_label {
  white-space: nowrap;
  padding: 0.5em 1em 0.5em 0;
}

.sc_chat_form_field_tags_list {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}

.sc_chat_form_field_tags_item {
  display: inline-block;
  vertical-align: top;
  margin: 0 0.5em 0.5em 0;
  padding: 0.5em 1em;
  background-color: #f8f8f9;
  color: #9099a2;
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-tags-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-chat-tags-border-radius);
  border-radius: var(--trx-addons-ai-helper-chat-tags-border-radius);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.sc_chat_form_field_tags_item:hover {
  color: #23282d;
  background-color: #f0f1f2;
}

.sc_chat_limits {
  width: 100%;
  text-align: center;
  padding: 0 2em 1em;
  margin-top: -1em;
}
.sc_chat_limits .sc_chat_limits_used {
  display: block;
}

.sc_chat_message {
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-message-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-chat-message-border-radius);
  border-radius: var(--trx-addons-ai-helper-chat-message-border-radius);
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  position: relative;
  padding: 2em 3em;
  min-width: 40%;
  max-width: 90%;
  background-color: #feeeee;
  color: #f04c49;
  margin: 1em 0;
  text-align: center;
  display: none;
}
.sc_chat_message .trx_addons_button_close_icon {
  color: #99302e;
}
.sc_chat_message .trx_addons_button_close_icon:before, .sc_chat_message .trx_addons_button_close_icon:after {
  border-color: #99302e;
}

.sc_chat_message_inner p, .sc_chat_message_inner h1, .sc_chat_message_inner h2, .sc_chat_message_inner h3, .sc_chat_message_inner h4, .sc_chat_message_inner h5, .sc_chat_message_inner h6 {
  margin: 0;
}
.sc_chat_message_inner p + p, .sc_chat_message_inner h1 + p, .sc_chat_message_inner h2 + p, .sc_chat_message_inner h3 + p, .sc_chat_message_inner h4 + p, .sc_chat_message_inner h5 + p, .sc_chat_message_inner h6 + p {
  margin-top: 0.3em;
}
.sc_chat_message_inner h1, .sc_chat_message_inner h2, .sc_chat_message_inner h3, .sc_chat_message_inner h4, .sc_chat_message_inner h5, .sc_chat_message_inner h6 {
  color: #99302e;
}
.sc_chat_message_inner a {
  display: inline-block;
  vertical-align: top;
  font-weight: 500;
  color: #99302e;
  border-bottom: 1px dashed #99302e;
}
.sc_chat_message_inner a:hover {
  color: #99302e;
  border-bottom-style: solid;
}

.sc_chat_message_type_info {
  background-color: #e5f5fa;
  color: #00a0d2;
}
.sc_chat_message_type_info h1, .sc_chat_message_type_info h2, .sc_chat_message_type_info h3, .sc_chat_message_type_info h4, .sc_chat_message_type_info h5, .sc_chat_message_type_info h6 {
  color: #007599;
}
.sc_chat_message_type_info a {
  color: #007599;
  border-bottom-color: #007599;
}
.sc_chat_message_type_info a:hover {
  color: #007599;
}
.sc_chat_message_type_info .trx_addons_button_close_icon {
  color: #007599;
}
.sc_chat_message_type_info .trx_addons_button_close_icon:before, .sc_chat_message_type_info .trx_addons_button_close_icon:after {
  border-color: #007599;
}

.sc_chat_message_type_success {
  background-color: #e4f7ed;
  color: #38bb7a;
}
.sc_chat_message_type_success h1, .sc_chat_message_type_success h2, .sc_chat_message_type_success h3, .sc_chat_message_type_success h4, .sc_chat_message_type_success h5, .sc_chat_message_type_success h6 {
  color: #2e9963;
}
.sc_chat_message_type_success a {
  color: #2e9963;
  border-bottom-color: #2e9963;
}
.sc_chat_message_type_success a:hover {
  color: #2e9963;
}
.sc_chat_message_type_success .trx_addons_button_close_icon {
  color: #2e9963;
}
.sc_chat_message_type_success .trx_addons_button_close_icon:before, .sc_chat_message_type_success .trx_addons_button_close_icon:after {
  border-color: #2e9963;
}

.sc_chat_result {
  display: none;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  padding: 2em 2em 0 2em;
  width: 100%;
  max-height: 50vh;
  overflow-y: auto;
  overflow-x: visible;
  scrollbar-width: thin;
  scrollbar-color: var(--theme-color-alter_bd_color, var(--theme-color-bd_color)) var(--theme-color-alter_bg_color, var(--theme-color-bg_color_2));
}
.sc_chat_result::-webkit-scrollbar {
  width: 8px;
}
.sc_chat_result::-webkit-scrollbar-track {
  background: var(--theme-color-alter_bg_color, var(--theme-color-bg_color_2));
}
.sc_chat_result::-webkit-scrollbar-thumb {
  background-color: var(--theme-color-alter_bd_color, var(--theme-color-bd_color));
  border: 1px solid var(--theme-color-alter_bg_color, var(--theme-color-bg_color_2));
  -webkit-border-radius: 6px;
  -ms-border-radius: 6px;
  border-radius: 6px;
}
.sc_chat_result .sc_chat_list {
  margin: 0;
  padding: 0 0 1em;
  list-style: none;
}
.sc_chat_result .sc_chat_list:empty {
  padding: 0;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  gap: 1em;
  margin-bottom: 1em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item:last-child {
  margin-bottom: 0;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_avatar {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  width: var(--trx-addons-ai-helper-chat-items-icon-size);
  height: var(--trx-addons-ai-helper-chat-items-icon-size);
  line-height: var(--trx-addons-ai-helper-chat-items-icon-size);
  text-align: center;
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-items-icon-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-chat-items-icon-border-radius);
  border-radius: var(--trx-addons-ai-helper-chat-items-icon-border-radius);
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_avatar .sc_chat_list_item_icon {
  font-size: calc( var(--trx-addons-ai-helper-chat-items-icon-size) / 2 );
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_avatar .sc_chat_list_item_svg {
  width: 50%;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_avatar .sc_chat_list_item_icon,
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_avatar .sc_chat_list_item_svg,
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_avatar .sc_chat_list_item_image {
  max-width: 100%;
  line-height: 1;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  text-align: left;
  min-width: 8em;
  max-width: 80%;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content {
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) 0;
  -ms-border-radius: var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) 0;
  border-radius: var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) 0;
  padding: 0.5em 1em;
  background-color: #e4f7ed;
  color: #38bb7a;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h1 {
  font-size: 2em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h2 {
  font-size: 1.8em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h3 {
  font-size: 1.6em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h4 {
  font-size: 1.4em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h5 {
  font-size: 1.2em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h6 {
  font-size: 1.1em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content p, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ol, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ul, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content dl, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h1, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h2, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h3, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h4, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h5, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h6 {
  color: inherit;
  margin-top: 0;
  margin-bottom: 0.3em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content p:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ol:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ul:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content dl:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h1:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h2:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h3:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h4:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h5:last-child, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content h6:last-child {
  margin-bottom: 0;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ol, .sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content ul {
  margin-left: 1em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_content img {
  max-width: 100%;
  height: auto;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item.sc_chat_list_item_with_avatar .sc_chat_list_item_content {
  -webkit-border-radius: 0 var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius);
  -ms-border-radius: 0 var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius);
  border-radius: 0 var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius);
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_time {
  margin-top: 0.3em;
  color: #999;
  -webkit-align-self: flex-end;
  -ms-align-self: end;
  align-self: flex-end;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_attachments_list {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  margin-top: -1.8em;
  gap: 0.5em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_attachments_list_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  gap: 0.3em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  font-size: 0.8em;
  max-width: 10em;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_attachments_list_item_icon {
  width: 20px;
  height: 26px;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  background-size: contain;
  background-repeat: no-repeat;
  background-position: center;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item .sc_chat_list_item_attachments_list_item_name {
  display: none;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_user {
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_user .sc_chat_list_item_avatar {
  order: 2;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_user .sc_chat_list_item_wrap {
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
  order: 1;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_user .sc_chat_list_item_content {
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) 0 var(--trx-addons-ai-helper-chat-items-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) 0 var(--trx-addons-ai-helper-chat-items-border-radius);
  border-radius: var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius) 0 var(--trx-addons-ai-helper-chat-items-border-radius);
  background-color: #e5f5fa;
  color: #00a0d2;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_user .sc_chat_list_item_content h1, .sc_chat_result .sc_chat_list .sc_chat_list_item_user .sc_chat_list_item_content h2, .sc_chat_result .sc_chat_list .sc_chat_list_item_user .sc_chat_list_item_content h3, .sc_chat_result .sc_chat_list .sc_chat_list_item_user .sc_chat_list_item_content h4, .sc_chat_result .sc_chat_list .sc_chat_list_item_user .sc_chat_list_item_content h5, .sc_chat_result .sc_chat_list .sc_chat_list_item_user .sc_chat_list_item_content h6 {
  color: #00a0d2;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_user.sc_chat_list_item_with_avatar .sc_chat_list_item_content {
  -webkit-border-radius: var(--trx-addons-ai-helper-chat-items-border-radius) 0 var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-chat-items-border-radius) 0 var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius);
  border-radius: var(--trx-addons-ai-helper-chat-items-border-radius) 0 var(--trx-addons-ai-helper-chat-items-border-radius) var(--trx-addons-ai-helper-chat-items-border-radius);
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_user .sc_chat_list_item_time {
  -webkit-align-self: flex-start;
  -ms-align-self: start;
  align-self: flex-start;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_loading {
  min-width: 6em;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_loading .sc_chat_list_item_content {
  white-space: nowrap;
  overflow: hidden;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_loading .sc_chat_list_item_loading_dot {
  display: inline-block;
  width: 3px;
  height: 3px;
  margin-right: 3px;
  -webkit-border-radius: 50%;
  -ms-border-radius: 50%;
  border-radius: 50%;
  background-color: #38bb7a;
  -webkit-animation: trx-animation-jumping 1.5s linear infinite;
  -ms-animation: trx-animation-jumping 1.5s linear infinite;
  animation: trx-animation-jumping 1.5s linear infinite;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_loading .sc_chat_list_item_loading_dot:nth-child(2) {
  -webkit-animation-delay: 0.2s;
  -ms-animation-delay: 0.2s;
  animation-delay: 0.2s;
}
.sc_chat_result .sc_chat_list .sc_chat_list_item_loading .sc_chat_list_item_loading_dot:nth-child(3) {
  -webkit-animation-delay: 0.4s;
  -ms-animation-delay: 0.4s;
  animation-delay: 0.4s;
}

@-webkit-keyframes trx-animation-jumping {
  0% {
    -webkit-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
  }
  20% {
    -webkit-transform: translateY(-5px);
    -ms-transform: translateY(-5px);
    transform: translateY(-5px);
  }
  40% {
    -webkit-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
  }
  100% {
    -webkit-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
  }
}
@keyframes trx-animation-jumping {
  0% {
    -webkit-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
  }
  20% {
    -webkit-transform: translateY(-5px);
    -ms-transform: translateY(-5px);
    transform: translateY(-5px);
  }
  40% {
    -webkit-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
  }
  100% {
    -webkit-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
  }
}
.sc_chat_popup {
  position: fixed;
  z-index: 999999;
  bottom: var(--trx-addons-ai-helper-popup-offset-y);
  right: var(--trx-addons-ai-helper-popup-offset-x);
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  gap: 1em;
  max-width: 25%;
  max-height: calc( 100% - var(--trx-addons-ai-helper-popup-offset-y) - var(--trx-addons-ai-helper-popup-button-size) - 2em );
}
body.rtl .sc_chat_popup {
  left: var(--trx-addons-ai-helper-popup-offset-x);
  right: auto;
}
.sc_chat_position_tl .sc_chat_popup {
  left: var(--trx-addons-ai-helper-popup-offset-x);
  right: auto;
  top: var(--trx-addons-ai-helper-popup-offset-y);
  bottom: auto;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}
.sc_chat_position_tr .sc_chat_popup {
  left: auto;
  right: var(--trx-addons-ai-helper-popup-offset-x);
  top: var(--trx-addons-ai-helper-popup-offset-y);
  bottom: auto;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
}
.sc_chat_position_bl .sc_chat_popup {
  left: var(--trx-addons-ai-helper-popup-offset-x);
  right: auto;
  top: auto;
  bottom: var(--trx-addons-ai-helper-popup-offset-y);
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}
.sc_chat_position_br .sc_chat_popup {
  left: auto;
  right: var(--trx-addons-ai-helper-popup-offset-x);
  top: auto;
  bottom: var(--trx-addons-ai-helper-popup-offset-y);
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
}
.sc_chat_popup.sc_chat_opening, .sc_chat_popup.sc_chat_opened {
  min-width: 468px;
}
.sc_chat_popup:not(.sc_chat_opened) .sc_chat_content {
  display: none;
}
.sc_chat_popup .sc_chat_popup_button {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  -webkit-flex-shrink: 0;
  -ms-flex-shrink: 0;
  flex-shrink: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-border-radius: var(--trx-addons-ai-helper-popup-button-border-radius);
  -ms-border-radius: var(--trx-addons-ai-helper-popup-button-border-radius);
  border-radius: var(--trx-addons-ai-helper-popup-button-border-radius);
  -webkit-transition: background-color 0.3s ease, color 0.3s ease;
  -ms-transition: background-color 0.3s ease, color 0.3s ease;
  transition: background-color 0.3s ease, color 0.3s ease;
  width: var(--trx-addons-ai-helper-popup-button-size);
  height: var(--trx-addons-ai-helper-popup-button-size);
  line-height: var(--trx-addons-ai-helper-popup-button-size);
  text-align: center;
  overflow: hidden;
  background-color: #38bb7a;
  color: #fff;
}
.sc_chat_popup .sc_chat_popup_button .sc_chat_popup_button_svg {
  width: 50%;
}
.sc_chat_popup .sc_chat_popup_button .sc_chat_popup_button_svg svg {
  -webkit-transition: fill 0.3s ease;
  -ms-transition: fill 0.3s ease;
  transition: fill 0.3s ease;
}
.sc_chat_popup .sc_chat_popup_button .sc_chat_popup_button_icon {
  font-size: calc( var(--trx-addons-ai-helper-popup-button-size) / 2 );
  -webkit-transition: color 0.3s ease;
  -ms-transition: color 0.3s ease;
  transition: color 0.3s ease;
}
.sc_chat_popup .sc_chat_popup_button .sc_chat_popup_button_icon,
.sc_chat_popup .sc_chat_popup_button .sc_chat_popup_button_svg,
.sc_chat_popup .sc_chat_popup_button .sc_chat_popup_button_image {
  max-width: 100%;
  line-height: 1;
}
.sc_chat_popup .sc_chat_limits .sc_chat_limits_used {
  white-space: normal;
}
.sc_chat_popup .sc_chat_message {
  position: absolute;
  z-index: 100;
  bottom: 1.5em;
  margin: 0;
  width: 100%;
  -webkit-box-shadow: 0 0 15px rgba(0, 0, 0, 0.15);
  -ms-box-shadow: 0 0 15px rgba(0, 0, 0, 0.15);
  box-shadow: 0 0 15px rgba(0, 0, 0, 0.15);
}

.sc_chat.trx_addons_customizable .sc_chat_content_area {
  width: 100%;
  max-width: 100%;
  padding: 2em;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_chat.trx_addons_customizable .sc_chat_content_area .sc_chat_form_field_prompt,
.sc_chat.trx_addons_customizable .sc_chat_content_area .sc_chat_form_field_tags,
.sc_chat.trx_addons_customizable .sc_chat_content_area .sc_chat_limits,
.sc_chat.trx_addons_customizable .sc_chat_content_area .sc_chat_result {
  padding: 0;
}
.sc_chat.trx_addons_customizable .sc_chat_content_area .sc_chat_form_field_prompt:not(:first-child),
.sc_chat.trx_addons_customizable .sc_chat_content_area .sc_chat_form_field_tags:not(:first-child),
.sc_chat.trx_addons_customizable .sc_chat_content_area .sc_chat_limits:not(:first-child),
.sc_chat.trx_addons_customizable .sc_chat_content_area .sc_chat_result:not(:first-child) {
  margin-top: 2em;
}
.sc_chat.trx_addons_customizable .sc_chat_content_area .sc_chat_result:has(.sc_chat_list:empty) + div {
  margin-top: 0;
}
.sc_chat.trx_addons_customizable .sc_chat_form_field_tags {
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.sc_chat.trx_addons_customizable .sc_chat_form_field_tags_label {
  padding: 0 1em 0.5em 0;
}

/*# sourceMappingURL=chat.css.map */
