"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["497"],{41939:function(a){a.exports=JSON.parse('{"copyClipboard":"Copiar para a \xe1rea de transfer\xeancia","copyClipboardSuccess":"Copiado!","noDataToDisplay":"Nenhum dado para exibir","search":"Pesquisar","sort":"Ordenar","pagination":{"rowsPerPage":"Linhas por p\xe1gina:","displayedRows":"{from}-{to} de {count}"}}')}}]);