.et-db #et-boc .et-l .et_pb_wc_checkout_additional_info #order_review_heading,.et-db #et-boc .et-l .et_pb_wc_checkout_additional_info .col2-set .col-1{display:none}.et-db #et-boc .et-l .et_pb_wc_checkout_additional_info .col2-set .col-2{width:100%}.et-db #et-boc .et-l .et_pb_wc_checkout_additional_info.et_pb_wc_no_title h3,.et-db #et-boc .et-l .et_pb_wc_checkout_additional_info .woocommerce-additional-fields h3:not(:first-of-type),.et-db #et-boc .et-l .et_pb_wc_checkout_additional_info .woocommerce-shipping-fields{display:none}.et-db #et-boc .et-l .et_pb_wc_checkout_additional_info form .form-row textarea.input-text{height:auto}.et-db #et-boc .et-l .et_pb_wc_checkout_additional_info.et_pb_hide_module,.et-db #et-boc .et-l .et_pb_wc_checkout_additional_info.et_pb_wc_order_pay,.et-db #et-boc .et-l .et_pb_wc_checkout_additional_info .woocommerce-form-login-toggle,.et-db #et-boc .et-l .et_pb_wc_checkout_additional_info .woocommerce-notices-wrapper{display:none}