/*! For license information please see menus.js.LICENSE.txt */
!function(){"use strict";var e={"./packages/packages/libs/menus/src/create-menu.ts":function(e,r,t){t.r(r),t.d(r,{createMenu:function(){return createMenu}});var n=t("@elementor/locations"),c=t("./packages/packages/libs/menus/src/create-register-item.tsx"),u=t("./packages/packages/libs/menus/src/create-use-menu-items.ts");function createMenu({groups:e=[],components:r}){const t=function createLocations(e){return e.reduce((e,r)=>(e[r]=(0,n.createLocation)(),e),{})}([...e,"default"]),a=function createRegisterFns(e,r){return Object.entries(r).reduce((r,[t,n])=>{const u=`register${function capitalize(e){return e.charAt(0).toUpperCase()+e.slice(1)}(t)}`;return{...r,[u]:(0,c.createRegisterItem)(e,n)}},{})}(t,r);return{useMenuItems:(0,u.createUseMenuItems)(t),...a}}},"./packages/packages/libs/menus/src/create-register-item.tsx":function(e,r,t){t.r(r),t.d(r,{createRegisterItem:function(){return createRegisterItem}});var n=t("react");function _extends(){return _extends=Object.assign?Object.assign.bind():function(e){for(var r=1;r<arguments.length;r++){var t=arguments[r];for(var n in t)({}).hasOwnProperty.call(t,n)&&(e[n]=t[n])}return e},_extends.apply(null,arguments)}function createRegisterItem(e,r){return({id:t,group:c="default",priority:u=10,overwrite:a=!1,props:i,useProps:s})=>{if(!(c in e))return;const o=r,_=s||(()=>i);e[c].inject({id:t,component:e=>{const r=_();return n.createElement(o,_extends({},e,r))},options:{priority:u,overwrite:a}})}}},"./packages/packages/libs/menus/src/create-use-menu-items.ts":function(e,r,t){t.r(r),t.d(r,{createUseMenuItems:function(){return createUseMenuItems}});var n=t("react");function createUseMenuItems(e){return()=>(0,n.useMemo)(()=>Object.entries(e).reduce((e,[r,t])=>{const n=t.getInjections().map(e=>({id:e.id,MenuItem:e.component}));return{...e,[r]:n}},{}),[])}},"@elementor/locations":function(e){e.exports=window.elementorV2.locations},react:function(e){e.exports=window.React}},r={};function __webpack_require__(t){var n=r[t];if(void 0!==n)return n.exports;var c=r[t]={exports:{}};return e[t](c,c.exports,__webpack_require__),c.exports}__webpack_require__.n=function(e){var r=e&&e.__esModule?function(){return e.default}:function(){return e};return __webpack_require__.d(r,{a:r}),r},__webpack_require__.d=function(e,r){for(var t in r)__webpack_require__.o(r,t)&&!__webpack_require__.o(e,t)&&Object.defineProperty(e,t,{enumerable:!0,get:r[t]})},__webpack_require__.o=function(e,r){return Object.prototype.hasOwnProperty.call(e,r)},__webpack_require__.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})};var t={};!function(){__webpack_require__.r(t),__webpack_require__.d(t,{createMenu:function(){return e.createMenu}});var e=__webpack_require__("./packages/packages/libs/menus/src/create-menu.ts")}(),(window.elementorV2=window.elementorV2||{}).menus=t}(),window.elementorV2.menus?.init?.();
//# sourceMappingURL=menus.js.map