/**
 * Resets
 */
#epanel span,
#epanel applet,
#epanel object,
#epanel iframe,
#epanel h1,
#epanel h2,
#epanel h3,
#epanel h4,
#epanel h5,
#epanel h6,
#epanel p,
#epanel blockquote,
#epanel a,
#epanel abbr,
#epanel acronym,
#epanel address,
#epanel big,
#epanel cite,
#epanel code,
#epanel del,
#epanel dfn,
#epanel font,
#epanel img,
#epanel ins,
#epanel kbd,
#epanel q,
#epanel s,
#epanel samp,
#epanel small,
#epanel strike,
#epanel strong,
#epanel tt,
#epanel var,
#epanel fieldset,
#epanel dl,
#epanel dt,
#epanel dd,
#epanel ol,
#epanel ul,
#epanel li,
#epanel form,
#epanel label,
#epanel legend,
#epanel table,
#epanel caption,
#epanel tbody,
#epanel tfoot,
#epanel thead,
#epanel tr,
#epanel th,
#epanel td {
	margin: 0;
	padding: 0;
	border: 0;
	outline: 0;
	font-weight: inherit;
	font-style: inherit;
	font-size: 100%;
	font-family: inherit;
	vertical-align: baseline;
	-webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

#epanel pre,
#epanel sub,
#epanel sup,
#epanel em {
	margin: 0;
	padding: 0;
	border: 0;
	outline: 0;
	-webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

#epanel button {
	box-shadow: none;
	-webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

/* remember to define focus styles! */
#epanel :focus {
	outline: 0;
}

#epanel ol, #epanel ul {
	list-style: none;
	-webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

#epanel a {
	text-decoration: none;
	-webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

/**
 * Main Wrappers
 */
#panel-wrap, #custom-lbox {
	font-family: 'Open Sans', sans-serif;
	-webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

#wrapper {
	margin: 30px 30px 0 20px;
}

#epanel-wrapper {
	background: white;
	border: none;
    box-shadow: 0 5px 30px rgba(0,0,0,.1);
	border-radius: 3px;
	color: #32373c;
}

/**
 * ePanel Header
 */
#epanel-header {
	background: #6c2eb9;
	padding: 20px 26px 20px;
	line-height: .8;
	position: relative;
	border-radius: 3px 3px 0 0;
}

h1#epanel-title {
	font-weight: 600;
	font-size: 18px;
	color: rgb(255, 255, 255);
	background-color: #6c2eb9;
	border-bottom: 0px;
	line-height: 18px;
	margin-bottom: 0px;
	position: relative;
	padding-left: 11px;
}

.rtl h1#epanel-title {
	padding-left: 0;
	padding-right: 11px;
}

#epanel-title:before {
	font-family: 'etbuilder';
	speak: none;
	font-weight: normal;
	font-variant: normal;
	text-transform: none;
	line-height: 1;
	-webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
	content: "<";
	display: none;
	position: absolute;
	left: 0;
	top: -6px;
	font-size: 32px;
}

.rtl #epanel-title:before {
	left: auto;
	right: 0;
}

.toplevel_page_et_extra_options h1#epanel-title, .toplevel_page_et_divi_options h1#epanel-title {
	padding-left: 45px;
}

.rtl.toplevel_page_et_extra_options h1#epanel-title,
.rtl.toplevel_page_et_divi_options h1#epanel-title {
	padding-left: 0;
	padding-right: 45px;
}

.toplevel_page_et_extra_options #epanel-title:before, .toplevel_page_et_divi_options #epanel-title:before {
	display: block;
}

/**
 * Reset Buttons
 */
#epanel-header .et-defaults-button {
	width: 40px;
    height: 40px;
    padding: 0;
    text-align: center;
    line-height: 40px;
    position: absolute;
    bottom: -40px;
    right: 10px;
    z-index: 50;
    color: white;
    background-color: #7e3bd0;
    transition: all 0.3s;
}

.rtl #epanel-header .et-defaults-button {
	right: auto;
	left: 20px;
}

#epanel-header .et-defaults-button:hover {
	background-color: #8F42ED;
}

#epanel-header .et-defaults-button:focus {
	box-shadow: none;
}

#epanel-header .et-defaults-button.epanel-reset:before {
	font-family: 'etbuilder';
	content: '\4d';
	font-size: 16px;
	-webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    font-weight: 400;
}

#epanel-header .et-defaults-button .label {
	display: none;
}

/**
 * Primary Tab Menu
 */
#epanel-mainmenu {
	background-color: #7e3bd0;
	display: block;
	position: relative;
	overflow: hidden;
}

#epanel #epanel-mainmenu {
	padding-right: 100px;
}

.rtl #epanel #epanel-mainmenu {
	padding-left: 100px;
	padding-right: 0;
}

#epanel-mainmenu li {
	float: left;
	display: inline-block;
	font-family: 'Open Sans', sans-serif;
	font-weight: 600;
}

.rtl #epanel-mainmenu li {
	float: right;
}

#epanel-mainmenu li.ui-state-active a {
	background-color: #8F42ED;
}

#epanel-mainmenu a:hover{
	background-color: #7435c1;
}

#epanel-mainmenu a {
	box-sizing: border-box;
	color: white;
	padding: 13px 26px;
	display: inline-block;
	transition: all 0.3s;
	outline: 0;
	font-size: 14px;
	line-height: 14px;
}

#epanel-mainmenu a:focus {
	box-shadow: none;
}

/**
 * Secondary Tab Menu
 */
#epanel-content ul.et-id-tabs {
	background-color: #F1F5F9;
	float: left;
	width: 100%;
}

#epanel-content ul.et-id-tabs:after {
	content: "";
	visibility: hidden;
	display: block;
	height: 0;
	clear: both;
}

#epanel-content ul.et-id-tabs li {
	display: inline-block;
	float: left;
}

.rtl #epanel-content ul.et-id-tabs li {
	float: right;
}

#epanel-content ul.et-id-tabs a {
	color: #8E969E;
	display: block;
	clear: both;
	position: relative;
	padding: 13px 26px;
	font-size: 14px;
	line-height: 14px;
	font-weight: 600;
	transition: all 0.3s;
	-webkit-transition: all 0.3s;
}

#wrap-general ul.et-id-tabs a:first-of-type {
	padding-right: 25px;
}

.rtl #wrap-general ul.et-id-tabs a:first-of-type {
	padding-left: 25px;
	padding-right: 40px;
}

#ui-id-9 {
	padding-right: 27px;
}

#epanel-content ul.et-id-tabs a:hover {
	background-color: #e6ecf2;
}

#epanel-content ul.et-id-tabs .ui-tabs-active a {
	background-color: #fff;
}

#epanel-content ul.et-id-tabs a:focus {
	box-shadow: none;
}

#epanel-content ul.et-id-tabs li{
	position: relative;
}

#epanel-content ul.et-id-tabs .ui-state-active a:focus {
	box-shadow: none;
}

/**
 * Content
 */
#epanel-content-wrap {
	display: block;
	position: relative;
	
}

#epanel-content {
	position: relative;
}

#epanel-content > .et-content-div {
	clear: both;
}

#epanel-content > .et-content-div[aria-hidden="false"],
#epanel-content .et-tab-content[aria-hidden="false"] {
	-webkit-animation: fadeIn .5s 1 cubic-bezier(0.77, 0, 0.175, 1);
	-moz-animation: fadeIn .5s 1 cubic-bezier(0.77, 0, 0.175, 1);
	-o-animation: fadeIn .5s 1 cubic-bezier(0.77, 0, 0.175, 1);
	animation: fadeIn .5s 1 cubic-bezier(0.77, 0, 0.175, 1);
}

#epanel.et-onload #epanel-content > .et-content-div[aria-hidden="false"],
#epanel.et-onload #epanel-content .et-tab-content[aria-hidden="false"] {
	-webkit-animation: none;
	-moz-animation: none;
	-o-animation: none;
	animation: none;
}

#epanel-content .et-tab-content {
	clear: both;
	padding: 30px;
}

#epanel-content .et-epanel-box {
	margin-bottom: 20px;
	position: relative;
}

#epanel-content .et-tab-content .et-epanel-box:last-child {
	margin-bottom: 0;
}

/**
 * Inputs
 */
#epanel .et-epanel-box .et-box-title {
	padding: 10px 0px 10px 0;
	position: relative;
}

#epanel .et-epanel-box .et-box-description {
	position: absolute;
	top: 11px;
	right: 0;
	opacity: 0;
	width: 18px;
	height: 18px;
	color: #32373C;
	content: '';
	text-align: center;
	-webkit-transition: opacity .5s;
	-moz-transition: opacity .5s;
	transition: opacity .5s;
	-webkit-transition-timing-function: ease;
	-moz-transition-timing-function: ease;
	transition-timing-function: ease;
}

.rtl #epanel .et-epanel-box .et-box-description {
	right: auto;
	left: 0;
}

#epanel .et-epanel-box .et-box-description:before {
	content: 't';
	font-family: 'ETmodules';
	font-size: 16px;
	color: rgb(43, 135, 218);
}

#epanel .et-epanel-box:hover .et-box-description {
	opacity: 1;
}

#epanel .et-epanel-box div.et-box-title h3 {
	word-wrap: break-word;
	display: block;
	font-weight: 600;
	font-size: 14px;
	color: #32373c;
}

#epanel-content .et-epanel-box .et-box-title {
	width: 30%;
	display: inline-block;
	vertical-align: top;
	box-sizing: border-box;
}

#epanel-content .et-epanel-box .et-box-content {
	display: inline-block;
	width: 65%;
	vertical-align: top;
	padding: 0 0 0 30px;
	box-sizing: border-box;
}

#epanel-content .et-epanel-box-small-1:not(.et-hidden-option) .et-box-content,
#epanel-content .et-epanel-box-small-2:not(.et-hidden-option) .et-box-content {
	width: 200px;
}

#epanel-content .et-box-content--list {
	display: grid;
	grid-template-columns: repeat(auto-fill, minmax(200px, 1fr));
	grid-gap: 10px;
}

#epanel-content .et-box-content .et-box-content--list > * {
	padding-left: 0;
	margin: 0;
}

#epanel-content .et-panel-box__checkbox-list-label {
	display: block;
	margin-bottom: 5px;
	font-weight: bold;
}

#epanel-content .et-epanel-box .et-box-content input,
#epanel-content .et-epanel-box .et-box-content .et-upload-buttons {
	vertical-align: top;
	float: left;
}

.rtl #epanel-content .et-epanel-box .et-box-content input,
.rtl #epanel-content .et-epanel-box .et-box-content .et-upload-buttons{
	float: right;
}

.et-epanel-box select,
.et-epanel-box input[type="text"],
.et-epanel-box input[type="password"],
.et-epanel-box textarea {
	margin-left: 0;
	border-radius: 3px;
	border: none;
	box-shadow: none;
	background: #F1F5F9;
	padding: 13px;
	font-size: 13px;
	color: #4c5866;
	height: auto;
	width: auto;
	font-family: 'Open Sans', sans-serif;
	width: 100%;
	margin-bottom: 0;
	-webkit-transition: background .5s;
	-moz-transition: background .5s;
	transition: background .5s;
	font-weight: 600;
}

/* Firefox fix */
.et-epanel-box select {
	padding: 5px 13px;
}

.et-epanel-box input[type="text"]:focus,
.et-epanel-box input[type="password"]:focus,
.et-epanel-box textarea:focus {
	background: #e6ecf2;
}

.et-epanel-box select,
.et-epanel-box input[type="text"],
.et-epanel-box input[type="password"] {
	height: 30px;
}

.et-epanel-box select {
	width: 55%;
}

/**
 * Yes / No toggle styling
 */
input.et-checkbox.yes_no_button {
	display: none;
}

#epanel .et_pb_yes_no_button {
	width: 100%;
	display: inline-block;
	position: relative;
	cursor: pointer;
	-moz-transition: all 0.3s;
	-webkit-transition: all 0.3s;
	transition: all 0.3s;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	font-size: 12px;
}

#epanel .et_pb_yes_no_button.et_pb_off_state {
	background-color: #F1F5F9;
}

#epanel .et_pb_yes_no_button.et_pb_on_state {
	background-color: #008BDB;
}

#epanel .et_pb_yes_no_button span.et_pb_button_slider {
	position: absolute;
	background: #FFF;
	width: 50%;
	height: 20px;
	margin: 5px 0;
	background: #FFF;
	-webkit-box-shadow: 0px 2px 5px 0px rgba(0, 0, 0, 0.25);
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	-webkit-box-shadow: 0px 1px 3px 0px rgba(0, 0, 0, 0.1);
	-moz-box-shadow: 0px 1px 3px 0px rgba(0, 0, 0, 0.1);
	box-shadow: 0px 1px 3px 0px rgba(0, 0, 0, 0.1);
	-moz-transition: all 0.3s;
	-webkit-transition: all 0.3s;
	transition: all 0.3s;
}

#epanel .et_pb_yes_no_button.et_pb_off_state span.et_pb_button_slider {
	left: 5px;
}

.rtl #epanel .et_pb_yes_no_button.et_pb_off_state span.et_pb_button_slider {
	left: 50%;
	margin-left: -5px;
}

#epanel .et_pb_yes_no_button.et_pb_on_state span.et_pb_button_slider {
	left: 50%;
	margin-left: -5px;
}

.rtl #epanel .et_pb_yes_no_button.et_pb_on_state span.et_pb_button_slider {
	left: 5px;
	margin-left: 0;
}

#epanel .et_pb_yes_no_button.et_pb_on_state span.et_pb_value_text.et_pb_on_value {
	margin-left: 0;
	margin-right: 0;
}

#epanel .et_pb_yes_no_button.et_pb_off_state span.et_pb_value_text.et_pb_off_value {
	margin-right: 0;
	margin-left: 0;
}

#epanel .et_pb_yes_no_button span.et_pb_value_text {
	padding: 6px;
	float: left;
	width: 50%;
	text-align: center;
	font-weight: 700;
	text-transform: uppercase;
	-moz-transition: all 0.3s;
	-webkit-transition: all 0.3s;
	transition: all 0.3s;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
}

.rtl #epanel .et_pb_yes_no_button span.et_pb_value_text {
	float: right;
}

#epanel span.et_pb_value_text.et_pb_off_value {
	color: #8E969E;
}

#epanel span.et_pb_value_text.et_pb_on_value {
	color: #FFF;
}

#epanel .et_pb_yes_no_button_wrapper select {
	opacity: 0;
	position: absolute;
	z-index: -1;
	width: 0px !important;
	height: 0px !important;
}

#epanel .et-pb-options-tab-advanced .et_pb_yes_no_button_wrapper {
	width: 200px;
	position: relative;
}

#epanel .et-pb-options-tab-advanced .et_pb_yes_no_button {
	float: left;
}

#epanel .et_pb_button_equal_sides .et_pb_yes_no_button.et_pb_on_state {
	background-color: #F1F5F9;
}

#epanel .et_pb_button_equal_sides span.et_pb_value_text.et_pb_on_value {
	color: #8E969E;
}

#epanel .et-hidden-option .et_pb_yes_no_button {
	display: none;
}

/**
 * Save Buttons Wrapper
 */
#epanel-top {
	padding-bottom: 30px;
}

#epanel-bottom {
	padding-top: 30px;
}

.et-save-button {
	-webkit-transition: background .5s;
    -moz-transition: background .5s;
    transition: background .5s;
    color: #FFF;
    cursor: pointer;
    background-color: #00C3AA;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    border: none;
    padding: 0 20px;
    font-size: 14px;
    font-weight: 600;
    height: 40px;
    line-height: 40px;
    display: inline-block;
    text-decoration: none;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
    position: relative;
}

.rtl .et-save-button {
	padding-right: 58px;
	padding-left: 20px;

}

.et-save-button:hover {
	background-color: #00BBA3;
}

/* Reset Popup */
.reset-popup-overlay, #custom-lbox {
	position: fixed; top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	background: rgb(255,255,255,0.7);
	background: -moz-radial-gradient(center, ellipse cover, rgba(255,255,255,1) 20%, rgba(255,255,255,0.7) 100%);
	background: -webkit-radial-gradient(center, ellipse cover, rgba(255,255,255,1) 20%,rgba(255,255,255,0.7) 100%);
	background: radial-gradient(ellipse at center, rgba(255,255,255,1) 20%,rgba(255,255,255,0.7) 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#ffffff', endColorstr='#ffffff',GradientType=1 );
	z-index: 9999;
	-webkit-animation: et_pb_fade_in_small .5s 1 cubic-bezier(0.77,0,.175,1);
	animation: et_pb_fade_in_small .5s 1 cubic-bezier(0.77,0,.175,1);
}

.reset-popup-overlay {
	display: none;
}

.reset-popup-overlay.active, #custom-lbox {
	display: block;
	animation: fadeIn 0.5s cubic-bezier(0.77, 0, 0.175, 1) 1;
}

.reset-popup-header {
	font-weight: 600;
	font-size: 18px;
	color: rgb(255, 255, 255);
	background-color: #6c2eb9;
	margin: 0px;
	padding: 19px 26px 18px;
	box-sizing: border-box;
	display: block;
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
}

.defaults-hover, .et-box-desc {
	display: none;
	z-index: 10000;
	overflow: auto;
	min-height: 213px;
	position: fixed;
	left: 50%;
	width: 400px;
	background: rgb(255, 255, 255);
	margin-left: -200px;
	box-sizing: border-box;
	box-shadow: rgba(0, 0, 0, 0.4) 0px 0px 100px;
	padding: 86px 30px 70px;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box; box-sizing: border-box;
	-moz-box-shadow: 0px 0px 100px rgba(0, 160, 210, 0.20);
	-webkit-box-shadow: 0px 0px 100px rgba(0, 160, 210, 0.20);
	box-shadow: 0px 0px 100px rgba(0, 160, 210, 0.20);
	border-radius: 3px; -moz-border-radius: 3px;
	-webkit-border-radius: 3px;
	overflow: hidden;
	font-weight: 600;
    color: #4c5866;
    line-height: 1.5em;
    font-size: 13px;
}

.et-box-desc {
	padding-bottom: 30px;
}

.defaults-hover.active {
	display: block;
	-webkit-animation: et_pb_fade_in_scale .5s 1 cubic-bezier(0.77,0,.175,1);
	animation: et_pb_fade_in_scale .5s 1 cubic-bezier(0.77,0,.175,1);
}

.et_pb_modal_closing .defaults-hover {
	opacity: 0;
	-webkit-animation: et_pb_fade_out_scale .5s 1 cubic-bezier(0.77,0,.175,1);
	animation: et_pb_fade_out_scale .5s 1 cubic-bezier(0.77,0,.175,1);
}
.et_pb_modal_closing {
	opacity: 0;
	-moz-transition: opacity .5s .2s;
	-webkit-transition: opacity .5s .2s;
	transition: opacity .5s .2s;
}

.no,
#epanel-reset {
	position: absolute;
	bottom: 0;
	display: block;
	color: white;
	font-size: 14px;
	height: 40px;
	width: 50%;
	border: none;
	font-family: 'Open Sans', sans-serif;
	font-weight: 700;
	box-sizing: border-box;
	text-align: center;
	line-height: 40px;
	margin: 0;
	cursor: pointer;
	transition: background .5s;
	padding: 0;
}

.no {
	left: 0;
	background: #008BDA;
}

.rtl .no {
	left: auto;
	right: 0;
}

.no:hover {
	background: #007cc3;
}

#epanel-reset {
	right: 0;
	background: #00c3aa;
}

.rtl #epanel-reset {
	right: auto;
	left: 0;
}

#epanel-reset:hover {
	background: #00BBA3;
}

/* Help Popup */

.et-box-desc {
	display: block;
	-webkit-animation: et_pb_fade_in_scale .5s 1 cubic-bezier(0.77,0,.175,1);
	animation: et_pb_fade_in_scale .5s 1 cubic-bezier(0.77,0,.175,1);
}

.et_pb_modal_closing .et-box-desc {
	opacity: 0;
	-webkit-animation: et_pb_fade_out_scale .5s 1 cubic-bezier(0.77,0,.175,1);
	animation: et_pb_fade_out_scale .5s 1 cubic-bezier(0.77,0,.175,1);
}

.et-box-desc-top {
	font-weight: 600;
	font-size: 18px;
	color: rgb(255, 255, 255);
	background-color: #6c2eb9;
	margin: 0px;
	padding: 20px 26px 19px;
	box-sizing: border-box;
	display: block;
	width: 100%;
	box-sizing: border-box;
	top: 0;
	left: 0;
	right: 0;
	position: absolute;
}

.et-box-desc-content {
	display: block;
	position: relative;
	font-weight: 600;
    color: #4c5866;
}

.et-box-desc-content h3 {
	font-size: 15px;
	line-height: 25px;
	margin: 0px 0px 15px;
	width: 320px;
	color: #32373c;
	font-weight: 600;
}

.et-box-desc-content p {
	margin: 0px;
	font-size: 14px;
}

.et-box-desc-content .et-lightbox-close {
	position: absolute;
    top: -86px;
    right: -30px;
    background: none;
    text-align: center;
    width: 58px;
    height: 58px;
    box-sizing: border-box;
    font-size: 23px;
    color: #fff;
    cursor: pointer;
}

.rtl .et-box-desc-content .et-lightbox-close {
	right: auto;
	left: -40px;
}

.et-box-desc-content .et-lightbox-close:before {
	content: 'M';
	font: 23px 'ETmodules';
	line-height: 58px;
	font-weight: 600;
}

.ui-tabs-hide,
.et-box-descr {
	display: none;
}

.et-box-description,
.et-lightbox-close {
	cursor: pointer;
}

/**
 * Upload fields
 */
#epanel-content .et-epanel-box .et-upload-field {
	margin: 0 5% 0 0;
	width: 47.5%;
	display: inline-block;
}

.rtl #epanel-content .et-epanel-box .et-upload-field {
	margin-right: 0;
	margin-left: 5%;
}

#epanel-content .et-epanel-box .et-upload-image-button,
#epanel-content .et-epanel-box .et-upload-image-reset,
#epanel-content .et-epanel-box .et-button {
	float: left;
	box-sizing: border-box;
	color: #FFF;
	background-color: #4c5866;
	padding: 0 20px;
	margin: 0 0 0 7px;
	font-size: 12px;
	line-height: 30px;
	text-transform: uppercase;
	font-weight: 700;
	height: 30px;
	cursor: pointer;
	overflow: hidden;
	position: relative;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	border: none;
	text-align: center;
	text-shadow: none;
	-webkit-transition: background .5s;
	-moz-transition: background .5s;
	transition: background .5s;
}

#epanel-content .et-epanel-box .et-button--simple:first-child {
	margin-left: 0;
}

.rtl #epanel-content .et-panel-box .et-upload-image-button,
.rtl #epanel-content .et-epanel-box .et-upload-image-reset,
.rtl #epanel-content .et-epanel-box .et-button {
	float: right;
	margin-left: 0;
	margin-right: 5%;
}

#epanel-content .et-epanel-box .et-upload-image-button:focus,
#epanel-content .et-epanel-box .et-upload-image-reset:focus,
#epanel-content .et-epanel-box .et-button:focus,
#epanel-content .et-epanel-box .et-upload-image-button:hover,
#epanel-content .et-epanel-box .et-upload-image-reset:hover,
#epanel-content .et-epanel-box .et-button:hover {
	background: #343c46;
}

#epanel-content .et-epanel-box .et-upload-buttons {
	width: 47.5%;
	display: inline-block;
}

#epanel-content .et-epanel-box .et-upload-image-button {
	display: inline-block;
	width: 47.5%;
	margin: 0 0 0 5%;
	padding: 0;
}

.rtl #epanel-content .et-epanel-box .et-upload-image-button {
	margin: 0 5% 0 0;
}

#epanel-content .et-epanel-box .et-upload-image-reset {
	display: inline-block;
	width: 47.5%;
	margin: 0;
}

.rtl #epanel-content .et-epanel-box .et-upload-image-reset {
	margin: 0;
}

#epanel-content .et-epanel-box .et_make_connection {
	margin-left: 0;
	width: 195px;
}

.rtl #epanel-content .et-epanel-box .et_make_connection {
	margin-right: 0;
}

/**
 * Navigation's Item Selector
 * Powered by jQuery's checkbox
 */
#epanel p.inputs {
	display: inline-block;
	width: 32%;
	clear: both;
	min-height: 14px;
	box-sizing: border-box;
	padding: 10px 10px 10px 40px;
	vertical-align: top;
	position: relative;
}

.rtl #epanel p.inputs {
	padding-right: 40px;
	padding-left: 10px;
}

#epanel p.inputs label {
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
	font-weight: 600;
	color: #4c5866;
}

#epanel p.inputs .jquery-checkbox img {
	display: none;
}

#epanel p.inputs .jquery-checkbox .mark {
	display: block;
	width: 16px;
	height: 16px;
	color: #00C3AA;
}


#epanel p.inputs .jquery-checkbox .mark:before, #epanel p.inputs.different .jquery-checkbox-checked .mark:before {
	font: 20px 'ETmodules';
	content: 'N';
}

#epanel p.inputs:not(.different) .jquery-checkbox-checked .mark:before, #epanel p.inputs.different .jquery-checkbox:not(.jquery-checkbox-checked) .mark:before {
	content: 'M';
	color: #FF5600;
	font-size: 23px;
	font-weight: 600;
}

#epanel p.inputs  span.jquery-checkbox {
	position: absolute;
	top: 10px;
	left: 10px;
	cursor: pointer;
}

.rtl #epanel p.inputs  span.jquery-checkbox {
	left: auto;
	right: 10px;
}

/**
 * Layout's Postinfo Selector
 */
#epanel p.postinfo {
	float: left;
	margin-right: 25px;
	text-transform: capitalize;
	margin-top: 10px;
	cursor: pointer;
	font-weight: 600;
	color: #4c5866;
}

.rtl #epanel p.postinfo {
	float: right;
}

#epanel p.postinfo .mark:before {
	font: 16px 'etbuilder';
	width: 16px;
	height: 16px;
	display: inline-block;
	margin-right: 7px;
	vertical-align: middle;
	color: #008BDB;
	transition: all 0.3s;
}

.rtl #epanel p.postinfo .mark:before {
	margin-right: 0;
	margin-left: 7px;
}

#epanel p.postinfo .mark:after {
	vertical-align: middle;
	transition: all 0.3s;
}

#epanel p.postinfo .jquery-checkbox .mark:before,
#epanel p.postinfo .jquery-checkbox .mark:after {
	color: #666;
	opacity: .3;
}

#epanel p.postinfo .jquery-checkbox-checked .mark:before,
#epanel p.postinfo .jquery-checkbox-checked .mark:after {
	opacity: 1;
}

#epanel p.postinfo .jquery-checkbox-checked .mark:before {
	color: #008BDB;
}

#epanel p.postinfo img {
	display: none;
}

#epanel p.postinfo-author .mark:before {
	content: 'G';
}

#epanel p.postinfo-author img {
	vertical-align: middle;
	width: 63px;
	height: 19px;
	background: transparent url(../images/epanel/postinfo-author.gif) no-repeat;
	margin-right: 5px;
	margin-top: -1px;
	margin-left: 0px !important;
}

#epanel p.postinfo-date .mark:before {
	content: 'I';
}

#epanel p.postinfo-categories img {
	vertical-align: middle;
	width: 91px;
	height: 19px;
	background: transparent url(../images/epanel/postinfo-categories.gif) no-repeat;
	margin-right: 5px;
	margin-left: 0px !important;
}

#epanel p.postinfo-categories .mark:before {
	content: '2';
}

#epanel p.postinfo-date img {
	vertical-align: middle;
	width: 55px;
	height: 19px;
	background: transparent url(../images/epanel/postinfo-date.gif) no-repeat;
	margin-right: 5px;
	margin-left: 0px !important;
}

#epanel p.postinfo-comments .mark:before {
	content: '4';
}

#epanel p.postinfo-rating_stars img {
	vertical-align: middle;
	width: 91px;
	height: 19px;
	margin-right: 5px;
	margin-left: 0px !important;
}

#epanel p.postinfo-rating_stars .mark:before {
	content: "\E033";
	font: 16px 'ETModules';
}

/**
 * Colorpicker
 */
.colorpicker {
	width: 356px;
	height: 176px;
	overflow: hidden;
	position: absolute;
	background: url(../images/epanel/custom_background.png);
	font-family: Arial, Helvetica, sans-serif;
	display: none;
}

.colorpicker_color {
	width: 150px;
	height: 150px;
	left: 14px;
	top: 13px;
	position: absolute;
	background: #f00;
	overflow: hidden;
	cursor: crosshair;
}

.colorpicker_color div {
	position: absolute;
	top: 0;
	left: 0;
	width: 150px;
	height: 150px;
	background: url(../images/epanel/colorpicker_overlay.png);
}

.colorpicker_color div div {
	position: absolute;
	top: 0;
	left: 0;
	width: 11px;
	height: 11px;
	overflow: hidden;
	background: url(../images/epanel/colorpicker_select.gif);
	margin: -5px 0 0 -5px;
}

.colorpicker_hue {
	position: absolute;
	top: 13px;
	left: 171px;
	width: 35px;
	height: 150px;
	cursor: n-resize;
}

.colorpicker_hue div {
	position: absolute;
	width: 35px;
	height: 9px;
	overflow: hidden;
	background: url(../images/epanel/custom_indic.gif) left top;
	margin: -4px 0 0 0;
left: 0px;
}

.colorpicker_new_color {
	position: absolute;
	width: 60px;
	height: 30px;
	left: 213px;
	top: 13px;
	background: #f00;
}

.colorpicker_current_color {
	position: absolute;
	width: 60px;
	height: 30px;
	left: 283px;
	top: 13px;
	background: #f00;
}

#epanel .colorpicker input,
.colorpicker input {
	background-color: transparent !important;
	border: 1px solid transparent !important;
	position: absolute !important;
	font-size: 10px !important;
	font-family: Arial, Helvetica, sans-serif !important;
	color: #898989 !important;
	top: 4px !important;
	right: 11px !important;
	text-align: right !important;
	margin: 0 !important;
	padding: 0 !important;
	height: 12px !important;
	background-image: none !important;
	width: 35px;
}

.colorpicker_hex {
	position: absolute;
	width: 72px;
	height: 22px;
	background: url(../images/epanel/custom_hex.png) top;
	left: 212px;
	top: 142px;
}

#epanel .colorpicker_hex input,
.colorpicker_hex input {
	width: 39px;
}

.colorpicker_field {
	height: 22px;
	width: 62px;
	background-position: top;
	position: absolute;
}

.colorpicker_field span {
	position: absolute;
	width: 12px;
	height: 22px;
	overflow: hidden;
	top: 0;
	right: 0;
	cursor: n-resize;
}

.colorpicker_rgb_r {
	background-image: url(../images/epanel/custom_rgb_r.png);
	top: 52px;
	left: 212px;
}

.colorpicker_rgb_g {
	background-image: url(../images/epanel/custom_rgb_g.png);
	top: 82px;
	left: 212px;
}

.colorpicker_rgb_b {
	background-image: url(../images/epanel/custom_rgb_b.png);
	top: 112px;
	left: 212px;
}

.colorpicker_hsb_h {
	background-image: url(../images/epanel/custom_hsb_h.png);
	top: 52px;
	left: 282px;
}

.colorpicker_hsb_s {
	background-image: url(../images/epanel/custom_hsb_s.png);
	top: 82px;
	left: 282px;
}

.colorpicker_hsb_b {
	background-image: url(../images/epanel/custom_hsb_b.png);
	top: 112px;
	left: 282px;
}

.colorpicker_submit {
	position: absolute;
	width: 22px;
	height: 22px;
	background: url(../images/epanel/custom_submit.png) top;
	left: 322px;
	top: 142px;
	overflow: hidden;
}

.colorpicker_focus {
	background-position: center;
}

.colorpicker_hex.colorpicker_focus {
	background-position: bottom;
}

.colorpicker_submit.colorpicker_focus {
	background-position: bottom;
}

.colorpicker_slider {
	background-position: bottom;
}

.colorpalette-colorpicker span.wp-picker-input-wrap {
    display: block !important;
    position: absolute;
    top: 40px;
}

.colorpalette-colorpicker button.button.button-confirm {
    display: none;
}

.colorpalette-colorpicker .wp-picker-holder { 
	margin-top: 50px; 
}

.navigationTabs { height: 23px; line-height: 23px; border-bottom: 1px solid #ccc; }
.navigationTabs li { float: left; height: 23px; line-height: 23px; padding-right: 3px; }
.navigationTabs li a{ float: left; display: block; height: 23px; line-height: 23px; padding: 0 10px; overflow: hidden;	color: #52697E;	background-color: #eee;	position: relative;	text-decoration: none; }
.navigationTabs li a:hover { background-color: #f0f0f0; }
.navigationTabs li a.active { background-color: #fff; border: 1px solid #ccc; border-bottom: 0px solid; }
.tabsContent { border: 1px solid #ccc; border-top: 0px solid; width: 698px; overflow: hidden; }
.tab { padding: 16px; display: none; }
.tab h2 { font-weight: 600; font-size: 16px; }
.tab h3 {	font-weight: 600; font-size: 14px; margin-top: 20px; }
.tab p { margin-top: 16px; clear: both; }
.tab ul { margin-top: 16px; list-style: disc; }
.tab li { margin: 10px 0 0 35px; }
.tab a { color: #8FB0CF; }
.tab strong { font-weight: 600; }
.tab pre { font-size: 11px; margin-top: 20px; width: 668px; overflow: auto; clear: both; }
.tab table { width: 100%; }
.tab table td { padding: 6px 10px 6px 0; vertical-align: top; }
.tab dt {	margin-top: 16px; }

#colorSelector {	position: relative;	width: 36px; height: 36px; background: url(../images/epanel/select.png); }
#colorSelector div { position: absolute; top: 3px; left: 3px; width: 30px; height: 30px; background: url(../images/epanel/select.png) center; }
#colorSelector2 { position: absolute; top: 0; left: 0; width: 36px; height: 36px; background: url(../images/epanel/select2.png); }
#colorSelector2 div { position: absolute; top: 4px; left: 4px; width: 28px; height: 28px; background: url(../images/epanel/select2.png) center; }
#colorpickerHolder2 { top: 32px; left: 0; width: 356px; height: 0; overflow: hidden;	position: absolute; }
#colorpickerHolder2 .colorpicker { background-image: url(../images/epanel/custom_background.png); position: absolute; bottom: 0; left: 0; }
#colorpickerHolder2 .colorpicker_hue div {	background-image: url(../images/epanel/custom_indic.gif); }
#colorpickerHolder2 .colorpicker_hex { background-image: url(../images/epanel/custom_hex.png); }
#colorpickerHolder2 .colorpicker_rgb_r {	background-image: url(../images/epanel/custom_rgb_r.png); }
#colorpickerHolder2 .colorpicker_rgb_g { background-image: url(../images/epanel/custom_rgb_g.png); }
#colorpickerHolder2 .colorpicker_rgb_b {	background-image: url(../images/epanel/custom_rgb_b.png); }
#colorpickerHolder2 .colorpicker_hsb_s {	background-image: url(../images/epanel/custom_hsb_s.png); display: none; }
#colorpickerHolder2 .colorpicker_hsb_h {	background-image: url(../images/epanel/custom_hsb_h.png); display: none; }
#colorpickerHolder2 .colorpicker_hsb_b { background-image: url(../images/epanel/custom_hsb_b.png); display: none; }
#colorpickerHolder2 .colorpicker_submit { background-image: url(../images/epanel/custom_submit.png); }
#colorpickerHolder2 .colorpicker input { color: #778398; }

/* wp color picker option */
.et-box-content .et_pb_colorpalette_overview { display: block; margin-bottom: 10px; }

.et-box-content .colorpalette-item {
	display: inline-block;
	content: '';
	-moz-border-radius: 100%;
	-webkit-border-radius: 100%;
	border-radius: 100%;
	cursor: pointer;
	position: relative;
	width: 26px;
	height: 26px;
	margin-right: 5px;
	vertical-align: middle;
	background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAAHnlligAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAHJJREFUeNpi+P///4EDBxiAGMgCCCAGFB5AADGCRBgYDh48CCRZIJS9vT2QBAggFBkmBiSAogxFBiCAoHogAKIKAlBUYTELAiAmEtABEECk20G6BOmuIl0CIMBQ/IEMkO0myiSSraaaBhZcbkUOs0HuBwDplz5uFJ3Z4gAAAABJRU5ErkJggg==");
	background-size: 40%;
}
.et-box-content .colorpalette-item .color {
	position: absolute;
	-moz-border-radius: 100%;
	-webkit-border-radius: 100%;
	border-radius: 100%;
	-moz-box-shadow: inset 0 0 5px 0 rgba(0, 0, 0, 0.2);
	-webkit-box-shadow: inset 0 0 5px 0 rgba(0, 0, 0, 0.2);
	box-shadow: inset 0 0 5px 0 rgba(0, 0, 0, 0.2);
	left: 0;
	top: 0;
	width: 100%;
	height: 100%;
	transition: background-color 200ms ease;
}
.et-box-content .wp-color-result { display: none; }
.et-box-content .iris-picker { display: block !important; }
.et-box-content .colorpalette-item:last-child { margin-right: 0; }
.et-box-content .colorpalette-colorpicker { display: none; }
.et-box-content .colorpalette-colorpicker.active { display: block; }
.et-box-content .wp-picker-holder { margin-top: 50px; }
.et-box-content input.input-colorpalette-colorpicker.wp-color-picker { display: block !important; width: 316px !important; }

.et-clearfix { clear: both; }

/* Portability Integration */
#epanel-header .epanel-portability {
	right: 50px;
}

.rtl #epanel-header .epanel-portability {
	right: auto;
	left: 50px;
}

/* Clear Static CSS Button */
#epanel-content .et-epanel-box .et-box-content ~ .et_pb_clear_static_css {
	display: inline-block;
	float: initial;
	width: 222px;
	margin-left: 50px;
	opacity: 0;
	transition: opacity 0.3s linear;
}

#epanel-content .et-epanel-box .et-box-content.et_pb_on_state ~ .et_pb_clear_static_css {
	opacity: 1;
}

/**
 * Saving Animation
 */
#et-ajax-saving {
	display: none;
	transition: background, box-shadow 0.3s;
	box-shadow: rgba(0, 139, 219, 0.247059) 0px 0px 60px;
	position: fixed;
	top: 50%;
	left: 50%;
	width: 50px;
	height: 50px;
	background: rgb(255, 255, 255);
	border-radius: 50px;
	margin: -25px 0 0 -25px;
	z-index: 999999;
	text-align: center;
}

#et-ajax-saving img {
	margin: 9px;
}

#et-ajax-saving.success-animation {
	background-color: rgb(169, 233, 0);
	box-shadow: rgba(0, 0, 0, 0) 0px 0px 40px;
	opacity: 1;
	animation: bounceIn 1s;
}

#et-ajax-saving.success-animation:before {
	background: none;
	font-family: 'etbuilder';
	speak: none;
	font-weight: normal;
	font-variant: normal;
	text-transform: none;
	line-height: 1;
	-webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
	content: "N";
	color: rgb(255, 255, 255);
	font-size: 22px;
	line-height: 50px;
}

#et-ajax-saving.et_loading:before {
	display: none;
}

#et-ajax-saving.success-animation img {
	display: none;
}

/**
* Animation
*/
@-webkit-keyframes fadeIn {
	0% {
		opacity: 0;
	}

	100% {
		opacity: 1;
	}
}

@-moz-keyframes fadeIn {
	0% {
		opacity: 0;
	}

	100% {
		opacity: 1;
	}
}

@-o-keyframes fadeIn {
	0% {
		opacity: 0;
	}

	100% {
		opacity: 1;
	}
}

@keyframes fadeIn {
	0% {
		opacity: 0;
	}

	100% {
		opacity: 1;
	}
}

/*!
Animate.css - http://daneden.me/animate
Licensed under the MIT license - http://opensource.org/licenses/MIT

Copyright (c) 2015 Daniel Eden
*/

@keyframes bounceIn {
	0%, 20%, 40%, 60%, 80%, 100% {
		-webkit-transition-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
		transition-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
	}
	0% {
		opacity: 0; -webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3);
	}
	20% {
		-webkit-transform: scale3d(1.1, 1.1, 1.1);
		transform: scale3d(1.1, 1.1, 1.1);
	}
	40% {
		-webkit-transform: scale3d(.9, .9, .9);
		transform: scale3d(.9, .9, .9);
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(1.03, 1.03, 1.03);
		transform: scale3d(1.03, 1.03, 1.03);
	}
	80% {
		-webkit-transform: scale3d(.97, .97, .97);
		transform: scale3d(.97, .97, .97);
	}
	100% {
		opacity: 1;
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1);
	}
}

@-webkit-keyframes bounceIn {
	0%, 20%, 40%, 60%, 80%, 100% {
		-webkit-transition-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
		transition-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
	}
	0% {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3);
	}
	20% {
		-webkit-transform: scale3d(1.1, 1.1, 1.1);
		transform: scale3d(1.1, 1.1, 1.1);
	}
	40% {
		-webkit-transform: scale3d(.9, .9, .9);
		transform: scale3d(.9, .9, .9);
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(1.03, 1.03, 1.03);
		transform: scale3d(1.03, 1.03, 1.03);
	}
	80% {
		-webkit-transform: scale3d(.97, .97, .97);
		transform: scale3d(.97, .97, .97);
	}
	100% {
		opacity: 1; -webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1);
	}
}

  /* End Animate.css */

@-webkit-keyframes et_pb_fade_in_scale { 0% { opacity: 0; transform: scale(.9,.9); } 100% { opacity: 1; transform: scale(1,1); } }
@-moz-keyframes et_pb_fade_in_scale { 0% { opacity: 0; transform: scale(.9,.9) } 100% { opacity: 1; transform: scale(1,1); } }
@-o-keyframes et_pb_fade_in_scale { 0% { opacity: 0; transform: scale(.9,.9) } 100% { opacity: 1; transform: scale(1,1); } }
@keyframes et_pb_fade_in_scale { 0% { opacity: 0; transform: scale(.9,.9); } 100% { opacity: 1; transform: scale(1,1); } }

@-webkit-keyframes et_pb_fade_out_scale { 0% { opacity: 1; transform: scale(1,1); } 100% { opacity: 0; transform: scale(.9,.9); } }
@-moz-keyframes et_pb_fade_out_scale { 0% { opacity: 1; transform: scale(1,1); } 100% { opacity: 0; transform: scale(.9,.9); } }
@-o-keyframes et_pb_fade_out_scale { 0% { opacity: 1; transform: scale(1,1); } 100% { opacity: 0; transform: scale(.9,.9); } }
@keyframes et_pb_fade_out_scale { 0% { opacity: 1; transform: scale(1,1); } 100% { opacity: 0; transform: scale(.9,.9); } }

/* Responsive */
@media only screen and ( max-width: 1161px ) {

	#epanel-content .et-epanel-box .et-upload-image-button,
	#epanel-content .et-epanel-box .et-upload-image-reset {
		padding-right: 15px;
		padding-left: 15px;
	}

	#epanel-content .et-epanel-box .et-upload-image-button {
		margin-right: 0;
	}
}

@media only screen and ( max-width: 1024px ) {
	#epanel .et-epanel-box .et-box-description {
		opacity: .2;
		right: -15px;
	}

}

@media only screen and ( max-width: 1017px ) {
	#epanel-mainmenu a,
	#epanel-content ul.et-id-tabs a {
		padding: 20px 15px;
	}

	#epanel-mainmenu li:first-of-type a,
	#epanel-content ul.et-id-tabs li:first-of-type a {
		padding-left: 30px;
	}
}

@media only screen and ( max-width: 782px ) {
	#wrapper {
		margin-right: 25px;
		margin-left: 15px;
	}

	#epanel-content .et-epanel-box .et-upload-image-button,
	#epanel-content .et-epanel-box .et-upload-image-reset {
		font-size: 13px;
	}

	#epanel-content .et-epanel-box .et-upload-field,
	#epanel-content .et-epanel-box .et-upload-buttons {
		width: 100%;
	}

	#epanel-content .et-epanel-box .et-upload-field {
		margin-bottom: 15px;
	}

}

@media only screen and ( max-width: 480px ) {
	h1#epanel-title {
		padding-left: 30px;
	}

	#epanel-title:before {
		left: -10px;
	}

	#epanel-mainmenu li:first-of-type a,
	#epanel-content ul.et-id-tabs li:first-of-type a {
		padding: 20px;
	}

	#epanel-mainmenu li {
		display: block;
		float: none;
	}

	#epanel-content .et-tab-content {
		padding: 30px 20px 20px;
	}

	#epanel-content .et-epanel-box .et-box-title {
		width: 90%;
	}

	#epanel-content .et-epanel-box .et-box-content {
		width: 90%;
		padding: 0;
	}

	#epanel-content .et-epanel-box-small-1 .et-box-content,
	#epanel-content .et-epanel-box-small-2 .et-box-content {
		max-width: 90%;
		width: 90%;
	}

	.et-epanel-box select {
		max-width: 100%;
		width: 100%;
	}

	#epanel .et-epanel-box .et-box-description {
		right: 0;
		top: 49px;
	}
}

#epanel .CodeMirror {
	padding: 13px 13px 13px 0px;
	border-radius: 3px;
}

#epanel .CodeMirror-dialog-top {
  background: #F1F5F9;
  border-bottom: none;
  box-shadow: 0 0 50px rgba(0,0,0,.5);
  height: 30px;
}

#epanel .CodeMirror-search-label {
  color: rgb(190, 201, 214);
  font-size: 0.875rem;
  height: 30px;
  line-height: 30px;
}

#epanel .CodeMirror-search-field {
  color: #4C5866 !important;
  font-size: 0.8rem !important;
  height: 30px;
  float: none !important;
  background: none;
}

#epanel .CodeMirror-search-hint {
  display: none;
}

.CodeMirror.cm-s-et {
	/*
		Based on CodeMirror Material Theme

		MIT License
		Copyright (C) 2017 by Marijn Haverbeke <marijnh@gmail.com> and others
   */
	background-color: #4C5866;
	color: #ffffff;
}
.CodeMirror.cm-s-et .CodeMirror-gutters {
	background: #4C5866;
	color: #537f7e;
	border: none;
}
.CodeMirror.cm-s-et .CodeMirror-guttermarker, .CodeMirror.cm-s-et .CodeMirror-guttermarker-subtle, .CodeMirror.cm-s-et .CodeMirror-linenumber {
	color: #8393a5;
}
.CodeMirror.cm-s-et .CodeMirror-cursor {
	border-left: 1px solid #fff;
}
.CodeMirror.cm-s-et div.CodeMirror-selected {
	background: rgba(145, 203, 255, 0.2);
}
.CodeMirror.cm-s-et .cm-s-material.CodeMirror-focused div.CodeMirror-selected {
	background: rgba(0, 0, 0, 0.1);
}
.CodeMirror.cm-s-et .CodeMirror-line::selection, .CodeMirror.cm-s-et .CodeMirror-line > span::selection, .CodeMirror.cm-s-et .CodeMirror-line > span > span::selection {
	background: rgba(0, 0, 0, 0.1);
}
.CodeMirror.cm-s-et .CodeMirror-line::-moz-selection, .CodeMirror.cm-s-et .CodeMirror-line > span::-moz-selection, .CodeMirror.cm-s-et .CodeMirror-line > span > span::-moz-selection {
	background: rgba(0, 0, 0, 0.1);
}
.CodeMirror.cm-s-et .CodeMirror-activeline-background {
	background: rgba(0, 0, 0, 0.1);
}
.CodeMirror.cm-s-et .cm-keyword {
	color: #88c2f8;
}
.CodeMirror.cm-s-et .cm-operator {
	color: #ffffff;
}
.CodeMirror.cm-s-et .cm-variable-2,
.CodeMirror.cm-s-et .cm-string-2,
.CodeMirror.cm-s-et .cm-meta {
	color: #fff;
}
.CodeMirror.cm-s-et .cm-variable-3, .CodeMirror.cm-s-et .cm-type {
	color: #88c2f8;
}
.CodeMirror.cm-s-et .cm-builtin,
.CodeMirror.cm-s-et .cm-qualifier,
.CodeMirror.cm-s-et .cm-variable-3,
.CodeMirror.cm-s-et .cm-type {
	color: #fe9c47;
}
.CodeMirror.cm-s-et .cm-atom {
	color: #88c2f8;
}
.CodeMirror.cm-s-et .cm-number {
	color: #fe9c47;
}
.CodeMirror.cm-s-et .cm-def {
	color: #ffffff;
}
.CodeMirror.cm-s-et .cm-string {
	color: #fe9c47;
}
.CodeMirror.cm-s-et .cm-comment {
	color: #8393a5;
}
.CodeMirror.cm-s-et .cm-variable {
	color: #88c2f8;
}
.CodeMirror.cm-s-et .cm-attribute {
	color: #88c2f8;
}
.CodeMirror.cm-s-et .cm-property {
	color: #88dfbe;
}
.CodeMirror.cm-s-et .cm-tag {
	color: #88dfbe;
}
.CodeMirror.cm-s-et .cm-searching {
	background: none;
	border-bottom: 1px solid white;
	color: white;
}
.CodeMirror.cm-s-et .CodeMirror-matchingbracket {
	text-decoration: underline;
	color: white !important;
}
#epanel .CodeMirror .CodeMirror-matchingtag {
	background: rgba(255, 255, 255, 0.15);
}
#epanel .CodeMirror .CodeMirror-linewidget {
	width: 100% !important;
}
#epanel .CodeMirror .codemirror-lint-warning,
#epanel .CodeMirror .codemirror-lint-error {
	background-color: transparent;
	color: #ff5758;
	border: 2px solid #ff5758;
	border-radius: 3px;
	padding: 5px 10px;
	margin: 5px 0;
}
#epanel .CodeMirror .codemirror-lint-warning {
	color: #fe9c47;
	border-color: #fe9c47;
}
#epanel .CodeMirror .codemirror-colorview {
	border: 1px solid #fff;
	border-radius: 10px;
	margin: 0px 5px 0 0;
}
#epanel .CodeMirror .codemirror-colorview .codemirror-colorview-background {
	border-radius: 10px;
}

@media only screen and ( max-width: 415px ) {
	.defaults-hover {
		width: auto;
		left: 25px;
		right: 25px;
		margin-left: 0;
	}
}
