"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9564"],{77703:function(e){e.exports=JSON.parse('{"wPLoginAttempts":"Tentativas de autentica\xe7\xe3o no WordPress.","wPLoginAttemptsResetSuccess":"As tentativas de autentica\xe7\xe3o no WordPress foram repostas com sucesso.","errorTryAgain":"Ocorreu um erro. Por favor, tente novamente.","backupCreation":"Cria\xe7\xe3o de c\xf3pia de seguran\xe7a.","backupCreated":"A c\xf3pia de seguran\xe7a do s\xedtio foi criada com sucesso.","backupUpdate":"A c\xf3pia de seguran\xe7a do s\xedtio foi atualizada com sucesso.","backupUpdated":"A c\xf3pia de seguran\xe7a do s\xedtio foi atualizada com sucesso.","backupRestore":"Restaura\xe7\xe3o da c\xf3pia de seguran\xe7a.","backupDelete":"Elimina\xe7\xe3o da c\xf3pia de seguran\xe7a.","backupDeleted":"A c\xf3pia de seguran\xe7a foi eliminada.","backupExport":"Exporta\xe7\xe3o da c\xf3pia de seguran\xe7a.","backupExportSuccessToast":"Em breve receber\xe1 um correio eletr\xf3nico com a hiperliga\xe7\xe3o para descarregar.","debugMode":"Modo de depura\xe7\xe3o.","debugModeSwithFailed":"{value, select, true {A desativa\xe7\xe3o} other {A ativa\xe7\xe3o}} do modo de depura\xe7\xe3o falhou. Por favor, tente novamente.","siteDeletion":"Remo\xe7\xe3o do site.","siteDeleted":"O site foi removido.","setFavoriteSuccess":"{domain} foi adicionado aos seus s\xedtios favoritos.","removeFavoriteSuccess":"{domain} foi removido dos seus s\xedtios favoritos.","maxReachedFavorites":"Atingiste o n\xfamero m\xe1ximo de favoritos.","generalErrorToast":"Ups, isso n\xe3o funcionou. Tenta novamente mais tarde.","websiteDeactivation":"Desativa\xe7\xe3o do s\xedtio web.","setDefaultPaymentFailed":"N\xe3o foi poss\xedvel definir o m\xe9todo de pagamento predefinido.","actionFailedMessage":"Lamentamos, mas isso n\xe3o funcionou.","retryErrorMessage":"Lamentamos, mas isso n\xe3o funcionou. Por favor, tente novamente.","addingDomainFailed":"A adi\xe7\xe3o de um dom\xednio n\xe3o foi bem-sucedida. Por favor, tente novamente.","removingDomainFailed":"A remo\xe7\xe3o de um dom\xednio n\xe3o foi bem-sucedida. Por favor, tente novamente.","settingDomainPrimaryFailed":"A defini\xe7\xe3o do dom\xednio como principal n\xe3o foi bem-sucedida. Por favor, tente novamente.","emailVerification":"Verifica\xe7\xe3o do correio eletr\xf3nico.","emailAlreadyVerified":"O correio eletr\xf3nico j\xe1 se encontra verificado.","emailVerificationSent":"Enviado! Verifique a sua caixa de entrada para encontrar o correio eletr\xf3nico de verifica\xe7\xe3o.","emailVerificationResendDelay":"J\xe1 envi\xe1mos um correio eletr\xf3nico de verifica\xe7\xe3o para a sua caixa de entrada. Caso ainda n\xe3o o tenha localizado, poder\xe1 solicitar o reenvio dentro de 5 minutos.","teamMemberRemoved":"{email} foi removido da sua equipa.","inviteSentTo":"Foi enviado um convite para {email}.","billingInfoUpdated":"As suas informa\xe7\xf5es de fatura\xe7\xe3o foram atualizadas.","subCanceledConfirmation":"A sua subscri\xe7\xe3o foi cancelada e o seu reembolso est\xe1 a ser processado. Verifique o seu correio eletr\xf3nico para obter mais detalhes.","siteDomainRemoved":"O s\xedtio web {domain} foi removido.","siteLockPassReset":"Reposi\xe7\xe3o da palavra-passe do bloqueio do s\xedtio.","updatedSiteLockCode":"O seu novo c\xf3digo de bloqueio do s\xedtio \xe9: {pass}.","contactSupport":"Contactar o apoio t\xe9cnico.","srySomethingWrong":"Lamentamos, mas ocorreu um erro.","subRefundFailed":"A sua subscri\xe7\xe3o permanece ativa porque n\xe3o foi poss\xedvel processar o reembolso. Estamos \xe0 disposi\xe7\xe3o para o auxiliar.","partialRefundMessage":"O seu reembolso n\xe3o p\xf4de ser totalmente processado, mas a sua subscri\xe7\xe3o j\xe1 n\xe3o est\xe1 ativa. Estamos \xe0 disposi\xe7\xe3o para o auxiliar.","exitMaintenanceModeToastTitle":"Sair do modo de manuten\xe7\xe3o.","exitMaintenanceModeToastText":"O s\xedtio {slug} saiu com sucesso do modo de manuten\xe7\xe3o."}')}}]);