.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_post_title.et_pb_featured_bg{padding:16% 8%;background-size:cover;background-position:50%;position:relative;overflow:hidden}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_post_title .et_pb_parallax_css{background-repeat:no-repeat;background-position:top;background-size:cover;background-attachment:fixed;position:absolute;width:100%;height:100%;overflow:hidden}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_post_title.et_pb_featured_bg .et_pb_title_container{padding:1em 1.5em}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_post_title.et_pb_featured_bg .et_pb_title_meta_container{padding-bottom:0}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_title_container h1{font-size:26px}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_3 .et_pb_title_container h1,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_title_container h1,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_title_container h1,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_title_container h1,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_2_5 .et_pb_title_container h1{font-size:18px}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_title_featured_container{margin-left:auto;margin-right:auto}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_title_featured_container .et_pb_image_wrap{display:inline-block;position:relative;max-width:100%;width:100%}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_title_featured_container img{width:100%}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_title_container{display:block;max-width:100%;word-wrap:break-word;z-index:98;position:relative}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_title_featured_container{line-height:0;position:relative}.et-db #et-boc .et-l .et-db #et-boc .et-l p.et_pb_title_meta_container{padding-bottom:1em}.et-db #et-boc .et-l .et-db #et-boc .et-l p.et_pb_title_meta_container .et_pb_title_meta_item--visible+.et_pb_title_meta_item--visible:before{content:" | "}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_light p.et_pb_title_meta_container,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_light p.et_pb_title_meta_container a{color:#666}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_dark p.et_pb_title_meta_container,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_dark p.et_pb_title_meta_container a{color:inherit}@media (max-width:980px){.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_light_tablet p.et_pb_title_meta_container,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_light_tablet p.et_pb_title_meta_container a{color:#666}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_dark_tablet p.et_pb_title_meta_container,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_dark_tablet p.et_pb_title_meta_container a{color:inherit}}@media (max-width:767px){.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_title_container h1{font-size:18px}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_light_phone p.et_pb_title_meta_container,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_light_phone p.et_pb_title_meta_container a{color:#666}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_dark_phone p.et_pb_title_meta_container,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_bg_layout_dark_phone p.et_pb_title_meta_container a{color:inherit}}