"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1274"],{52124:function(e){e.exports=JSON.parse('{"title":"Toolbeheerder","subtitle":"Beheer al uw tools op \xc9\xc9N plek.","filters":{"all":"Alle","active":"Actief","disabled":"Uitgeschakeld","notInstalled":"Niet ge\xefnstalleerd"},"back":"Terug naar tooloverzicht","breadcrumb":{"home":"Startpagina","toolManager":"Toolbeheerder"},"tools":{"build":{"title":"Bouwen","items":{"core":{"title":"Editor kern"},"pro":{"title":"Editor pro","features":{"themeBuilder":"Themabouwer","popups":"Pop-ups","commerce":"Commerce","savedTemplates":"Opgeslagen sjablonen","templateCategories":"Sjablooncategorie\xebn","starterTemplates":"Startersjablonen (websitesjablonen)","customFonts":"Aangepaste lettertypen","customIcons":"Aangepaste pictogrammen","customCode":"Aangepaste code","customCss":"Aangepaste CSS"}},"ai":{"title":"Agentic AI"}}},"optimize":{"title":"Optimaliseren","items":{"accessibility":{"title":"Toegankelijkheid"},"io":{"title":"Afbeeldingsoptimalisatie"}}},"manage":{"title":"Beheren","items":{"email":{"title":"E-mailbezorgbaarheid"}}}},"actions":{"add":"Toevoegen","update":"Bijwerken","activate":"Activeren","deactivate":"Deactiveren","migrateToOne":"Migreren naar \xe9\xe9n","updateRequired":"Update vereist","confirmAdd":{"title":"Tool toevoegen","msg":"Weet u zeker dat u deze tool wilt toevoegen? Dit voegt de tool toe aan uw account en u kunt deze in uw projecten gebruiken.","ok":"Toevoegen","cancel":"Annuleren"},"confirmActivate":{"title":"Weet u zeker dat u {name} wilt activeren? ","msg":"Door te activeren ...","ok":"Activeren","cancel":"Annuleren"},"confirmDeactivate":{"title":"Weet u zeker dat u {name} wilt deactiveren? ","msg":"Door te deactiveren ...","ok":"Deactiveren","cancel":"Niet nu"}},"showMoreFeatures":"Meer functies tonen","hideMoreFeatures":"Meer functies verbergen","noToolsFound":"Geen tools gevonden die overeenkomen met de zoekopdracht","noToolsFoundDescription":"Probeer uw filters aan te passen.","updateRequiredTooltip":"Up-to-date plug-ins hebben nieuwe functies en fixes, zodat uw site veilig en soepel werkt."}')}}]);