.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_member_social_links a:hover{color:#2ea3f2}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_team_member{word-wrap:break-word}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_with_border .et_pb_team_member_image{border:0 solid #333}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_team_member_image{max-width:320px;margin-right:30px;line-height:0!important;position:relative}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column .et_pb_team_member_image.et-svg{width:320px;max-width:100%}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_team_member_no_image .et_pb_team_member_description{display:block!important}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_member_position{color:#aaa;padding-bottom:7px}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_2 .et_pb_team_member_image,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_3 .et_pb_team_member_image,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_team_member_image,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_team_member_image,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_team_member_image,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_2_5 .et_pb_team_member_image,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_3_5 .et_pb_team_member_image,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_3_8 .et_pb_team_member_image{display:block;width:auto;margin:0 0 12px;text-align:center}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_2 .et_pb_team_member,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_2 .et_pb_team_member_description,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_3 .et_pb_team_member,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_3 .et_pb_team_member_description,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_team_member,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_team_member_description,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_team_member,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_team_member_description,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_team_member,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_team_member_description,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_2_5 .et_pb_team_member,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_2_5 .et_pb_team_member_description,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_3_4 .et_pb_team_member,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_3_4 .et_pb_team_member_description,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_3_5 .et_pb_team_member,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_3_5 .et_pb_team_member_description,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_3_8 .et_pb_team_member,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_3_8 .et_pb_team_member_description{display:block}.et-db #et-boc .et-l .et-db #et-boc .et-l .entry-content .et_pb_member_social_links{list-style-type:none!important;margin-top:20px;padding:0}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_member_social_links li{display:inline-block;margin-right:15px}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_member_social_links a{display:inline-block;font-size:16px;position:relative;text-align:center;transition:color .3s ease 0s;color:#b2b2b2;text-decoration:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_facebook_icon:before{content:"\E093"}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_twitter_icon:before{content:"\E094"}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_google_icon:before{content:"\E096"}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_linkedin_icon:before{content:"\E09D"}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_member_social_links span{display:none}@media (min-width:768px) and (max-width:980px){.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column .et_pb_team_member_image{width:auto;margin:0 30px 12px 0;text-align:left}}@media (min-width:768px) and (max-width:980px){.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_row_4col .et_pb_column.et_pb_column_1_4 .et_pb_team_member_image{width:auto;max-width:none;margin:0 0 12px;text-align:center}}@media (max-width:767px){.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_team_member_image{width:auto;margin:0 0 12px;display:block;text-align:center}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_team_member_description{display:block}}@media (min-width:768px){.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_team_member_description{flex:1}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_team_member{display:flex;align-items:flex-start}}