<?php
/**
 * Internationalization.
 *
 * @package Divi
 */

return array(
	// Translators: %1$s: what is being copied.
	'0 items'                              => esc_html__( '0 items', 'et_builder' ),
	'%1$s Copy'                            => esc_html__( '%1$s Copy', 'et_builder' ),
	'All Changes Saved'                    => esc_html__( 'All Changes Saved', 'et_builder' ),
	'Body'                                 => et_builder_i18n( 'Body' ),
	'Cancel'                               => et_builder_i18n( 'Cancel' ),
	'Choose File'                          => esc_html__( 'Choose File', 'et_builder' ),
	'Close'                                => esc_html__( 'Close', 'et_builder' ),
	'Continue'                             => esc_html__( 'Continue', 'et_builder' ),
	'Delete'                               => esc_html__( 'Delete', 'et_builder' ),
	'Disable Global'                       => esc_html__( 'Disable Global', 'et_builder' ),
	'Duplicate'                            => esc_html__( 'Duplicate', 'et_builder' ),
	'Edit'                                 => esc_html__( 'Edit', 'et_builder' ),
	'Error'                                => esc_html__( 'Error', 'et_builder' ),
	'Footer'                               => esc_html__( 'Footer', 'et_builder' ),
	'Header'                               => esc_html__( 'Header', 'et_builder' ),
	'History'                              => esc_html__( 'History', 'et_builder' ),
	'More Settings'                        => esc_html__( 'More Settings', 'et_builder' ),
	'No file selected'                     => esc_html__( 'No File Selected', 'et_builder' ),
	'No results found.'                    => esc_html__( 'No results found.', 'et_builder' ),
	'Note: this process cannot be undone.' => esc_html__( 'Note: this process cannot be undone.', 'et_builder' ),
	'Options'                              => esc_html__( 'Options', 'et_builder' ),
	'Redo'                                 => esc_html__( 'Redo', 'et_builder' ),
	'Reset'                                => esc_html__( 'Reset', 'et_builder' ),
	'Save'                                 => esc_html__( 'Save', 'et_builder' ),
	'Save Changes'                         => esc_html__( 'Save Changes', 'et_builder' ),
	'Search dotdotdot'                     => esc_html__( 'Search …', 'et_builder' ),
	'Search for:'                          => esc_html__( 'Search for:', 'et_builder' ),
	'Settings'                             => esc_html__( 'Settings', 'et_builder' ),
	'Move'                                 => esc_html__( 'Move', 'et_builder' ),
	'Undo'                                 => esc_html__( 'Undo', 'et_builder' ),
	'Copy'                                 => esc_html__( 'Copy', 'et_builder' ),
	'Paste'                                => esc_html__( 'Paste', 'et_builder' ),
	// Translators: %1$s: Component name
	'%1$s could not be displayed.'         => esc_html__( '%1$s could not be displayed.', 'et_builder' ),
	'hide error message'                   => esc_html__( 'hide error message', 'et_builder' ),
	'show error message'                   => esc_html__( 'show error message', 'et_builder' ),
	'An unknown error has occurred. Please try again later.' => esc_html__( 'An unknown error has occurred. Please try again later.', 'et_builder' ),
);
