@import "../../../../css/_mixins.scss";
@import "../../../../css/_trx_addons.vars.scss";

//@mixin sc_mgenerator--lg() {
@media #{$media_lg} {
	/* mgenerator */
	.sc_mgenerator_form_field_tags {
		.sc_mgenerator_form_align_left_tablet & {
			@include flex-justify-content(flex-start);
		}
		.sc_mgenerator_form_align_right_tablet & {
			@include flex-justify-content(flex-end);
		}
	}
	.sc_mgenerator_limits {
		.sc_mgenerator_form_align_left_tablet & {
			text-align: left;
		}
		.sc_mgenerator_form_align_right_tablet & {
			text-align: right;
		}
	}
}
		
//@mixin sc_mgenerator--sm() {
@media #{$media_sm} {
    /* mgenerator */
	.sc_mgenerator_form_field.sc_mgenerator_form_field_prompt {
		width: 100%;
	}
	.sc_mgenerator_form_field_prompt {
		.sc_mgenerator_form_field_prompt_button {
			padding: 0 1em;
		}
	}
	.sc_mgenerator_form_field_tags {
		.sc_mgenerator_form_align_left_mobile & {
			@include flex-justify-content(flex-start);
		}
		.sc_mgenerator_form_align_right_mobile & {
			@include flex-justify-content(flex-end);
		}
	}
	.sc_mgenerator_form_field_tags_item {
		padding: 0.25em 0.75em;
	}
	.sc_mgenerator_form_field_tags_label {
		padding: 0.25em 0.75em 0.25em 0;
	}
	.sc_mgenerator_limits {
		.sc_mgenerator_form_align_left_mobile & {
			text-align: left;
		}
		.sc_mgenerator_form_align_right_mobile & {
			text-align: right;
		}
	}
	.sc_mgenerator_message {
		min-width: 50%;
	}
}

//@mixin sc_mgenerator--sm_wp() {
@media #{$media_sm_wp} {
	/* mgenerator */
	.sc_mgenerator_form_fields {
		@include flex-direction(column);
		@include flex-justify-content(flex-start);
		@include flex-align-items(stretch);
		gap: 1.5em;
		padding: 1.5em;
	}
	.sc_mgenerator_form_fields_left {
		@include flex-basis(100%);
		max-width: none;
	}
	.sc_mgenerator_form_fields_right {
		@include flex-basis(100%);
		max-width: none;
	}
}
	
//@mixin sc_mgenerator--xs() {
@media #{$media_xs} {
	/* mgenerator */
	.sc_mgenerator_form_field_tags {
		@include flex-direction(column);
	}
	.sc_mgenerator_form_field_tags_label {
		padding: 0 0 0.5em 0;
	}
}
