<?php
/**
 * "Code Snippets" quick feature constants file.
 *
 * Divi Cloud Code Snippet constants.
 *
 * @link https://github.com/elegantthemes/Divi/issues/26232
 *
 * @package Divi
 * @subpackage Cloud
 * @since 4.19.0
 */

if ( ! defined( 'ET_CODE_SNIPPET_POST_TYPE' ) ) {
	define( 'ET_CODE_SNIPPET_POST_TYPE', 'et_code_snippet' );
}

if ( ! defined( 'ET_CODE_SNIPPET_TAXONOMY_TYPE' ) ) {
	define( 'ET_CODE_SNIPPET_TAXONOMY_TYPE', 'et_code_snippet_type' );
}
