.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_number_counter{word-wrap:break-word;margin:0 auto 30px;position:relative;text-align:center}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_number_counter .percent{z-index:2}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_number_counter h3{font-size:18px;position:relative}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_number_counter .et_pb_module_header{position:relative}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_number_counter{opacity:0;transition:opacity 1s}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_number_counter.active{opacity:1}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_number_counter{width:auto}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_number_counter canvas{display:none;visibility:hidden}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_number_counter .percent{height:72px;position:relative}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_number_counter .percent p{font-size:72px;line-height:72px;font-weight:500}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_number_counter.et_pb_with_title .percent{margin-bottom:20px}@media (min-width:981px) and (max-width:1100px){.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_number_counter .percent,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_number_counter .percent,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_number_counter .percent{height:55px}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_number_counter h3,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_number_counter h3,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_number_counter h3{padding:10px 0 0}}