.et-db #et-boc .et-l .et_pb_accordion.et_pb_text_align_left .et_pb_toggle_title,.et-db #et-boc .et-l .et_pb_accordion.et_pb_text_align_left h5.et_pb_toggle_title,.et-db #et-boc .et-l .et_pb_accordion .et_pb_toggle.et_pb_text_align_left .et_pb_toggle_title,.et-db #et-boc .et-l .et_pb_accordion .et_pb_toggle.et_pb_text_align_left h5.et_pb_toggle_title{cursor:pointer;position:relative;padding:0 50px 0 0}.et-db #et-boc .et-l .et_pb_accordion .et_pb_toggle_title:before{right:0;left:auto}.et-db #et-boc .et-l .et_pb_accordion .et_pb_toggle{margin-bottom:10px;position:relative}.et-db #et-boc .et-l .et_pb_accordion .et_pb_toggle:last-child{margin-bottom:0}.et-db #et-boc .et-l .et_pb_accordion .et_pb_toggle_open .et_pb_toggle_title:before{display:none}@media (max-width:980px){.et-db #et-boc .et-l .et_pb_accordion.et_pb_text_align_left-tablet .et_pb_toggle_title,.et-db #et-boc .et-l .et_pb_accordion.et_pb_text_align_left-tablet h5.et_pb_toggle_title,.et-db #et-boc .et-l .et_pb_accordion .et_pb_toggle.et_pb_text_align_left-tablet .et_pb_toggle_title,.et-db #et-boc .et-l .et_pb_accordion .et_pb_toggle.et_pb_text_align_left-tablet h5.et_pb_toggle_title{cursor:pointer;position:relative;padding:0 50px 0 0}}@media (max-width:767px){.et-db #et-boc .et-l .et_pb_accordion.et_pb_text_align_left-phone .et_pb_toggle_title,.et-db #et-boc .et-l .et_pb_accordion.et_pb_text_align_left-phone h5.et_pb_toggle_title,.et-db #et-boc .et-l .et_pb_accordion .et_pb_toggle.et_pb_text_align_left-phone .et_pb_toggle_title,.et-db #et-boc .et-l .et_pb_accordion .et_pb_toggle.et_pb_text_align_left-phone h5.et_pb_toggle_title{cursor:pointer;position:relative;padding:0 50px 0 0}}