.ehp-image{--ehp-image-height:100%;--ehp-image-min-height:0;--ehp-image-position:center;--ehp-image-width:100%;--ehp-image-border-color:#54595f;--ehp-image-border-width:0;--ehp-image-border-radius-block-end:8px;--ehp-image-border-radius-block-start:8px;--ehp-image-border-radius-inline-end:8px;--ehp-image-border-radius-inline-start:8px;align-items:center;display:flex;justify-content:center;z-index:2}.elementor .ehp-image img{height:var(--ehp-image-height);min-height:var(--ehp-image-min-height);-o-object-fit:cover;object-fit:cover;-o-object-position:var(--ehp-image-position);object-position:var(--ehp-image-position);width:var(--ehp-image-width)}.elementor .ehp-image img.has-shape-custom{--ehp-shapes-border-radius-block-end:var(--ehp-image-border-radius-block-end);--ehp-shapes-border-radius-block-start:var(--ehp-image-border-radius-block-start);--ehp-shapes-border-radius-inline-end:var(--ehp-image-border-radius-inline-end);--ehp-shapes-border-radius-inline-start:var(--ehp-image-border-radius-inline-start)}.elementor .ehp-image img.has-border{border-color:var(--ehp-image-border-color);border-style:solid;border-width:var(--ehp-image-border-width)}
