"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["7632"],{74076:function(e){e.exports=JSON.parse('{"title":"Administrador de herramientas","subtitle":"Controle todas sus herramientas en UN solo lugar.","filters":{"all":"Todas","active":"Activas","disabled":"Desactivadas","notInstalled":"No instaladas"},"back":"Volver a la vista general de herramientas","breadcrumb":{"home":"Inicio","toolManager":"Administrador de herramientas"},"tools":{"build":{"title":"Crear","items":{"core":{"title":"N\xfacleo del editor"},"pro":{"title":"Editor pro","features":{"themeBuilder":"Constructor de temas","popups":"Ventanas emergentes","commerce":"Comercio","savedTemplates":"Plantillas guardadas","templateCategories":"Categor\xedas de plantillas","starterTemplates":"Plantillas de inicio (plantillas de sitio web)","customFonts":"Fuentes personalizadas","customIcons":"Iconos personalizados","customCode":"C\xf3digo personalizado","customCss":"CSS personalizado"}},"ai":{"title":"IA ag\xe9ntica"}}},"optimize":{"title":"Optimizar","items":{"accessibility":{"title":"Accesibilidad"},"io":{"title":"Optimizaci\xf3n de im\xe1genes"}}},"manage":{"title":"Gestionar","items":{"email":{"title":"Capacidad de entrega de correo electr\xf3nico"}}}},"actions":{"add":"A\xf1adir","update":"Actualizar","activate":"Activar","deactivate":"Desactivar","migrateToOne":"Migrar a uno","updateRequired":"Actualizaci\xf3n necesaria","confirmAdd":{"title":"A\xf1adir herramienta","msg":"\xbfEst\xe1 seguro de que desea a\xf1adir esta herramienta? Esto a\xf1adir\xe1 la herramienta a su cuenta y podr\xe1 usarla en sus proyectos.","ok":"A\xf1adir","cancel":"Cancelar"},"confirmActivate":{"title":"\xbfEst\xe1 seguro de que desea activar {name}? ","msg":"Al activar...","ok":"Activar","cancel":"Cancelar"},"confirmDeactivate":{"title":"\xbfEst\xe1 seguro de que desea desactivar {name}? ","msg":"Al desactivar...","ok":"Desactivar","cancel":"Ahora no"}},"showMoreFeatures":"Mostrar m\xe1s caracter\xedsticas","hideMoreFeatures":"Ocultar m\xe1s caracter\xedsticas","noToolsFound":"Ninguna herramienta coincide con la b\xfasqueda","noToolsFoundDescription":"Intente ajustar sus filtros.","updateRequiredTooltip":"Los plugins actualizados tienen nuevas caracter\xedsticas y correcciones para que su sitio funcione de forma segura y fluida."}')}}]);