// Fields Map (Based on Repeater control)

.elementor-panel {

	.elementor-control-type-fields_map {

		.elementor-repeater-fields {
			margin: 10px 0;

			.elementor-control {
				padding: 0;
			}

			&:last-child {
				margin-block-end: 0;
			}
		}
	}
}

.elementor-repeater-row--form-step {
	.elementor-repeater-row-tools {
		&:hover {
			background-color: $editor-lighter;
		}

		div:not(.elementor-repeater-row-handle-sortable) {
			background-color: $editor-background-light;

			&:hover {
				background-color: $editor-background;
			}
		}
	}
}
