jQuery(window).on("elementor:init",(function(){"use strict";var e=elementor.modules.controls.BaseData,t=e.extend({interval:null,ui:function(){var t=e.prototype.ui.apply(this,arguments);return t.inputs="textarea",t},events:function(){return _.extend(e.prototype.events.apply(this,arguments),{"change @ui.inputs":"onBaseInputChange"})},onBaseInputChange:function(e){clearTimeout(this.correctionTimeout);var t=e.currentTarget,n=this.getInputValue(t);this.updateElementModel(n,t)},onDestroy:function(){clearInterval(window.metFormPickerInterval2555)},onRender:function(){e.prototype.onRender.apply(this,arguments);var t=this;jQuery(document).on("click",".mf-edit-form",(function(){let e=jQuery("#elementor-preview-iframe")[0].contentDocument;jQuery(e).find(".elementor-element-editable .formpicker_warper_edit").trigger("click")})),window.metFormPickerInterval2555=setInterval((function(){var e=jQuery("body").attr("data-metform-template-load"),n=jQuery("body").attr("data-metform-template-key");if("true"==e&&1==t.isRendered&&n!==undefined){var r,o=(new Date).getTime(),a=n.split("***");r=(a=a[0])+"***"+o,jQuery("body").attr("data-metform-template-load","false"),t.setValue(r)}}),200)}},{});elementor.addControlView("formpicker",t)}));