.et-db #et-boc .et-l .et_pb_wc_breadcrumb{word-wrap:break-word}.et-db #et-boc .et-l .et_pb_with_border .woocommerce-breadcrumb{border:0 solid #333}.et-db #et-boc .et-l .et-dynamic-content-woo--product_breadcrumb.woocommerce .woocommerce-breadcrumb{color:inherit!important;font-family:inherit;font-weight:inherit;font-style:inherit;font-size:inherit;letter-spacing:inherit;line-height:inherit;text-align:inherit;text-shadow:inherit}