<?php
if (!defined('WORDFENCE_LS_VERSION')) { exit; }

?>
<div>
	<h2><?php esc_html_e('Permission Denied', 'wordfence') ?></h2>
	<p><?php esc_html_e('You do not have permission to manage 2FA settings for your account.', 'wordfence') ?></p>
</div>