!function(e){var t={};function i(r){if(t[r])return t[r].exports;var n=t[r]={i:r,l:!1,exports:{}};return e[r].call(n.exports,n,n.exports,i),n.l=!0,n.exports}i.m=e,i.c=t,i.d=function(e,t,r){i.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:r})},i.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},i.t=function(e,t){if(1&t&&(e=i(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var r=Object.create(null);if(i.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var n in e)i.d(r,n,function(t){return e[t]}.bind(null,n));return r},i.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return i.d(t,"a",t),t},i.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},i.p="",i(i.s=2)}({2:function(e,t){!function(e){ET_PageBuilder.Theme_Compat_Make=window.wp.Backbone.View.extend({initialize:function(){this.listenTo(Backbone.Events,"et-activate-builder",this.activateDiviBuilder),this.listenTo(Backbone.Events,"et-deactivate-builder",this.deactivateDiviBuilder)},activateDiviBuilder:function(){this.toggleMakeBuilder("off")},deactivateDiviBuilder:function(){this.toggleMakeBuilder("on")},toggleMakeBuilder:function(t){var i=e("#ttfmake-builder"),r=e("#page_template"),n=r.find('option[value="template-builder.php"]');"on"===t?(i.show(),n.attr({selected:"selected"}).removeAttr("disabled")):(i.hide(),n.attr({disabled:"disabled"}).removeAttr("selected")),r.trigger("change")}});var t=new ET_PageBuilder.Theme_Compat_Make;e("#et_pb_toggle_builder.et_pb_builder_is_used").length&&t.activateDiviBuilder()}(jQuery)}});