@import url(https://fonts.googleapis.com/css2?family=Roboto:ital,wght@0,100..900;1,100..900&display=swap);#adminmenu .toplevel_page_metform-menu .wp-menu-image>img{-webkit-filter:grayscale(1);filter:grayscale(1);transition:opacity .3s,-webkit-filter .3s;transition:opacity .3s,filter .3s;transition:opacity .3s,filter .3s,-webkit-filter .3s}#adminmenu .toplevel_page_metform-menu.opensub .wp-menu-image>img,#adminmenu .toplevel_page_metform-menu.wp-menu-open .wp-menu-image>img,#adminmenu .toplevel_page_metform-menu:hover .wp-menu-image>img{-webkit-filter:grayscale(0);filter:grayscale(0)}@keyframes infinite-spinning{from{-webkit-transform:rotate(0);transform:rotate(0)}to{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}.metform-pdf-export-btn.loading{pointer-events:none;filter:grayscale(1)}.metform-pdf-export-btn.loading .pdf-spinner{position:relative;width:18px;height:18px;border-radius:18px;background:rgba(0,0,0,.5);-webkit-animation:infinite-spinning 1.08s linear infinite;animation:infinite-spinning 1.08s linear infinite;vertical-align:middle;margin-right:7px;display:inline-block;top:-1px;left:5px}.metform-pdf-export-btn.loading .pdf-spinner::after{content:"";position:absolute;top:2px;left:50%;width:4px;height:4px;border-radius:4px;margin-left:-2px;background:#fff}.mf-svg-container{cursor:pointer;width:fit-content;font-family:roboto,sans-serif;font-weight:500;font-size:12px}.mf-svg-container .mf-svg-inner{display:flex}.mf-svg-container .mf-svg-inner svg{margin-top:1px;margin-right:3px;transition:filter .3s ease}.mf-svg-container .mf-export-pdf-btn{border:#2271b1 1px solid;padding:4px 8px;border-radius:6px;transition:background-color .3s ease}.mf-svg-container .mf-export-pdf-btn .mf-svg-text{margin-bottom:-2px;color:#2271b1;transition:color .3s ease}.mf-svg-container .mf-export-pdf-btn:hover{background-color:#2271b1}.mf-svg-container .mf-export-pdf-btn:hover .mf-svg-text{color:#fff}.mf-svg-container .mf-export-pdf-btn:hover svg{filter:brightness(0) invert(1)}.mf-svg-container .mf-svg-inner.mf-upgrade-btn .mf-svg-text:hover{text-decoration:underline}.mf-svg-container .mf-svg-inner.mf-upgrade-btn .mf-svg-text{color:#e81454}.mf-tooltip-wrapper{position:relative;display:inline-block;cursor:pointer}.mf-tooltip-wrapper::before{content:attr(data-tooltip);position:absolute;bottom:100%;left:50%;transform:translateX(-50%);background-color:#292929;color:#fff;padding:6px 8px;border-radius:4px;font-size:12px;white-space:nowrap;opacity:0;visibility:hidden;transition:opacity .3s,visibility .3s;margin-bottom:8px;z-index:1000;box-shadow:0 2px 8px rgba(0,0,0,.15)}.mf-tooltip-wrapper::after{content:"";position:absolute;bottom:85%;left:50%;transform:translateX(-50%);border:5px solid transparent;border-top-color:#292929;opacity:0;visibility:hidden;transition:opacity .3s,visibility .3s;margin-bottom:1px;z-index:1000}.mf-tooltip-wrapper:hover::after,.mf-tooltip-wrapper:hover::before{opacity:1;visibility:visible}#helpscout .mf-pro-missing,#zoho .mf-pro-missing{width:530px}.mf-max-width-800{max-width:800px}.mf-mt-40{margin-top:40px}.mf-ml-24{margin-left:24px}.metform-admin .biggopti{display:none}