.et-db #et-boc .et-l .et_pb_video_box{display:block;position:relative;z-index:1;line-height:0}.et-db #et-boc .et-l .et_pb_video_box video{width:100%!important;height:auto!important}.et-db #et-boc .et-l .et_pb_video_overlay{position:absolute;z-index:10;top:0;left:0;height:100%;width:100%;background-size:cover;background-repeat:no-repeat;background-position:50%;cursor:pointer}.et-db #et-boc .et-l .et_pb_video_play:before{font-family:ETmodules;content:"I"}.et-db #et-boc .et-l .et_pb_video_play{display:block;position:absolute;z-index:100;color:#fff;left:50%;top:50%}.et-db #et-boc .et-l .et_pb_column_1_2 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_2_3 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_3_4 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_3_5 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_4_4 .et_pb_video_play{font-size:6rem;line-height:6rem;margin-left:-3rem;margin-top:-3rem}.et-db #et-boc .et-l .et_pb_column_1_3 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_2_5 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_3_8 .et_pb_video_play{font-size:3rem;line-height:3rem;margin-left:-1.5rem;margin-top:-1.5rem}.et-db #et-boc .et-l .et_pb_bg_layout_light .et_pb_video_play{color:#333}.et-db #et-boc .et-l .et_pb_video_overlay_hover{background:transparent;width:100%;height:100%;position:absolute;z-index:100;transition:all .5s ease-in-out}.et-db #et-boc .et-l .et_pb_video .et_pb_video_overlay_hover:hover{background:rgba(0,0,0,.6)}@media (min-width:768px) and (max-width:980px){.et-db #et-boc .et-l .et_pb_column_1_3 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_2_5 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_3_8 .et_pb_video_play{font-size:6rem;line-height:6rem;margin-left:-3rem;margin-top:-3rem}}@media (max-width:980px){.et-db #et-boc .et-l .et_pb_bg_layout_light_tablet .et_pb_video_play{color:#333}}@media (max-width:768px){.et-db #et-boc .et-l .et_pb_column_1_2 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_2_3 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_3_4 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_3_5 .et_pb_video_play,.et-db #et-boc .et-l .et_pb_column_4_4 .et_pb_video_play{font-size:3rem;line-height:3rem;margin-left:-1.5rem;margin-top:-1.5rem}}@media (max-width:767px){.et-db #et-boc .et-l .et_pb_bg_layout_light_phone .et_pb_video_play{color:#333}}