export const MODAL_TYPE_SAVE_ITEM = 'save_item';
export const MODAL_TYPE_EDIT_ITEM = 'edit_item';
export const STATE_LOADING = 'loading';
export const STATE_ERROR = 'error';
export const STATE_SUCCESS = 'success';
export const STATE_IDLE = 'idle';

// Capabilities.
export const CAP_PORTABILITY         = 'portability';
export const CAP_SNIPPET_PORTABILITY = 'et_code_snippets_portability';
