"use strict";(globalThis.webpackChunkimage_optimization=globalThis.webpackChunkimage_optimization||[]).push([[539],{539(e){e.exports=JSON.parse('{"example":{"component":"Componente di esempio"}}')}}]);