@font-face{font-family:ETmodules;font-display:swap;src:url(../../../core/admin/fonts/modules/all/modules.eot);src:url(../../../core/admin/fonts/modules/all/modules.eot?#iefix) format("embedded-opentype"),url(../../../core/admin/fonts/modules/all/modules.ttf) format("truetype"),url(../../../core/admin/fonts/modules/all/modules.woff) format("woff"),url(../../../core/admin/fonts/modules/all/modules.svg#ETmodules) format("svg");font-weight:400;font-style:normal}li.toplevel_page_et_divi_options div.wp-menu-image:before{font-family:ETmodules;content:"\E625";width:30px!important;font-size:30px!important;margin-top:-5px}