.formpicker_warper_edit{display:none;position:absolute;top:0;right:0;bottom:0;width:0;z-index:99999}.formpicker_warper_editable{min-height:30px;min-width:100px;position:relative}.formpicker_iframe_modal{display:none}.formpicker_iframe_modal .dialog-widget-content{position:static!important;margin-top:10px}.elementor-editor-active .formpicker_warper_editable:hover{outline:1px solid #71d7f7}.elementor-editor-active .formpicker_warper_editable:hover>.formpicker_warper_edit{display:block}.metform-builder-edit{display:block;position:sticky;top:0;width:26px;height:26px;margin-top:-1px;margin-left:-25px;background:linear-gradient(45deg,#ff6b11 0,#ff324d 100%);border-bottom-left-radius:3px;cursor:pointer}.metform-builder-edit:before{content:" ";position:absolute;top:0;left:0;width:100%;height:100%;background-image:url(../img/edit_icon.svg);background-size:17px;background-repeat:no-repeat;background-position:center}.elementor-editor-active .formpicker_warper_editable .formpicker_warper_editable .formpicker_warper_edit,.elementor-widget-metform .elementor-element-overlay{display:none!important}