"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1729"],{64166:function(e){e.exports=JSON.parse('{"wPLoginAttempts":"Tentatives de connexion WordPress.","wPLoginAttemptsResetSuccess":"Les tentatives de connexion WordPress ont \xe9t\xe9 r\xe9initialis\xe9es avec succ\xe8s.","errorTryAgain":"Une erreur s\'est produite, veuillez r\xe9essayer.","backupCreation":"Cr\xe9ation de sauvegarde.","backupCreated":"La sauvegarde du site a \xe9t\xe9 cr\xe9\xe9e avec succ\xe8s.","backupUpdate":"La sauvegarde du site a \xe9t\xe9 mise \xe0 jour avec succ\xe8s.","backupUpdated":"La sauvegarde du site a \xe9t\xe9 mise \xe0 jour avec succ\xe8s.","backupRestore":"Restauration de sauvegarde.","backupDelete":"Suppression de sauvegarde.","backupDeleted":"La sauvegarde a \xe9t\xe9 supprim\xe9e.","backupExport":"Exportation de sauvegarde.","backupExportSuccessToast":"Vous recevrez prochainement un courriel contenant le lien de t\xe9l\xe9chargement.","debugMode":"Mode de d\xe9bogage.","debugModeSwithFailed":"{value, select, true {La d\xe9sactivation} other {L\'activation}} du mode de d\xe9bogage a \xe9chou\xe9, veuillez r\xe9essayer.","siteDeletion":"Suppression du site.","siteDeleted":"Le site a \xe9t\xe9 supprim\xe9.","setFavoriteSuccess":"{domain} a \xe9t\xe9 ajout\xe9 \xe0 vos sites favoris.","removeFavoriteSuccess":"{domain} a \xe9t\xe9 retir\xe9 de vos sites favoris.","maxReachedFavorites":"Vous avez atteint le nombre maximum de favoris.","generalErrorToast":"Oups, \xe7a n\'a pas fonctionn\xe9. Veuillez r\xe9essayer plus tard.","websiteDeactivation":"D\xe9sactivation du site web.","setDefaultPaymentFailed":"\xc9chec de la d\xe9finition du mode de paiement par d\xe9faut.","actionFailedMessage":"Nous vous prions de nous excuser, cela n\'a pas fonctionn\xe9.","retryErrorMessage":"Nous vous prions de nous excuser, cela n\'a pas fonctionn\xe9. Veuillez r\xe9essayer.","addingDomainFailed":"L\'ajout d\'un domaine a \xe9chou\xe9, veuillez r\xe9essayer.","removingDomainFailed":"La suppression d\'un domaine a \xe9chou\xe9, veuillez r\xe9essayer.","settingDomainPrimaryFailed":"La d\xe9finition du domaine comme principal a \xe9chou\xe9, veuillez r\xe9essayer.","emailVerification":"V\xe9rification de l\'adresse \xe9lectronique.","emailAlreadyVerified":"L\'adresse \xe9lectronique est d\xe9j\xe0 v\xe9rifi\xe9e.","emailVerificationSent":"Envoy\xe9! Veuillez v\xe9rifier votre bo\xeete de r\xe9ception pour un courriel de v\xe9rification.","emailVerificationResendDelay":"Nous avons d\xe9j\xe0 envoy\xe9 un courriel de v\xe9rification \xe0 votre bo\xeete de r\xe9ception. Si vous ne trouvez toujours pas le courriel, vous pouvez demander un nouvel envoi dans 5 minutes.","teamMemberRemoved":"{email} a \xe9t\xe9 retir\xe9 de votre \xe9quipe.","inviteSentTo":"Une invitation a \xe9t\xe9 envoy\xe9e \xe0 {email}.","billingInfoUpdated":"Vos informations de facturation ont \xe9t\xe9 mises \xe0 jour.","subCanceledConfirmation":"Votre abonnement a \xe9t\xe9 annul\xe9 et votre remboursement est en cours de traitement. Veuillez v\xe9rifier votre courriel pour plus de d\xe9tails.","siteDomainRemoved":"Le site web {domain} a \xe9t\xe9 supprim\xe9.","siteLockPassReset":"R\xe9initialisation du mot de passe de verrouillage du site.","updatedSiteLockCode":"Votre nouveau code de verrouillage du site est : {pass}.","contactSupport":"Contacter le support.","srySomethingWrong":"Nous vous prions de nous excuser, une erreur s\'est produite.","subRefundFailed":"Votre abonnement est toujours actif car le remboursement n\'a pas pu \xeatre trait\xe9. Nous sommes \xe0 votre disposition pour vous aider.","partialRefundMessage":"Votre remboursement n\'a pas pu \xeatre enti\xe8rement trait\xe9, mais votre abonnement n\'est plus actif. Nous sommes \xe0 votre disposition pour vous aider.","exitMaintenanceModeToastTitle":"Quitter le mode de maintenance.","exitMaintenanceModeToastText":"Le site {slug} est sorti avec succ\xe8s du mode de maintenance."}')}}]);