"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9391"],{32375:function(a){a.exports=JSON.parse('{"alertError":{"defaultTitle":"\xa1Algo sali\xf3 mal!","defaultMessage":"Por favor, actualice esta p\xe1gina.","refreshBtn":"Actualizar","okBtn":"Aceptar"},"errorBoundary":{"default":{"title":"\xa1Algo sali\xf3 mal!","message":"Por favor, actualice esta p\xe1gina.","btn":"Actualizar"},"newVersion":{"title":"\xa1Nueva versi\xf3n disponible!","message":"Por favor, actualice esta p\xe1gina.","btn":"Actualizar"}}}')}}]);