.elementor img.has-shape-sharp,.has-shape-sharp{--ehp-shapes-border-radius-sharp:0;border-radius:var(--ehp-shapes-border-radius-sharp)}.elementor img.has-shape-rounded,.has-shape-rounded{--ehp-shapes-border-radius-rounded:12px;border-radius:var(--ehp-shapes-border-radius-rounded)}.elementor img.has-shape-round,.has-shape-round{--ehp-shapes-border-radius-round:32px;border-radius:var(--ehp-shapes-border-radius-round)}.elementor img.has-shape-default,.has-shape-default{--ehp-shapes-border-radius-default:8px;border-radius:var(--ehp-shapes-border-radius-default)}.elementor img.has-shape-oval,.has-shape-oval{--ehp-shapes-border-radius-oval:50%;border-radius:var(--ehp-shapes-border-radius-oval)}.elementor img.has-shape-custom,.has-shape-custom{border-bottom-right-radius:var(--ehp-shapes-border-radius-inline-start);border-bottom-left-radius:var(--ehp-shapes-border-radius-inline-end);border-top-right-radius:var(--ehp-shapes-border-radius-block-end);border-top-left-radius:var(--ehp-shapes-border-radius-block-start)}@media screen and (max-width:1024px){.elementor img.has-shape-md-sharp,.has-shape-md-sharp{--ehp-shapes-border-radius-sharp:0;border-radius:var(--ehp-shapes-border-radius-sharp)}.elementor img.has-shape-md-rounded,.has-shape-md-rounded{--ehp-shapes-border-radius-rounded:12px;border-radius:var(--ehp-shapes-border-radius-rounded)}.elementor img.has-shape-md-round,.has-shape-md-round{--ehp-shapes-border-radius-round:32px;border-radius:var(--ehp-shapes-border-radius-round)}.elementor img.has-shape-md-default,.has-shape-md-default{--ehp-shapes-border-radius-default:8px;border-radius:var(--ehp-shapes-border-radius-default)}.elementor img.has-shape-md-oval,.has-shape-md-oval{--ehp-shapes-border-radius-oval:50%;border-radius:var(--ehp-shapes-border-radius-oval)}.elementor img.has-shape-md-custom,.has-shape-md-custom{border-bottom-right-radius:var(--ehp-shapes-border-radius-inline-start);border-bottom-left-radius:var(--ehp-shapes-border-radius-inline-end);border-top-right-radius:var(--ehp-shapes-border-radius-block-end);border-top-left-radius:var(--ehp-shapes-border-radius-block-start)}}@media screen and (max-width:767px){.elementor img.has-shape-sm-sharp,.has-shape-sm-sharp{--ehp-shapes-border-radius-sharp:0;border-radius:var(--ehp-shapes-border-radius-sharp)}.elementor img.has-shape-sm-rounded,.has-shape-sm-rounded{--ehp-shapes-border-radius-rounded:12px;border-radius:var(--ehp-shapes-border-radius-rounded)}.elementor img.has-shape-sm-round,.has-shape-sm-round{--ehp-shapes-border-radius-round:32px;border-radius:var(--ehp-shapes-border-radius-round)}.elementor img.has-shape-sm-default,.has-shape-sm-default{--ehp-shapes-border-radius-default:8px;border-radius:var(--ehp-shapes-border-radius-default)}.elementor img.has-shape-sm-oval,.has-shape-sm-oval{--ehp-shapes-border-radius-oval:50%;border-radius:var(--ehp-shapes-border-radius-oval)}.elementor img.has-shape-sm-custom,.has-shape-sm-custom{border-bottom-right-radius:var(--ehp-shapes-border-radius-inline-start);border-bottom-left-radius:var(--ehp-shapes-border-radius-inline-end);border-top-right-radius:var(--ehp-shapes-border-radius-block-end);border-top-left-radius:var(--ehp-shapes-border-radius-block-start)}}.elementor img.has-shape.shape-type-box,.has-shape.shape-type-box{--ehp-shapes-border-shape-rounded:52px}.elementor img.has-shape.shape-type-image,.has-shape.shape-type-image{--ehp-shapes-border-radius-rounded:52px;--ehp-shapes-border-radius-round:300px}.elementor img.has-shape.shape-type-logo,.has-shape.shape-type-logo{--ehp-shapes-border-radius-round:52px}
