.et-db #et-boc .et-l .et_pb_with_border.et_pb_wc_reviews #reviews #comments ol.commentlist li img.avatar{border:0 solid #333}.et-db #et-boc .et-l .et_pb_wc_reviews.et_pb_no_comments_count .woocommerce-Reviews-title{display:none}.et-db #et-boc .et-l .et_pb_wc_reviews.et_pb_comments_module.et_pb_no_comments_count #comments{display:block}.et-db #et-boc .et-l .et_pb_wc_reviews.et_pb_module .star-rating{margin-bottom:12px!important}.et-db #et-boc .et-l .et_pb_wc_reviews.et_pb_module .star-rating span:before{transition:color .3s}.et-db #et-boc .et-l .et_pb_wc_reviews.et_pb_no_avatar .avatar{display:none}.et-db #et-boc .et-l .et_pb_wc_reviews.et_pb_no_avatar #reviews #comments ol.commentlist li .comment-text{margin-left:0!important}.et-db #et-boc .et-l .et_pb_wc_reviews .comment-reply-title{display:block}.et-db #et-boc .et-l .et_pb_wc_reviews.et_pb_no_comments_meta .meta,.et-db #et-boc .et-l .et_pb_wc_reviews.et_pb_no_comments_rating .star-rating{display:none}@media (min-width:480px){.et-db #et-boc .et-l .et_pb_row>.et_pb_column_1_6 .et_pb_wc_reviews #reviews #comments ol.commentlist li img.avatar{float:none;position:relative;margin-bottom:10px}.et-db #et-boc .et-l .et_pb_row>.et_pb_column_1_6 .et_pb_wc_reviews #reviews #comments ol.commentlist li .comment-text{margin-left:0!important}}@media (min-width:980px){.et-db #et-boc .et-l .et_pb_row>.et_pb_column_1_5 .et_pb_wc_reviews #reviews #comments ol.commentlist li img.avatar,.et-db #et-boc .et-l .et_pb_row_inner>.et_pb_column_1_6 .et_pb_wc_reviews #reviews #comments ol.commentlist li img.avatar,.et-db #et-boc .et-l .et_pb_row_inner>.et_pb_column_2_9 .et_pb_wc_reviews #reviews #comments ol.commentlist li img.avatar{float:none;position:relative;margin-bottom:10px}.et-db #et-boc .et-l .et_pb_row>.et_pb_column_1_5 .et_pb_wc_reviews #reviews #comments ol.commentlist li .comment-text,.et-db #et-boc .et-l .et_pb_row_inner>.et_pb_column_1_6 .et_pb_wc_reviews #reviews #comments ol.commentlist li .comment-text,.et-db #et-boc .et-l .et_pb_row_inner>.et_pb_column_2_9 .et_pb_wc_reviews #reviews #comments ol.commentlist li .comment-text{margin-left:0!important}}.et-db #et-boc .et-l .et-dynamic-content-woo--product_reviews.woocommerce .comment-reply-title,.et-db #et-boc .et-l .et-dynamic-content-woo--product_reviews.woocommerce .rating,.et-db #et-boc .et-l .et-dynamic-content-woo--product_reviews.woocommerce ol.commentlist li .description,.et-db #et-boc .et-l .et-dynamic-content-woo--product_reviews.woocommerce ol.commentlist li .meta{color:inherit!important;font-family:inherit;font-weight:inherit;font-style:inherit;font-size:inherit;letter-spacing:inherit;line-height:inherit;text-align:inherit;text-shadow:inherit}.et-db #et-boc .et-l .et-dynamic-content-woo--product_reviews.woocommerce .woocommerce-Reviews-title{color:inherit;font-family:inherit;font-weight:inherit;font-style:inherit;letter-spacing:inherit;line-height:inherit;text-align:inherit;text-shadow:inherit}