"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["4424"],{61735:function(e){e.exports=JSON.parse('{"dialog":{"title":"Teilen Sie Ihr Feedback mit uns","fieldTitlePlaceholder":"Titel","fieldDescriptionPlaceholder":"Sagen Sie uns, was Sie sich vorgestellt haben","fieldSubjectPlaceholder":"W\xe4hlen Sie das Thema Ihres Feedbacks aus","fieldProductPlaceholder":"Produkt ausw\xe4hlen","note":"Wir freuen uns \xfcber Ihr Feedback! Wir pr\xfcfen zwar alle Einsendungen, k\xf6nnen aber nicht garantieren, dass jeder Vorschlag zu einer \xc4nderung oder Aktualisierung f\xfchrt.","subjects":{"leaveFeedback":"Feedback geben","reportBug":"Fehler melden","requestFeature":"Funktion anfragen","shareThoughts":"Sonstige Gedanken teilen"},"products":{"general":"Allgemein","editor":"Editor","accessibility":"Barrierefreiheit","imageOptimization":"Bildoptimierung","emailDeliverability":"E-Mail-Zustellbarkeit"},"cancel":"Abbrechen","submit":"Senden","titleLengthError":"Der Titel muss weniger als 90 Zeichen lang sein","descriptionLengthError":"Die Beschreibung muss weniger als 1024 Zeichen lang sein","alert":{"title":"Ben\xf6tigen Sie Hilfe oder sind Sie auf ein Problem gesto\xdfen?","button":"Ein Support-Ticket einreichen"}},"tooltipSuccess":"Feedback gesendet. Vielen Dank f\xfcr Ihre Hilfe.","tooltipError":"Es ist ein Fehler aufgetreten. Bitte versuchen Sie, Ihr Feedback erneut zu senden."}')}}]);