/*! For license information please see editor-styles.js.LICENSE.txt */
!function(){"use strict";var e={"./packages/packages/libs/editor-styles/src/types.ts":function(e,t,s){s.r(t)},"./packages/packages/libs/editor-styles/src/utils/generate-id.ts":function(e,t,s){function generateId(e="",t=[]){let s;do{s=e+Math.random().toString(16).slice(2,9)}while(t.includes(s));return s}s.r(t),s.d(t,{generateId:function(){return generateId}})},"./packages/packages/libs/editor-styles/src/utils/get-styles-schema.ts":function(e,t,s){s.r(t),s.d(t,{getStylesSchema:function(){return getStylesSchema}});const getStylesSchema=()=>{const e=(()=>{const e=window;return e.elementor?.config??{}})();return e?.atomic?.styles_schema??{}}},"./packages/packages/libs/editor-styles/src/utils/get-variant-by-meta.ts":function(e,t,s){function getVariantByMeta(e,t){return e.variants.find(e=>e.meta.breakpoint===t.breakpoint&&e.meta.state===t.state)}s.r(t),s.d(t,{getVariantByMeta:function(){return getVariantByMeta}})},"./packages/packages/libs/editor-styles/src/utils/state-utils.ts":function(e,t,s){s.r(t),s.d(t,{isClassState:function(){return isClassState},isPseudoState:function(){return isPseudoState}});const r=["hover","focus","active"],a=["e--selected"];function isClassState(e){return a.includes(e)}function isPseudoState(e){return r.includes(e)}}},t={};function __webpack_require__(s){var r=t[s];if(void 0!==r)return r.exports;var a=t[s]={exports:{}};return e[s](a,a.exports,__webpack_require__),a.exports}__webpack_require__.d=function(e,t){for(var s in t)__webpack_require__.o(t,s)&&!__webpack_require__.o(e,s)&&Object.defineProperty(e,s,{enumerable:!0,get:t[s]})},__webpack_require__.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},__webpack_require__.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})};var s={};!function(){__webpack_require__.r(s),__webpack_require__.d(s,{generateId:function(){return e.generateId},getStylesSchema:function(){return t.getStylesSchema},getVariantByMeta:function(){return r.getVariantByMeta},isClassState:function(){return a.isClassState},isPseudoState:function(){return a.isPseudoState}});__webpack_require__("./packages/packages/libs/editor-styles/src/types.ts");var e=__webpack_require__("./packages/packages/libs/editor-styles/src/utils/generate-id.ts"),t=__webpack_require__("./packages/packages/libs/editor-styles/src/utils/get-styles-schema.ts"),r=__webpack_require__("./packages/packages/libs/editor-styles/src/utils/get-variant-by-meta.ts"),a=__webpack_require__("./packages/packages/libs/editor-styles/src/utils/state-utils.ts")}(),(window.elementorV2=window.elementorV2||{}).editorStyles=s}(),window.elementorV2.editorStyles?.init?.();
//# sourceMappingURL=editor-styles.js.map