@import "../../../../css/_mixins.scss";
@import "../../../../css/_trx_addons.vars.scss";

//@mixin sc_tgenerator--lg() {
@media #{$media_lg} {
	/* TGenerator */
	.sc_tgenerator_limits {
		.sc_tgenerator_form_align_left_tablet & {
			text-align: left;
		}
		.sc_tgenerator_form_align_right_tablet & {
			text-align: right;
		}
	}
}

//@mixin sc_tgenerator--sm() {
@media #{$media_sm} {
    /* TGenerator */
	.sc_tgenerator_form_field_process,
	.sc_tgenerator_form_field_tone,
	.sc_tgenerator_form_field_language {
		.sc_tgenerator_form_field_select_options {
			left: auto;
			right: 0;
		}
	}
	.sc_tgenerator_form_field_prompt {
		.sc_tgenerator_form_field_prompt_button {
			padding: 0 1em;
		}
	}
	.sc_tgenerator_limits {
		.sc_tgenerator_form_align_left_mobile & {
			text-align: left;
		}
		.sc_tgenerator_form_align_right_mobile & {
			text-align: right;
		}
		.sc_tgenerator_limits_used {
			display: block;
			white-space: normal;
		}
	}
	.sc_tgenerator_message {
		min-width: 50%;
	}
}
