.woocommerce-checkout #main-content .et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_order_details table.shop_table tr.cart-subtotal td{border-top:1px solid rgba(0,0,0,.1)}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_order_details.et_pb_hide_module,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_order_details.et_pb_wc_order_pay,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_order_details .woocommerce-form-login-toggle,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_order_details .woocommerce-notices-wrapper{display:none}