jQuery(document).ready((function(e){var o=e("#metform-formlist");e("#post-query-submit").before(o.html()),o.remove();let t=new URL(window.location.href).searchParams.get("mf_form_id");t&&e("#metform-form_id").val(t),e(".row-actions .edit a, .page-title-action").html("View"),e(".mf-entry-pro.mf-svg-container").on("click",(function(e){window.open("https://wpmet.com/plugin/metform/pricing/","_blank")}))}));