.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_cart_totals form .form-row{padding:0;margin-bottom:12px}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_cart_totals .select2-container--default .select2-selection--single,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_cart_totals form .form-row input.input-text,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_cart_totals form .form-row textarea{width:-moz-available;width:-webkit-fill-available;width:fill-available}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_cart_totals table.shop_table{table-layout:fixed}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_cart_totals .select2-container--default .select2-selection--single,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_cart_totals form .form-row input.input-text,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_cart_totals form .form-row textarea{height:auto}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_cart_totals.et_pb_wc_cart_empty{display:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .et-pb-preview .et_pb_wc_cart_totals.et_pb_wc_cart_empty{display:block}@media (max-width:768px){.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_cart_totals span.select2-container[dir=ltr] .select2-selection__rendered{text-align:left}}