.et-db #et-boc .et-l .et_pb_tab,.et-db #et-boc .et-l .et_pb_tabs_controls{word-wrap:break-word}.et-db #et-boc .et-l .et_pb_tabs{border:1px solid #d9d9d9}.et-db #et-boc .et-l ul.et_pb_tabs_controls{background-color:#f4f4f4}.et-db #et-boc .et-l ul.et_pb_tabs_controls:after{border-top:1px solid #d9d9d9;content:"";display:block;visibility:visible;position:relative;top:-1px;z-index:9}.et-db #et-boc .et-l .et_pb_tabs_controls li{float:left;border-right:1px solid #d9d9d9;font-weight:600;position:relative;cursor:pointer;max-width:100%;display:table;z-index:11;line-height:1.7em}.et-db #et-boc .et-l .et_pb_tabs_controls li:not(.et_pb_tab_active):last-child{border-right:none}.et-db #et-boc .et-l .et_pb_tabs_controls li a{text-decoration:none;color:#666;padding:4px 30px;vertical-align:middle;display:table-cell;line-height:inherit}.et-db #et-boc .et-l .et_pb_tabs_controls li.et_pb_tab_active{background-color:#fff}.et-db #et-boc .et-l .et_pb_tab_active a{color:#333!important}.et-db #et-boc .et-l .et_pb_tab p:last-of-type{padding-bottom:0}.et-db #et-boc .et-l .et_pb_all_tabs{background-color:#fff}.et-db #et-boc .et-l .et_pb_all_tabs>div{display:none}.et-db #et-boc .et-l .et_pb_all_tabs .et_pb_active_content{display:block}.et-db #et-boc .et-l .et_pb_tab{padding:24px 30px}.et-db #et-boc .et-l .et_pb_tab_content{position:relative}.et-db #et-boc .et-l .et_pb_column_1_3 .et_pb_tabs_controls,.et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_tabs_controls,.et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_tabs_controls,.et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_tabs_controls,.et-db #et-boc .et-l .et_pb_column_2_5 .et_pb_tabs_controls,.et-db #et-boc .et-l .et_pb_column_3_8 .et_pb_tabs_controls{border-bottom:none}.et-db #et-boc .et-l .et_pb_column_1_3 .et_pb_tabs_controls li,.et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_tabs_controls li,.et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_tabs_controls li,.et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_tabs_controls li,.et-db #et-boc .et-l .et_pb_column_2_5 .et_pb_tabs_controls li,.et-db #et-boc .et-l .et_pb_column_3_8 .et_pb_tabs_controls li{float:none;border-right:none;border-bottom:1px solid #d9d9d9}.et-db #et-boc .et-l .et_pb_column_1_3 .et_pb_tabs_vertically_stacked .et_pb_tabs_controls li,.et-db #et-boc .et-l .et_pb_column_1_4 .et_pb_tabs_vertically_stacked .et_pb_tabs_controls li,.et-db #et-boc .et-l .et_pb_column_1_5 .et_pb_tabs_vertically_stacked .et_pb_tabs_controls li,.et-db #et-boc .et-l .et_pb_column_1_6 .et_pb_tabs_vertically_stacked .et_pb_tabs_controls li,.et-db #et-boc .et-l .et_pb_column_2_5 .et_pb_tabs_vertically_stacked .et_pb_tabs_controls li,.et-db #et-boc .et-l .et_pb_column_3_8 .et_pb_tabs_vertically_stacked .et_pb_tabs_controls li{width:100%}.et-db #et-boc .et-l .et_pb_tabs_controls{list-style:none!important;padding:0!important;line-height:inherit!important}@media (max-width:767px){.et-db #et-boc .et-l .et_pb_tabs_controls{border-bottom:none;height:auto!important}.et-db #et-boc .et-l .et_pb_tabs_controls li{float:none;border-right:none;border-bottom:1px solid #d9d9d9;display:block}}@media (max-width:479px){.et-db #et-boc .et-l .et_pb_tabs_controls{border-bottom:none}.et-db #et-boc .et-l .et_pb_tabs_controls li{float:none;border-right:none;border-bottom:1px solid #d9d9d9}}