/* RTL Support */

body {
	direction:rtl;
	unicode-bidi:embed;
}

.input-append .add-on:last-child, .input-append .btn:last-child {
	-webkit-border-radius: 3px 0 0 3px;
	-moz-border-radius: 3px 0 0 3px;
	border-radius: 3px 0 0 3px;
}

.input-append input, .input-append select, .input-append .uneditable-input {
	-webkit-border-radius: 0 3px 3px 0;
	-moz-border-radius: 0 3px 3px 0;
	border-radius: 0 3px 3px 0;
}