<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Yethee\\Tiktoken\\' => array($vendorDir . '/yethee/tiktoken/src'),
    'Symfony\\Contracts\\Service\\' => array($vendorDir . '/symfony/service-contracts'),
    'Psr\\Container\\' => array($vendorDir . '/psr/container/src'),
);
