.et-db #et-boc .et-l .et_pb_login_form .et_pb_newsletter_button{margin:0;width:100%;cursor:pointer}.et-db #et-boc .et-l .et_pb_login_form form{text-align:left}.et-db #et-boc .et-l .et_pb_login_form ::-webkit-input-placeholder{color:#666}.et-db #et-boc .et-l .et_pb_login_form ::-moz-placeholder{color:#666}.et-db #et-boc .et-l .et_pb_login_form :-ms-input-placeholder{color:#666}.et-db #et-boc .et-l .et_pb_newsletter.et_pb_login{display:block}.et-db #et-boc .et-l .et_pb_newsletter.et_pb_login .et_pb_module_header:empty+.et_pb_newsletter_description_content>br:first-child{display:none}.et-db #et-boc .et-l .et_pb_newsletter.et_pb_login .et_pb_newsletter_description,.et-db #et-boc .et-l .et_pb_newsletter.et_pb_login .et_pb_newsletter_form{float:left;position:relative}.et-db #et-boc .et-l .et_pb_newsletter.et_pb_login .et_pb_newsletter_description{margin-bottom:20px}body.logged-in:not(.et-fb) .et-db #et-boc .et-l .et_pb_newsletter.et_pb_login .et_pb_newsletter_description{margin-bottom:0}.et-db #et-boc .et-l .et_pb_forgot_password{font-size:12px;margin-top:-5px}.et-db #et-boc .et-l .et_pb_forgot_password a{color:#fff;text-decoration:underline}.et-db #et-boc .et-l .et_pb_bg_layout_light .et_pb_forgot_password a{color:#666}@media (min-width:768px){.et-db #et-boc .et-l .et_pb_in_customizer.et_pb_login .et_pb_newsletter_description{width:50%}}.et-db #et-boc .et-l .et_pb_newsletter .et_pb_newsletter_description,.et-db #et-boc .et-l .et_pb_newsletter .et_pb_newsletter_form{position:relative}.logged-in:not(.et-fb) .et_pb_login .et_pb_newsletter_description{width:100%;padding:0}