.et-db #et-boc .et-l .et_pb_fullwidth_section .et_pb_post_title{padding:6% 0;position:relative}.et-db #et-boc .et-l .et_pb_fullwidth_section .et_pb_post_title.et_pb_image_above{padding-top:0}.et-db #et-boc .et-l .et_pb_fullwidth_section .et_pb_post_title.et_pb_featured_bg .et_pb_title_container,.et-db #et-boc .et-l .et_pb_fullwidth_section .et_pb_post_title.et_pb_image_below{padding-bottom:0}.et-db #et-boc .et-l .et_pb_fullwidth_section .et_pb_title_container,.et-db #et-boc .et-l .et_pb_fullwidth_section .et_pb_title_featured_container{width:80%;max-width:1080px;margin:auto;display:block}@media (max-width:980px){.et-db #et-boc .et-l .et_pb_fullwidth_section .et_pb_post_title{padding:80px 0}}.single-post.et_left_sidebar .et_pb_fullwidth_section .et_pb_post_title,.single-post.et_right_sidebar .et_pb_fullwidth_section .et_pb_post_title{padding-top:0}.single-post.et_right_sidebar .et_pb_fullwidth_section .et_pb_post_title.et_pb_featured_bg{padding-top:6%}.single .et_pb_fullwidth_section .et_pb_title_featured_container,.single.et_right_sidebar .et_pb_fullwidth_section .et_pb_title_container{width:100%;max-width:100%;padding-top:0}