.et-db #et-boc .et-l .et-waypoint.et_pb_animation_off,.et-db #et-boc .et-l .et-waypoint:not(.et_pb_counters).et_pb_animation_off,.et-db #et-boc .et-l .et_pb_animation_off{opacity:1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_left.et-animated,.et-db #et-boc .et-l .et_pb_animation_left.et-animated{opacity:1;-webkit-animation:fadeLeft 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeLeft 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_right.et-animated,.et-db #et-boc .et-l .et_pb_animation_right.et-animated{opacity:1;-webkit-animation:fadeRight 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeRight 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_top.et-animated,.et-db #et-boc .et-l .et_pb_animation_top.et-animated{opacity:1;-webkit-animation:fadeTop 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeTop 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_bottom.et-animated,.et-db #et-boc .et-l .et_pb_animation_bottom.et-animated{opacity:1;-webkit-animation:fadeBottom 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeBottom 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_fade_in.et-animated,.et-db #et-boc .et-l .et_pb_animation_fade_in.et-animated{opacity:1;-webkit-animation:fadeIn 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeIn 1s cubic-bezier(.77,0,.175,1) 1}@media (max-width:980px){.et-db #et-boc .et-l .et-waypoint.et_pb_animation_off_tablet,.et-db #et-boc .et-l .et-waypoint:not(.et_pb_counters).et_pb_animation_off_tablet,.et-db #et-boc .et-l .et_pb_animation_off_tablet{opacity:1;-webkit-animation:none;animation:none}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_left_tablet.et-animated,.et-db #et-boc .et-l .et_pb_animation_left_tablet.et-animated{opacity:1;-webkit-animation:fadeLeft 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeLeft 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_right_tablet.et-animated,.et-db #et-boc .et-l .et_pb_animation_right_tablet.et-animated{opacity:1;-webkit-animation:fadeRight 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeRight 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_top_tablet.et-animated,.et-db #et-boc .et-l .et_pb_animation_top_tablet.et-animated{opacity:1;-webkit-animation:fadeTop 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeTop 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_bottom_tablet.et-animated,.et-db #et-boc .et-l .et_pb_animation_bottom_tablet.et-animated{opacity:1;-webkit-animation:fadeBottom 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeBottom 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_fade_in_tablet.et-animated,.et-db #et-boc .et-l .et_pb_animation_fade_in_tablet.et-animated{opacity:1;-webkit-animation:fadeIn 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeIn 1s cubic-bezier(.77,0,.175,1) 1}}@media (max-width:767px){.et-db #et-boc .et-l .et-waypoint.et_pb_animation_off_phone,.et-db #et-boc .et-l .et-waypoint:not(.et_pb_counters).et_pb_animation_off_phone,.et-db #et-boc .et-l .et_pb_animation_off_phone{opacity:1;-webkit-animation:none;animation:none}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_left_phone.et-animated,.et-db #et-boc .et-l .et_pb_animation_left_phone.et-animated{opacity:1;-webkit-animation:fadeLeft 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeLeft 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_right_phone.et-animated,.et-db #et-boc .et-l .et_pb_animation_right_phone.et-animated{opacity:1;-webkit-animation:fadeRight 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeRight 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_top_phone.et-animated,.et-db #et-boc .et-l .et_pb_animation_top_phone.et-animated{opacity:1;-webkit-animation:fadeTop 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeTop 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_bottom_phone.et-animated,.et-db #et-boc .et-l .et_pb_animation_bottom_phone.et-animated{opacity:1;-webkit-animation:fadeBottom 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeBottom 1s cubic-bezier(.77,0,.175,1) 1}.et-db #et-boc .et-l .et-waypoint.et_pb_animation_fade_in_phone.et-animated,.et-db #et-boc .et-l .et_pb_animation_fade_in_phone.et-animated{opacity:1;-webkit-animation:fadeIn 1s cubic-bezier(.77,0,.175,1) 1;animation:fadeIn 1s cubic-bezier(.77,0,.175,1) 1}}