@media (min-width:981px){.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_2_3 .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2,.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_2_3 .et_pb_row_inner .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2,.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_3_4 .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2,.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_3_4 .et_pb_row_inner .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2,.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_2_3 .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2,.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_2_3 .et_pb_row_inner .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2,.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_3_4 .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2,.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_3_4 .et_pb_row_inner .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2{margin-right:0;margin-left:0}.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_1_2 .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of1,.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_1_2 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2:nth-child(2n),.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_1_2 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of3:nth-child(3n),.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_1_2 .et_pb_row_inner .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of1,.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_2_3 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2:nth-child(2n),.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_2_3 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of3:nth-child(3n),.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_3_4 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2:nth-child(2n),.et-db #et-boc .et-l .et_pb_gutters1.rtl .et_pb_column_3_4 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of3:nth-child(3n),.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_1_2 .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of1,.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_1_2 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2:nth-child(2n),.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_1_2 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of3:nth-child(3n),.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_1_2 .et_pb_row_inner .et_pb_column_4_4 .et_pb_blog_grid .column.size-1of1,.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_2_3 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2:nth-child(2n),.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_2_3 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of3:nth-child(3n),.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_3_4 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of2:nth-child(2n),.rtl .et-db #et-boc .et-l .et_pb_gutters1.et_pb_row .et_pb_column_3_4 .et_pb_column_inner.et_pb_column_4_4 .et_pb_blog_grid .column.size-1of3:nth-child(3n){margin-left:0}}