<?php

return array(
	'$apiKeyPromptHint'       => esc_html__( 'Enter your ET Account API Key.', 'Divi' ),
	'$usernamePromptHint'     => esc_html__( 'Enter your ET Account Username.', 'Divi' ),
	'API Key'                 => esc_html__( 'API Key', 'Divi' ),
	'Authentication Required' => esc_html__( 'Authentication Required', 'Divi' ),
	'Username'                => esc_html__( 'Username', 'Divi' ),
	'Submit'                  => esc_html__( 'Submit', 'Divi' ),
	'Authentication'          => esc_html__( 'Authentication', 'Divi' ),
	'$authErrorMessage'       => esc_html__( 'Invalid API Key or Username', 'Divi' ),
	'$authenticationPrompt'   => esc_html__( 'Before you can generate Text using the Divi AI you must authenticate your Elegant Themes subscription.', 'Divi' ),
);
