.et-db #et-boc .et-l .et_pb_portfolio_item{word-wrap:break-word}.et-db #et-boc .et-l .et_pb_with_border .et_portfolio_image{border:0 solid #333}.et-db #et-boc .et-l .et_portfolio_image img{vertical-align:bottom;margin-bottom:0}.et-db #et-boc .et-l .et_pb_portfolio_item{background-size:cover;background-position:50%;background-repeat:no-repeat}.et-db #et-boc .et-l .et_pb_with_border .et_pb_portfolio_image,.et-db #et-boc .et-l .et_pb_with_border .et_pb_portfolio_item{border:0 solid #333}.et-db #et-boc .et-l .et_pb_portfolio_item .et_pb_module_header a,.et-db #et-boc .et-l .et_pb_portfolio_item .post-meta a,.et-db #et-boc .et-l .et_pb_portfolio_item h3 a{text-decoration:none}.et-db #et-boc .et-l .et_pb_bg_layout_light .et_pb_portfolio_item .post-meta,.et-db #et-boc .et-l .et_pb_bg_layout_light .et_pb_portfolio_item .post-meta a{color:#666}.et-db #et-boc .et-l .et_pb_bg_layout_dark .et_pb_portfolio_item .post-meta,.et-db #et-boc .et-l .et_pb_bg_layout_dark .et_pb_portfolio_item .post-meta a{color:inherit}.et-db #et-boc .et-l .et_pb_portfolio_item .et_pb_module_header,.et-db #et-boc .et-l .et_pb_portfolio_item h2{margin-top:10px}.et-db #et-boc .et-l .et_pb_portfolio_image:hover .et_overlay{z-index:3;opacity:1}.et-db #et-boc .et-l .et_pb_portfolio .et_pb_portfolio_item,.et-db #et-boc .et-l .et_pb_portfolio.et_pb_section_parallax .pagination,.et-db #et-boc .et-l .et_pb_portfolio.et_pb_section_parallax .wp-pagenavi,.et-db #et-boc .et-l .et_pb_portfolio.et_pb_section_video .pagination,.et-db #et-boc .et-l .et_pb_portfolio.et_pb_section_video .wp-pagenavi,.et-db #et-boc .et-l .et_pb_portfolio_grid.et_pb_section_parallax .pagination,.et-db #et-boc .et-l .et_pb_portfolio_grid.et_pb_section_parallax .wp-pagenavi,.et-db #et-boc .et-l .et_pb_portfolio_grid.et_pb_section_video .pagination,.et-db #et-boc .et-l .et_pb_portfolio_grid.et_pb_section_video .wp-pagenavi{position:relative}.et-db #et-boc .et-l .et_pb_portfolio_items_wrapper.no_pagination{border-bottom:none}@media (min-width:981px){.et-db #et-boc .et-l .et_pb_portfolio_grid .et_pb_portfolio_item img{width:100%}.et-db #et-boc .et-l .et_pb_portfolio_grid .et_pb_portfolio_item .et_pb_module_header,.et-db #et-boc .et-l .et_pb_portfolio_grid .et_pb_portfolio_item h2{word-wrap:break-word;margin:10px 0 0;padding-bottom:0}.et-db #et-boc .et-l .et_pb_portfolio_grid .et_pb_portfolio_item h2{font-size:18px}.et-db #et-boc .et-l .et_pb_portfolio_item .post-meta{font-size:14px;margin:.4em 0 0}}@media (max-width:980px){.et-db #et-boc .et-l .et_pb_bg_layout_light_tablet .et_pb_portfolio_item .post-meta,.et-db #et-boc .et-l .et_pb_bg_layout_light_tablet .et_pb_portfolio_item .post-meta a{color:#666}.et-db #et-boc .et-l .et_pb_bg_layout_dark_tablet .et_pb_portfolio_item .post-meta,.et-db #et-boc .et-l .et_pb_bg_layout_dark_tablet .et_pb_portfolio_item .post-meta a{color:inherit}.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item{margin:0 5.5% 7.5% 0;width:29.666%;clear:none;float:left}.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item:nth-child(3n){margin-right:0}.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item:nth-child(3n+1){clear:both}}@media (max-width:767px){.et-db #et-boc .et-l .et_pb_portfolio_item h2{font-size:18px}.et-db #et-boc .et-l .et_pb_bg_layout_light_phone .et_pb_portfolio_item .post-meta,.et-db #et-boc .et-l .et_pb_bg_layout_light_phone .et_pb_portfolio_item .post-meta a{color:#666}.et-db #et-boc .et-l .et_pb_bg_layout_dark_phone .et_pb_portfolio_item .post-meta,.et-db #et-boc .et-l .et_pb_bg_layout_dark_phone .et_pb_portfolio_item .post-meta a{color:inherit}.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item{margin:0 5.5% 9.5% 0;width:47.25%;clear:none;float:left}.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item:nth-child(3n){margin-right:5.5%}.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item:nth-child(3n+1){clear:none}.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item .last_in_row,.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item:nth-child(2n){margin-right:0}.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item .first_in_row,.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item:nth-child(odd){clear:both}}@media (max-width:479px){.et-db #et-boc .et-l .et_pb_portfolio_item{margin-bottom:22px}.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item{margin:0 0 11.5%;width:100%}.et-db #et-boc .et-l .et_pb_column .et_pb_grid_item.et_pb_portfolio_item .on_last_row{margin-bottom:0}}