__( 'Components', 'elementor' );
__( 'Edit Component', 'elementor' );
__( 'Default', 'elementor' );
/* translators: %s is the name of the user who is currently editing the document */
__( '%s is currently editing this document', 'elementor' );
__(
							'You can wait for them to finish or reach out to coordinate your changes together.',
							'elementor'
						);
__( 'Close', 'elementor' );
__( 'Override Property', 'elementor' );
__( 'Default', 'elementor' );
__( 'Name', 'elementor' );
__( 'Group Name', 'elementor' );
__( 'Create new property', 'elementor' );
__( 'Update property', 'elementor' );
__( 'Create', 'elementor' );
__( 'Update', 'elementor' );
__( 'Enter value', 'elementor' );
__( 'Overridable property', 'elementor' );
__( 'Make prop overridable', 'elementor' );
__( 'Exit component editing mode', 'elementor' );
__( 'Component saved successfully as: %1$s (UID: %2$s)', 'elementor' );
__( 'Failed to save component. Please try again.', 'elementor' );
__( 'Save as a component', 'elementor' );
__( 'Name', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Create', 'elementor' );
__( 'Text that explains that there are no Components yet.', 'elementor' );
__(
					'Once you have Components, this is where you can manage them—rearrange, duplicate, rename and delete irrelevant classes.',
					'elementor'
				);
__( 'To create a component, first design it, then choose one of three options:', 'elementor' );
__( '1. Right-click and select Create Component', 'elementor' );
__( '2. Use the component icon in the Structure panel', 'elementor' );
__( '3. Use the component icon in the Edit panel header', 'elementor' );
__( 'Sorry, nothing matched', 'elementor' );
__( 'Try something else.', 'elementor' );
__( 'Clear & try again', 'elementor' );
__( 'Search', 'elementor' );
__( 'Component name is too long. Please keep it under 50 characters.', 'elementor' );
__( 'Component name already exists', 'elementor' );
__( 'Component name is required.', 'elementor' );
__( 'Component name is too short. Please enter at least 2 characters.', 'elementor' );