@font-face{font-family:FontAwesome;font-style:normal;font-weight:400;font-display:block;src:url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-regular-400.eot);src:url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-regular-400.eot?#iefix) format("embedded-opentype"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-regular-400.woff2) format("woff2"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-regular-400.woff) format("woff"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-regular-400.ttf) format("truetype"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-regular-400.svg#fontawesome) format("svg")}@font-face{font-family:FontAwesome;font-style:normal;font-weight:900;font-display:block;src:url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-solid-900.eot);src:url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-solid-900.eot?#iefix) format("embedded-opentype"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-solid-900.woff2) format("woff2"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-solid-900.woff) format("woff"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-solid-900.ttf) format("truetype"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-solid-900.svg#fontawesome) format("svg")}@font-face{font-family:FontAwesome;font-style:normal;font-weight:400;font-display:block;src:url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-brands-400.eot);src:url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-brands-400.eot?#iefix) format("embedded-opentype"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-brands-400.woff2) format("woff2"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-brands-400.woff) format("woff"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-brands-400.ttf) format("truetype"),url(#dynamic-product-dir/core/admin/fonts/fontawesome/fa-brands-400.svg#fontawesome) format("svg")}