<?php
/**
 * I18n file.
 *
 * Translatable strings go here.
 *
 * @package Divi
 */

return [
	'Snippet'                  => esc_html__( 'Snippet', 'et_builder' ),
	'Code Snippet'             => esc_html__( 'Code Snippet', 'et_builder' ),
	'Divi Code Snippets'       => esc_html__( 'Divi Code Snippets', 'et_builder' ),
	'Code Snippets Library'    => esc_html__( 'Code Snippets Library', 'et_builder' ),
	'Code Snippet Details'     => esc_html__( 'Code Snippet Details', 'et_builder' ),
	'CSS Snippet'              => esc_html__( 'CSS Snippet', 'et_builder' ),
	'Edit Snippet'             => esc_html__( 'Edit Snippet', 'et_builder' ),
	'HTML/JS Snippet'          => esc_html__( 'HTML/JS Snippet', 'et_builder' ),
	'Snippets'                 => esc_html__( 'Snippets', 'et_builder' ),
	'importContextFail'        => esc_html__( 'This file should not be imported in this context.', 'et_builder' ),
	'Edit %s'                  => esc_html__( 'Edit %s', 'et_builder' ),
	'Save'                     => esc_html__( 'Save', 'et_builder' ),
	'Cancel'                   => esc_html__( 'Cancel', 'et_builder' ),
	'Import & Export Snippets' => esc_html__( 'Import & Export Snippets', 'et_builder' ),
	'Import & Export Snippet'  => esc_html__( 'Import & Export Snippet', 'et_builder' ),
	'Import Snippets'          => esc_html__( 'Import Snippets', 'et_builder' ),
	'Import Snippet'           => esc_html__( 'Import Snippet', 'et_builder' ),
	'Log In To Divi Cloud'     => esc_html__( 'Log In To Divi Cloud', 'et_builder' ),
	'Theme Options Library'    => esc_html__( 'Theme Options Library', 'et_builder' ),
	'Theme Options Details'    => esc_html__( 'Theme Options Details', 'et_builder' ),
];
