<?php

return array(
	'Added Context'                                    => esc_html__( 'Added Context', 'Divi' ),
	'Advanced Settings'                                => esc_html__( 'Advanced Settings', 'Divi' ),
	'Change Image Style'                               => esc_html__( 'Change Image Style', 'Divi' ),
	'Change Tone'                                      => esc_html__( 'Change Tone', 'Divi' ),
	'Choose Type'                                      => esc_html__( 'Choose Type', 'Divi' ),
	'Choose Style'                                     => esc_html__( 'Choose Style', 'Divi' ),
	'Content Results'                                  => esc_html__( 'Content Results', 'Divi' ),
	'Content Type'                                     => esc_html__( 'Content Type', 'Divi' ),
	'Generate'                                         => esc_html__( 'Generate', 'Divi' ),
	'Generate Image With AI'                           => esc_html__( 'Generate Image With AI', 'Divi' ),
	'Generate More Like This One'                      => esc_html__( 'Generate More Like This One', 'Divi' ),
	'Generate Prompt With AI'                          => esc_html__( 'Generate Prompt With AI', 'Divi' ),
	'Generate Text'                                    => esc_html__( 'Generate Text', 'Divi' ),
	'Generate Code'                                    => esc_html__( 'Generate Code', 'Divi' ),
	'Generating'                                       => esc_html__( 'Generating', 'Divi' ),
	'Generating Images'                                => esc_html__( 'Generating Images', 'Divi' ),
	'Guide Me'                                         => esc_html__( 'Guide Me', 'Divi' ),
	'Height'                                           => esc_html__( 'Height', 'Divi' ),
	'Image Description'                                => esc_html__( 'Image Description', 'Divi' ),
	'Image Size'                                       => esc_html__( 'Image Size', 'Divi' ),
	'Image Style'                                      => esc_html__( 'Image Style', 'Divi' ),
	'Image Type'                                       => esc_html__( 'Image Type', 'Divi' ),
	'Modify Selected Image'                            => esc_html__( 'Modify Selected Image', 'Divi' ),
	'Modify With AI'                                   => esc_html__( 'Modify With AI', 'Divi' ),
	'Mood & Lighting'                                  => esc_html__( 'Mood & Lighting', 'Divi' ),
	'Aspect Ratio'                                     => esc_html__( 'Aspect Ratio', 'Divi' ),
	'Size'                                             => esc_html__( 'Size', 'Divi' ),
	'Width'                                            => esc_html__( 'Width', 'Divi' ),
	'Height'                                           => esc_html__( 'Height', 'Divi' ),
	'More Options'                                     => esc_html__( 'More Options', 'Divi' ),
	'Must Use Keywords'                                => esc_html__( 'Must Use Keywords', 'Divi' ),
	'New Description'                                  => esc_html__( 'New Description', 'Divi' ),
	'Refine Result'                                    => esc_html__( 'Refine Result', 'Divi' ),
	'Refine your prompt'                               => esc_html__( 'Refine your prompt', 'Divi' ),
	'Regenerate'                                       => esc_html__( 'Regenerate', 'Divi' ),
	'Results'                                          => esc_html__( 'Results', 'Divi' ),
	'Rewrite to be more engaging'                      => esc_html__( 'Rewrite to be more engaging', 'Divi' ),
	'Rewrite With AI'                                  => esc_html__( 'Rewrite With AI', 'Divi' ),
	'Select Mood'                                      => esc_html__( 'Select Mood', 'Divi' ),
	'Tone of Voice'                                    => esc_html__( 'Tone of Voice', 'Divi' ),
	'Use This Image'                                   => esc_html__( 'Use This Image', 'Divi' ),
	'Use This Text'                                    => esc_html__( 'Use This Text', 'Divi' ),
	'What are you writing about?'                      => esc_html__( 'What are you writing about?', 'Divi' ),
	'Width'                                            => esc_html__( 'Width', 'Divi' ),
	'Write %s With AI'                                 => esc_html__( 'Write %s With AI', 'Divi' ),
	'Close'                                            => esc_html__( 'Close', 'Divi' ),
	'Error'                                            => esc_html__( 'Error', 'Divi' ),
	'What would you like to create using custom code?' => esc_html__( 'What would you like to create using custom code?', 'Divi' ),
	'How would you like to change the style of this element?' => esc_html__( 'How would you like to change the style of this element?', 'Divi' ),
	'Use This Code'                                    => esc_html__( 'Use This Code', 'Divi' ),
	'length'                                           => [
		'ContentLength' => esc_html__( 'Content Length', 'Divi' ),
		'Exactly'       => esc_html__( 'Exactly', 'Divi' ),
		'Maximum'       => esc_html__( 'Maximum', 'Divi' ),
		'AtLeast'       => esc_html__( 'At Least', 'Divi' ),
		'About'         => esc_html__( 'About', 'Divi' ),

		'Words'         => esc_html__( 'Words', 'Divi' ),
		'Characters'    => esc_html__( 'Characters', 'Divi' ),
		'Sentences'     => esc_html__( 'Sentences', 'Divi' ),
		'Paragraphs'    => esc_html__( 'Paragraphs', 'Divi' ),
		'ListItems'     => esc_html__( 'List Items', 'Divi' ),
	],
	'tags'                                             => [
		'Retry'        => esc_html__( 'Retry', 'Divi' ),
		'Lengthen'     => esc_html__( 'Lengthen', 'Divi' ),
		'Shorten'      => esc_html__( 'Shorten', 'Divi' ),
		'Simplify'     => esc_html__( 'Simplify', 'Divi' ),
		'GenerateMore' => esc_html__( 'Generate Four More', 'Divi' ),
	],
	'tones'                                            => [
		'informative' => esc_html__( 'Informative', 'Divi' ),
		'humorous'    => esc_html__( 'Humorous', 'Divi' ),
		'formal'      => esc_html__( 'Formal', 'Divi' ),
		'respectful'  => esc_html__( 'Respectful', 'Divi' ),
	],
	'imageStyles'                                      => [
		'photo'           => [
			'label'     => esc_html__( 'Photo', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/photo.jpg',
		],
		'digitalPainting' => [
			'label'     => esc_html__( 'Digital Painting', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/digitalPainting.jpg',
		],
		'conceptArt'      => [
			'label'     => esc_html__( 'Concept Art', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/conceptArt.jpg',
		],
		'vector'          => [
			'label'     => esc_html__( 'Vector Graphic', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/vector.jpg',
		],
		'threeD'          => [
			'label'     => esc_html__( '3D Render', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/threeD.jpg',
		],
		'drawing'         => [
			'label'     => esc_html__( 'Drawing', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/drawing.jpg',
		],
		'abstract'        => [
			'label'     => esc_html__( 'Abstract Art', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/abstract.jpg',
		],
		'comicBook'       => [
			'label'     => esc_html__( 'Comic Book', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/comicBook.jpg',
		],
		'watercolor'      => [
			'label'     => esc_html__( 'Watercolor', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/watercolor.jpg',
		],
		'painting'        => [
			'label'     => esc_html__( 'Painting', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/painting.jpg',
		],
		'anime'           => [
			'label'     => esc_html__( 'Anime', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/anime.jpg',
		],
		'cartoon'         => [
			'label'     => esc_html__( 'Cartoon', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/cartoon.jpg',
		],
		'none'            => [
			'label'     => esc_html__( 'None', 'Divi' ),
			'thumbnail' => 'https://www.elegantthemes.com/images/vb/ai/none.png',
		],
	],
	'contextTypes'                                     => [
		'page'    => esc_html__( 'This Page Content', 'Divi' ),
		'section' => esc_html__( 'This Section Content', 'Divi' ),
		'module'  => esc_html__( 'This Module Content', 'Divi' ),
		'empty'   => esc_html__( 'No Context', 'Divi' ),
	],
	'toneOfVoice'                                      => [
		'creative'    => esc_html__( 'Creative', 'Divi' ),
		'informative' => esc_html__( 'Informative', 'Divi' ),
		'funny'       => esc_html__( 'Funny', 'Divi' ),
	],
	'fieldTypes'                                       => [
		'paragraph'   => esc_html__( 'Paragraph', 'Divi' ),
		'title'       => esc_html__( 'Title', 'Divi' ),
		'button'      => esc_html__( 'Button', 'Divi' ),
		'blog_post'   => esc_html__( 'Blog Post', 'Divi' ),
		'social_post' => esc_html__( 'Social Media Post', 'Divi' ),
	],
	'aspectRatio'                                      => [
		'square'    => esc_html__( 'Square (1:1)', 'Divi' ),
		'landscape' => esc_html__( 'Landscape (8:5)', 'Divi' ),
		'portrait'  => esc_html__( 'Portrait (3:4)', 'Divi' ),
		'custom'    => esc_html__( 'Custom Size', 'Divi' ),
	],
	'companyType'                                      => [
		'default' => esc_html__( 'Default', 'Divi' ),
	],
	'$contentPromptHint'                               => esc_html__( 'Tell Divi AI what you want it to write about. Talk to it like you would a person.', 'Divi' ),
	'$codePromptHint'                                  => esc_html__( 'Tell Divi AI what you want to achieve using custom code. Divi AI will respond appropriately based on the element and code field you are editing.', 'Divi' ),
	'$contentTypeHint'                                 => esc_html__( 'What type of content are you writing? This will help Divi AI tailor the output to your desired format.', 'Divi' ),
	'$contextHint'                                     => esc_html__( 'Supply Divi AI with additional context. The chosen context will alter the results and help Divi AI create relevant content.', 'Divi' ),
	'$imagePromptHint'                                 => esc_html__( 'Tell Divi AI what kind of image you want it to create. Be as descriptive as you like!', 'Divi' ),
	'$aspectRatioHint'                                 => esc_html__( 'Choose the aspect ratio that will be used for the generated image.', 'Divi' ),
	'$imageWidthHint'                                  => esc_html__( 'Set the width of image in pixels.', 'Divi' ),
	'$imageHeightHint'                                 => esc_html__( 'Set the height of image in pixels.', 'Divi' ),
	'$imageStyleHint'                                  => esc_html__( 'Choose what style of image you would like to create. Or, select none and describe the style of image in your prompt.', 'Divi' ),
	'$mustUseHint'                                     => esc_html__( 'These words will be forced to appear in the content. This is useful for SEO when optimizing for specific keywords, for example.', 'Divi' ),
	'$numberWordsHint'                                 => esc_html__( 'Tell Divi AI how long you want the content it generates to be. The output will be close to, but not exactly equal to, the length you define.', 'Divi' ),
	'$refineHint'                                      => esc_html__( 'You can continue to alter and improve the content that was generated by giving AI further instructions.', 'Divi' ),
	'$pageDescTitle'                                   => esc_html__( 'Describe The Page You Want Divi AI To Create', 'Divi' ),
	'$pageDescHint'                                    => esc_html__( 'Describe the page you want Divi AI to create. If there are specific sections, colors or fonts you want to use, let it know! Or, keep it simple and let Divi AI run with it.', 'Divi' ),
	'$pageDescPlaceholder'                             => esc_html__( 'Example: Create a services page that describes our solar installation services, including testimonials and a contact form to collect leads', 'Divi' ),
	'$siteDescTitle'                                   => esc_html__( 'Tell Divi AI About Your Website (Optional)', 'Divi' ),
	'$siteDescHint'                                    => esc_html__( 'Give Divi AI general information about your website or business. The more context it has about you and your goals, the better layouts it will create and the more relevant content it will write.', 'Divi' ),
	'$siteDescPlaceholder'                             => esc_html__( 'Example: Our company, Sunset Solar, is a solar panel installation company serving the San Francisco Bay Area', 'Divi' ),
	'$headingFontHint'                                 => esc_html__( 'The heading font will be used for all headings throughout the layout. Let AI pick a great font for you, or choose one yourself.', 'Divi' ),
	'$bodyFontHint'                                    => esc_html__( 'The body font will be used for all text blocks throughout the layout. Let AI pick a great font for you, or choose one yourself.', 'Divi' ),
	'$headingFontColorHint'                            => esc_html__( 'Pick a color for your headings, or let Divi AI choose one for you.', 'Divi' ),
	'$bodyFontColorHint'                               => esc_html__( 'Pick a color to use for things like paragraphs, or let Divi AI choose one for you.', 'Divi' ),
	'$primaryColorHint'                                => esc_html__( 'Select a primary color, or let Divi AI choose a great color for you. The primary color is used through the layout, such as background colors, button colors, etc.', 'Divi' ),
	'$secondaryColorHint'                              => esc_html__( 'Select a secondary color, or let Divi AI choose a great color for you. The secondary color is used through the layout as a secondary accent color, such as for icon colors, text highlights, etc.', 'Divi' ),
	'$contentPlaceholder'                              => esc_html__( 'Tell Divi AI about the content you would like it to write.', 'Divi' ),
	'$imagePlaceholder'                                => esc_html__( 'Tell Divi AI about the image you would like it to create.', 'Divi' ),
	'Generating'                                       => esc_html__( 'Generating', 'Divi' ),
	'Generate Prompt With AI'                          => esc_html__( 'Generate Prompt With AI', 'Divi' ),
	'More Options'                                     => esc_html__( 'More Options', 'Divi' ),
	'language'                                         => [
		'Language'          => esc_html__( 'Language', 'Divi' ),
		'LanugageOfPrompt'  => esc_html__( 'Language of Prompt', 'Divi' ),
		'LanguageOfWebsite' => esc_html__( 'Language of Website', 'Divi' ),
		'$languageHint'     => esc_html__( 'What language should Divi AI write in? Divi AI can write in over 26 languages!', 'Divi' ),
	],
	'$toneHint'                                        => esc_html__( 'Give you content a unique spin by telling Divi AI what tone of voice to use.', 'Divi' ),
	'Something went wrong'                             => esc_html__( 'Something went wrong. Please try again later or try different request.', 'Divi' ),
	'$unable_to_render_reference'                      => esc_html__( 'Images stored on a different website cannot be used as reference. The issue can be resolved by uploading the image to the WordPress media library.', 'Divi' ),
	'Learn More'                                       => esc_html__( 'Learn More', 'Divi' ),
	'AI Unlimited'                                     => esc_html__( 'AI Unlimited', 'Divi' ),
	'Free Trial'                                       => esc_html__( 'Free Trial', 'Divi' ),
	'Upgrade'                                          => esc_html__( 'Upgrade', 'Divi' ),
	'upgradeTipPart1'                                  => esc_html__( 'You can try out Divi AI 100 times', 'Divi' ),
	'upgradeTipPart1_layouts'                          => esc_html__( 'You can generate 10 layouts', 'Divi' ),
	'upgradeTipPart2'                                  => esc_html__( 'for free. Upgrade to enjoy', 'Divi' ),
	'upgradeTipPart3'                                  => esc_html__( 'unlimited usage.', 'Divi' ),
	'Level up your efficiency'                         => esc_html__( 'Level up your efficiency with limitless AI content and image requests.', 'Divi' ),
	'Purchase Membership'                              => esc_html__( 'Your free Divi AI usage limit has been exceeded. Purchase a Divi AI membership to use Divi AI without any limits!', 'Divi' ),
	'Upgrade Membership'                               => esc_html__( 'Your Divi AI usage limit has been exceeded. Upgrade Divi AI membership to use Divi AI without any limits!', 'Divi' ),
	'$serverBusy'                                      => esc_html__( 'Divi AI Server is too busy right now. Please try again in a few minutes.', 'Divi' ),
	'$finalizeImage'                                   => esc_html__( 'Divi AI is finalizing your images! Please stand by.', 'Divi' ),
	'$imagesETAMessage'                                => esc_html__( 'About %s seconds remaining', 'Divi' ),

	'Upload a Reference Image'                         => esc_html__( 'Upload a Reference Image', 'Divi' ),
	'Reference Image (Optional)'                       => esc_html__( 'Reference Image (Optional)', 'Divi' ),
	'$referenceImageHint'                              => esc_html__( 'Supply Divi AI with a reference image. This image will be combined with your image description to create the final image. Reference images are a great way to inform Divi AI about a desired composition or style while altering the subject matter of the reference image using your image description.', 'Divi' ),
	'Reference Image Influence'                        => esc_html__( 'Reference Image Influence', 'Divi' ),
	'$referenceImageInfluenceHint'                     => esc_html__( 'Define how much influence your reference image has over the generated image. The less influence you give to the reference image, the more impact your image description will have.', 'Divi' ),
	'Upgrade to Divi AI Unlimited'                     => esc_html__( 'Upgrade to Divi AI Unlimited', 'Divi' ),
	'The size of the image must be less than 10MB'     => esc_html__( 'The size of the image must be less than 10MB.', 'Divi' ),
	'You have to update Divi in order to use AI'       => esc_html__( 'You have to update Divi in order to use AI.', 'Divi' ),
	'Purchase A Divi AI Membership'                    => et_esc_html_once( 'Purchase A Divi AI Membership', 'Divi' ),

	'Build Your Page With AI'                          => esc_html__( 'Build Your Page With AI', 'Divi' ),
	'Generate Layout'                                  => esc_html__( 'Generate Layout', 'Divi' ),
	'Customize Fonts and Colors'                       => esc_html__( 'Customize Fonts and Colors', 'Divi' ),
	'Heading Font'                                     => esc_html__( 'Heading Font', 'Divi' ),
	'Body Font'                                        => esc_html__( 'Body Font', 'Divi' ),
	'Select Font'                                      => esc_html__( 'Select Font', 'Divi' ),
	'Search Fonts'                                     => esc_html__( 'Search Fonts', 'Divi' ),
	'Heading Font Color'                               => esc_html__( 'Heading Font Color', 'Divi' ),
	'Body Font Color'                                  => esc_html__( 'Body Font Color', 'Divi' ),
	'Primary Color'                                    => esc_html__( 'Primary Color', 'Divi' ),
	'Secondary Color'                                  => esc_html__( 'Secondary Color', 'Divi' ),
	'Generating Layout'                                => esc_html__( 'Generating Layout', 'Divi' ),
	'Writing Text Content'                             => esc_html__( 'Writing Text Content', 'Divi' ),
	'Creating Imagery'                                 => esc_html__( 'Creating Imagery', 'Divi' ),
	'Processing Imagery'                               => esc_html__( 'Processing Imagery', 'Divi' ),
	'Upscaling Images'                                 => esc_html__( 'Upscaling Images', 'Divi' ),
	'Adjust Divi AI Default Styles'                    => esc_html__( 'Adjust Divi AI Default Styles', 'Divi' ),
	'layoutsFont'                                      => [
		'letAIChoose'    => esc_html__( 'Let AI Choose For Me', 'Divi' ),
		'websiteDefault' => esc_html__( 'Website Default', 'Divi' ),
		'default'        => esc_html__( 'AI Default', 'Divi' ),
	],
	'layoutsColor'                                     => [
		'diviAIDefault'  => esc_html__( 'Divi AI Default', 'Divi' ),
		'websiteDefault' => esc_html__( 'Website Default', 'Divi' ),
		'custom'         => esc_html__( 'Custom', 'Divi' ),
	],
	'Website Description (Optional)'                   => esc_html__( 'Website Description (Optional)', 'Divi' ),
	'Divi AI Default Styles'                           => esc_html__( 'Divi AI Default Styles', 'Divi' ),
	'$layoutSettingsDescription'                       => esc_html__( 'Define your default fonts and colors or leave empty to let AI choose for you. The settings you define here will be used by default when you generate your next layout.', 'Divi' ),
	'Unable to generate shortcode'                     => esc_html__( 'Unable to generate shortcode. Please try again later.', 'Divi' ),
	'Generate Section With AI'                         => esc_html__( 'Generate Section With AI', 'Divi' ),
	'$sectionDescTitle'                                => esc_html__( 'Describe The Section You Want Divi AI To Create', 'Divi' ),
	'$sectionDescHint'                                 => esc_html__( 'Describe the section you want Divi AI to create. If there are specific elements, colors or fonts you want to use, let it know! Or, keep it simple and let Divi AI run with it.', 'Divi' ),
	'$sectionDescPlaceholder'                          => esc_html__( 'Example: Create a services section that describes our solar installation services.', 'Divi' ),
	'Generate Section'                                 => esc_html__( 'Generate Section', 'Divi' ),
	'Generating Section'                               => esc_html__( 'Generating Section', 'Divi' ),
	'Images'                                           => esc_html__( 'Images', 'Divi' ),
	'$ImagesHint'                                      => esc_html__( 'Divi AI will fill your layouts with relevant photos and images automatically. Using stock photos is the fastest and most reliable option. You can also generate completely unique images using AI, which takes longer but can result in a wider variety of unique images.', 'Divi' ),
	'Use Stock Images (Faster)'                        => esc_html__( 'Use Stock Images (Faster)', 'Divi' ),
	'Generate Images With AI (Slower)'                 => esc_html__( 'Generate Images With AI (Slower)', 'Divi' ),
	'Use Placeholder Images'                           => esc_html__( 'Use Placeholder Images', 'Divi' ),
);
