.elementor-control-type-choose-img .elementor-choices{width:100%}.elementor-control-type-choose-img .elementor-choices-img{-moz-column-gap:4px;column-gap:4px;display:grid;grid-template-columns:repeat(var(--elementor-choices-columns),1fr);height:-moz-fit-content;height:fit-content;line-height:normal;row-gap:4px}.elementor-control-type-choose-img .elementor-choices-element{align-items:center;display:flex;flex-direction:column;gap:4px;justify-content:center;padding:4px;width:auto}.elementor-control-type-choose-img .elementor-choices-image{height:auto;width:100%}.elementor-control-type-choose-img .elementor-choices-label{flex-basis:unset!important;padding:8px;transition:transform .2s}.elementor-control-type-choose-img .elementor-choices input:not(:checked)+.elementor-choices-label{opacity:.7}.elementor-control-type-choose-img .elementor-choices input:hover+.elementor-choices-label{opacity:1;transform:scale(1.05)}.elementor-control-type-choose-img .elementor-choices input.e-choose-placeholder+.elementor-choices-label,.elementor-control-type-choose-img .elementor-choices input:checked+.elementor-choices-label{background-color:initial;border:2px solid #f0abfc;border-radius:3px;opacity:1}.tipsy-inner{white-space:pre-line}
