.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_stock{word-wrap:break-word}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_stock .out-of-stock{color:red}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_stock .in-stock{color:#77a464}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_stock .stock{font-size:13px}