#wf-extended-protection-notice{display:inline-block;line-height:1.4;padding:11px 15px;font-size:14px;text-align:left;margin:25px 20px 0 2px;background-color:#fff;border-left:4px solid #ffba00;box-shadow:0 1px 1px 0 rgba(0,0,0,0.1)}#wfcolorbox.wf-modal .wf-modal-footer.wf-modal-footer-center{justify-content:center}div.wf-radio-group div.wf-radio-option{display:flex;align-items:center}div.wf-radio-group div.wf-radio-option:not(:last-child){margin-bottom:8px}div.wf-radio-group div.wf-radio-option input[type=radio]{margin-right:8px}.wf-password-requirements{list-style-type:circle;margin:0}.wf-password-requirements>li{margin-left:2rem;margin-bottom:0}a.wfhelp{margin:0 3px 0 3px;text-decoration:none;display:inline-block;vertical-align:middle;font:normal normal normal 14px/1 FontAwesome;text-rendering:auto;-webkit-font-smoothing:antialiased}a.wfhelp:before{content:'\f29c'}
