@media (max-width:980px){.rtl .et-db #et-boc .et-l .et_pb_column .et_pb_blog_grid .column.size-1of2,.rtl .et-db #et-boc .et-l .et_pb_column .et_pb_widget{margin:0 0 7.5% 5.5%;float:right}.rtl .et-db #et-boc .et-l .et_pb_column .et_pb_blog_grid .column.size-1of2 .last_in_row,.rtl .et-db #et-boc .et-l .et_pb_column .et_pb_blog_grid .column.size-1of2:nth-child(2n),.rtl .et-db #et-boc .et-l .et_pb_column .et_pb_widget .last_in_row,.rtl .et-db #et-boc .et-l .et_pb_column .et_pb_widget:nth-child(2n){margin-left:0}}@media (max-width:767px){.rtl .et-db #et-boc .et-l .et_pb_column .et_pb_blog_grid .column.size-1of1 .et_pb_post{margin-left:0}}