.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info #payment ul.payment_methods{border:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info #order_review_heading{display:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info .wc_payment_method a{font-size:14px!important;line-height:1.7em!important}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info .woocommerce-checkout #payment div.form-row{padding:0}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info form .form-row{margin:2em 0 0}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info .woocommerce-checkout #payment ul.payment_methods{padding:0}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info #payment div.payment_box{border-style:solid}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info #payment div.payment_box:before{content:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info #payment ul.payment_methods li.woocommerce-info{border-style:solid!important;border-width:0!important}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info #payment ul.payment_methods li.woocommerce-notice{margin-top:1em;line-height:1.7em;border-top-color:inherit;font-weight:500}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info #payment .wc_payment_method{border-style:solid}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info .woocommerce-order{border-radius:5px;border-style:solid}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info.et_pb_text_align_center #payment ul.payment_methods li.woocommerce-info,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info.et_pb_text_align_center #payment ul.payment_methods li p{text-align:center}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info.et_pb_text_align_right #payment ul.payment_methods li.woocommerce-info,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info.et_pb_text_align_right #payment ul.payment_methods li p{text-align:right}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info.et_pb_text_align_justified #payment ul.payment_methods li.woocommerce-info,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info.et_pb_text_align_justified #payment ul.payment_methods li p{text-align:justify}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info .woocommerce-form-login-toggle,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info .woocommerce-notices-wrapper{display:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .woocommerce-order-received .et_pb_no_top_bottom_padding{padding-top:0;padding-bottom:0}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info #payment .wc_payment_method,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_checkout_payment_info #payment div.payment_box{border-width:0}