.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_price{word-wrap:break-word}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_price .amount{word-break:break-all}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_price .price{font-size:26px!important}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_price .price del{color:#999}