.et-db #et-boc .et-l .et_pb_slider{position:relative;overflow:hidden}.et-db #et-boc .et-l .et_pb_slide{padding:0 6%;background-size:cover;background-position:50%;background-repeat:no-repeat}.et-db #et-boc .et-l .et_pb_slider .et_pb_slide{display:none;float:left;margin-right:-100%;position:relative;width:100%;text-align:center;list-style:none!important;background-position:50%;background-size:100%;background-size:cover}.et-db #et-boc .et-l .et_pb_slider .et_pb_slide:first-child{display:list-item}.et-db #et-boc .et-l .et-pb-controllers{position:absolute;bottom:20px;left:0;width:100%;text-align:center;z-index:10}.et-db #et-boc .et-l .et-pb-controllers a{display:inline-block;background-color:hsla(0,0%,100%,.5);text-indent:-9999px;border-radius:7px;width:7px;height:7px;margin-right:10px;padding:0;opacity:.5}.et-db #et-boc .et-l .et-pb-controllers .et-pb-active-control{opacity:1}.et-db #et-boc .et-l .et-pb-controllers a:last-child{margin-right:0}.et-db #et-boc .et-l .et-pb-controllers .et-pb-active-control{background-color:#fff}.et-db #et-boc .et-l .et_pb_slides .et_pb_temp_slide{display:block}.et-db #et-boc .et-l .et_pb_slides:after{content:"";display:block;clear:both;visibility:hidden;line-height:0;height:0;width:0}@media (max-width:980px){.et-db #et-boc .et-l .et_pb_bg_layout_light_tablet .et-pb-controllers .et-pb-active-control{background-color:#333}.et-db #et-boc .et-l .et_pb_bg_layout_light_tablet .et-pb-controllers a{background-color:rgba(0,0,0,.3)}.et-db #et-boc .et-l .et_pb_bg_layout_light_tablet .et_pb_slide_content{color:#333}.et-db #et-boc .et-l .et_pb_bg_layout_dark_tablet .et_pb_slide_description{text-shadow:0 1px 3px rgba(0,0,0,.3)}.et-db #et-boc .et-l .et_pb_bg_layout_dark_tablet .et_pb_slide_content{color:#fff}.et-db #et-boc .et-l .et_pb_bg_layout_dark_tablet .et-pb-controllers .et-pb-active-control{background-color:#fff}.et-db #et-boc .et-l .et_pb_bg_layout_dark_tablet .et-pb-controllers a{background-color:hsla(0,0%,100%,.5)}}@media (max-width:767px){.et-db #et-boc .et-l .et-pb-controllers{position:absolute;bottom:5%;left:0;width:100%;text-align:center;z-index:10;height:14px}.et-db #et-boc .et-l .et_transparent_nav .et_pb_section:first-child .et-pb-controllers{bottom:18px}.et-db #et-boc .et-l .et_pb_bg_layout_light_phone.et_pb_slider_with_overlay .et_pb_slide_overlay_container,.et-db #et-boc .et-l .et_pb_bg_layout_light_phone.et_pb_slider_with_text_overlay .et_pb_text_overlay_wrapper{background-color:hsla(0,0%,100%,.9)}.et-db #et-boc .et-l .et_pb_bg_layout_light_phone .et-pb-controllers .et-pb-active-control{background-color:#333}.et-db #et-boc .et-l .et_pb_bg_layout_dark_phone.et_pb_slider_with_overlay .et_pb_slide_overlay_container,.et-db #et-boc .et-l .et_pb_bg_layout_dark_phone.et_pb_slider_with_text_overlay .et_pb_text_overlay_wrapper,.et-db #et-boc .et-l .et_pb_bg_layout_light_phone .et-pb-controllers a{background-color:rgba(0,0,0,.3)}.et-db #et-boc .et-l .et_pb_bg_layout_dark_phone .et-pb-controllers .et-pb-active-control{background-color:#fff}.et-db #et-boc .et-l .et_pb_bg_layout_dark_phone .et-pb-controllers a{background-color:hsla(0,0%,100%,.5)}}.et_mobile_device .et_pb_slider_parallax .et_pb_slide,.et_mobile_device .et_pb_slides .et_parallax_bg.et_pb_parallax_css{background-attachment:scroll}