.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_content,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_title{word-wrap:break-word}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle{border:1px solid #d9d9d9}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_close{background-color:#f4f4f4;padding:20px}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_close .et_pb_toggle_content{display:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_open{padding:20px;background-color:#fff;z-index:1}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle.et_pb_text_align_left .et_pb_toggle_title,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle.et_pb_text_align_left h5.et_pb_toggle_title,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle .et_pb_toggle_title,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle h5.et_pb_toggle_title{cursor:pointer;position:relative;padding:0 50px 0 0}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_close .et_pb_toggle_title,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_close h5.et_pb_toggle_title{color:#666}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_open .et_pb_toggle_title,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_open h5.et_pb_toggle_title{color:#333}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_title:before{content:"\E050";position:absolute;right:0;font-size:16px;color:#ccc;top:50%;margin-top:-.5em}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle .et_pb_toggle_title:before{right:0;left:auto}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_open .et_pb_toggle_title:before{content:"\E04F"}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_content{padding-top:20px;position:relative}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_content:empty{display:none!important}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle_content p:last-of-type{padding-bottom:0}@media (max-width:980px){.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle.et_pb_text_align_left-tablet .et_pb_toggle_title,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle.et_pb_text_align_left-tablet h5.et_pb_toggle_title{cursor:pointer;position:relative;padding:0 50px 0 0}}@media (max-width:767px){.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle.et_pb_text_align_left-phone .et_pb_toggle_title,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_toggle.et_pb_text_align_left-phone h5.et_pb_toggle_title{cursor:pointer;position:relative;padding:0 50px 0 0}}