<?php

return array(
	'Agency'                  => esc_html_x( 'Agency', 'Business', 'et_builder' ),
	'Author'                  => esc_html__( 'Author', 'et_builder' ),
	'Coffee Shop'             => esc_html__( 'Coffee Shop', 'et_builder' ),
	'Consultant'              => esc_html_x( 'Consultant', 'Business', 'et_builder' ),
	'Copywriter'              => esc_html__( 'Copywriter', 'et_builder' ),
	'Design Agency'           => esc_html__( 'Design Agency', 'et_builder' ),
	'Digital Payments'        => esc_html__( 'Digital Payments', 'et_builder' ),
	'Farmers Market'          => esc_html__( 'Farmers Market', 'et_builder' ),
	'Fashion'                 => esc_html_x( 'Fashion', 'Layout Pack', 'et_builder' ),
	'Florist'                 => esc_html__( 'Florist', 'et_builder' ),
	'Freelancer'              => esc_html__( 'Freelancer', 'et_builder' ),
	'Interior Design Company' => esc_html__( 'Interior Design Company', 'et_builder' ),
	'LMS'                     => esc_html_x( 'LMS', 'Learning Management System', 'et_builder' ),
	'Photographer'            => esc_html__( 'Photographer', 'et_builder' ),
	'Photo Marketplace'       => esc_html__( 'Photo Marketplace', 'et_builder' ),
	'Restaurant'              => esc_html__( 'Restaurant', 'et_builder' ),
	'SaaS Company'            => esc_html__( 'SaaS Company', 'et_builder' ),
	'Travel Agency'           => esc_html__( 'Travel Agency', 'et_builder' ),
	'Web Agency'              => esc_html__( 'Web Agency', 'et_builder' ),
	'Wedding'                 => esc_html__( 'Wedding', 'et_builder' ),
	'Yoga Studio'             => esc_html__( 'Yoga Studio', 'et_builder' ),
);
