"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["8669"],{79440:function(a){a.exports=JSON.parse('{"downloadInvoice404":{"title":"Faktur Anda sedang diproses","message":"Kami akan mengirimkannya melalui email setelah selesai."},"supportedLanguages":{"en":"Bahasa Inggris","de":"Deutsch","es":"Espa\xf1ol","it":"Italiano","nl":"Nederlands","pt-PT":"Portugu\xeas","pt-BR":"Portugis (Brasil)","fr":"Bahasa Prancis","he-IL":"\u05E2\u05D1\u05E8\u05D9\u05EA"}}')}}]);