.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_additional_info.et_pb_hide_title h2{display:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_additional_info table.shop_attributes{border-style:dotted;border-color:rgba(0,0,0,.1);border-collapse:separate}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_additional_info{word-wrap:break-word}.et-db #et-boc .et-l .et-db #et-boc .et-l .et-dynamic-content-woo--product_additional_information.woocommerce h2{color:inherit!important;font-family:inherit;font-weight:inherit;font-style:inherit;font-size:inherit;letter-spacing:inherit;line-height:inherit;text-align:inherit;text-shadow:inherit}