/* Styles for controls in the Elementor Editor
------------------------------------------------ */

/* Add brand to widgets */
#elementor-panel-elements-wrapper .elementor-element .trx_addons_elementor_widget_icon:after {
	content: "TRX";
	font-family: Roboto,Arial,Helvetica,Verdana,sans-serif;
	font-size: 9px;
	font-weight: bold;
	padding: 0.2em 0.5em;
	background-color: #aedf49;
	color: #000;
	/*
	border-width: 0 1px 1px 0;
	border-color: #e0e0e0;
	border-style: solid;
	*/
	position: absolute;
	top: 0;
	left: 0;
}
#elementor-panel-elements-wrapper .elementor-element:hover .trx_addons_elementor_widget_icon:after {
	background: #000;
	color: #fff;
}

/* Make each panel category as accordion */
#elementor-panel-categories .elementor-panel-category-title {
	color: #556068;
	padding: 17px 0;
	-webkit-transition: color 0.3s ease-out;
	    -ms-transition: color 0.3s ease-out;
	        transition: color 0.3s ease-out;
}
#elementor-panel-categories .elementor-panel-category-title:hover {
	color: #8b949a;
}
.elementor-panel .elementor-panel-category:not(.elementor-active):after {
	display: none;
}

/* Hide native Elementor's responsive params */
body.replace_hide_on_xxx .elementor-control-hide_widescreen,
body.replace_hide_on_xxx .elementor-control-hide_laptop,
body.replace_hide_on_xxx .elementor-control-hide_tablet_extra,
body.replace_hide_on_xxx .elementor-control-hide_mobile_extra,
body.replace_hide_on_xxx .elementor-control-hide_desktop,
body.replace_hide_on_xxx .elementor-control-hide_tablet,
body.replace_hide_on_xxx .elementor-control-hide_mobile {
	display: none !important;
}

/* Make visible icons in the context menu in the Editor */
.elementor-context-menu-list .elementor-context-menu-list__item {
	gap: 0;
}
.elementor-context-menu-list .elementor-context-menu-list__item__icon {
	display: inline-block;
	vertical-align: middle;
	line-height: 1;
}

/* Icons selector */
.elementor-control .trx_addons_icon_selector + .trx_addons_list_icons {
	left: 0 !important;
}
.elementor-control .trx_addons_icon_selector + .trx_addons_list_icons span {
	width: 2.08em;
}

/* Image selector */
.elementor-control .elementor-control-media__preview {
	background-repeat: no-repeat;
	background-size: contain;
}

/* Date_Time Control */
.datepicker_header a.icon-home:before {
	display: none;
}

/* Color picker */
.elementor-control .iris-border .iris-picker-inner {
	margin-right: -1px;
}
.elementor-control .wp-picker-container input[type="text"].wp-color-picker {
	min-height: 14px;
}

/* Slider */
.elementor-control.elementor-control-type-slider.elementor-label-inline .elementor-slider {
	min-width: 68px;
}

/* Presets */
.elementor-control.elementor-control-type-trx_preset {
	.elementor-control-input-wrapper {
		display: flex;
		align-items: center;
		position: relative;

		select {
			padding-inline-start: 5px;
			padding-inline-end: 20px;

			option.default {
				font-weight: bold;
			}
		}
	}
	.trx-addons-new-preset-name--error {
		border-color: #93003c;
	}
	.trx-addons-button-save-preset,
	.trx-addons-button-update-preset,
	.trx-addons-button-delete-preset,
	.trx-addons-button-reset-style {
		margin: 0 0 0 2px;
		max-width: 25px;
		min-width: 25px;
		padding: 4px 0;
		background: none;
		border: 1px solid #d5dadf;
		font-size: 14px;
	
		&:hover {
			box-shadow: none;
			opacity: 0.75;
		}
		i {
			margin: 0;
		}
	}
	.trx-addons-button-save-preset {
		color: #31D00B;
	}
	.trx-addons-button-update-preset {
		color: #0AD0D0;
	}
	.trx-addons-button-delete-preset {
		color: #e20000;
	}
	.trx-addons-button-reset-style {
		color: #666;
	}

	.trx-addons-panel-popup {
		top: 42px;
		padding-top: 0;

		.trx-addons-panel-checkbox {
			display: flex;
			align-items: center;
		
			input[type=checkbox] {
				width: 15px;
				
				&.trx-addons-new-preset-name--error + span {
					color: #93003c;
				}
			}
			span {
				display: inline-block;
				padding-left: 5px;
			}
		}
		.trx-addons-panel-buttons {
			display: flex;
			flex-wrap: wrap;
		
			.elementor-button {
				padding: 5px 10px;
				font-weight: 400;
				min-width: 69px;
				text-align: center;
				margin-bottom: 10px;

				&.trx-addons-elementor-button-error {
					background: #B55039;
					color: white;
				
					&:hover {
						opacity: 0.85;
						box-shadow: 0 0 2px rgba(0, 0, 0, 0.12), 0 2px 2px rgba(0, 0, 0, 0.12);
					}
				}
				&.elementor-button-cancel {
					background: #b3b3b3;
					color: #fff;
					margin-left: 10px;
				
					&:hover {
						opacity: 0.85;
						box-shadow: 0 0 2px rgba(0, 0, 0, 0.12), 0 2px 2px rgba(0, 0, 0, 0.12);
					}
				}
				.trx-addons-button-state-icon {
					display: none;
				}
			}
		}
		label {
			cursor: pointer;
		}
		&.trx-addons-panel-popup--delete-preset p {
			min-height: 67px;
		}
		.trx-addons-panel-checkbox {
			min-height: 26px;
		}
	}
	.trx-addons-preset-message .trx-addons-preset-message--error {
		color: #B55039;
	}
	.trx-addons-preset-message .trx-addons-preset-message--success {
		color: #62b559;
	}
}


/* Third-party controls
------------------------------------------------ */

// Tutor LMS Elementor Addons
// #elementor-panel-category-tutor_addons_category .icon i[class^="icon-"]:before,
#elementor-navigator .elementor-navigator__item i[class^="icon-"]:before,
#elementor-panel-elements-wrapper .icon i[class^="icon-"]:before {
	font-family: inherit;
}

// Metform */
#elementor-navigator .elementor-navigator__item i[class*="mf-widget-icon"]:before,
#elementor-panel-elements-wrapper .icon i[class*="mf-widget-icon"]:before {
	font-family: inherit;
}