@media (min-width:981px){.et-db #et-boc .et-l .et_pb_gutter.et_pb_gutters4 #left-area{width:81%}.et-db #et-boc .et-l .et_pb_gutter.et_pb_gutters4 #sidebar{width:19%}.et-db #et-boc .et-l .et_pb_gutters4.et_right_sidebar #left-area{padding-right:8%}.et-db #et-boc .et-l .et_pb_gutters4.et_left_sidebar #left-area{padding-left:8%}.et-db #et-boc .et-l .et_pb_gutter.et_pb_gutters4.et_right_sidebar #main-content .container:before{right:19%!important}.et-db #et-boc .et-l .et_pb_gutter.et_pb_gutters4.et_left_sidebar #main-content .container:before{left:19%!important}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column{margin-right:8%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_4_4,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_4_4{width:100%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_4_4 .et_pb_module,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_4_4 .et_pb_module{margin-bottom:4%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_3_4,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_3_4{width:73%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_3_4 .et_pb_module,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_3_4 .et_pb_module{margin-bottom:5.479%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_2_3,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_2_3{width:64%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_2_3 .et_pb_module,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_2_3 .et_pb_module{margin-bottom:6.25%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_3_5,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_3_5{width:56.8%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_3_5 .et_pb_module,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_3_5 .et_pb_module{margin-bottom:7.042%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_1_2,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_1_2{width:46%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_1_2 .et_pb_module,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_1_2 .et_pb_module{margin-bottom:8.696%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_2_5,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_2_5{width:35.2%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_2_5 .et_pb_module,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_2_5 .et_pb_module{margin-bottom:11.364%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_1_3,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_1_3{width:28%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_1_3 .et_pb_module,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_1_3 .et_pb_module{margin-bottom:14.286%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_1_4,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_1_4{width:19%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_1_4 .et_pb_module,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_1_4 .et_pb_module{margin-bottom:21.053%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_1_5,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_1_5{width:13.6%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_1_5 .et_pb_module,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_1_5 .et_pb_module{margin-bottom:29.412%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_1_6,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_1_6{width:10%}.et-db #et-boc .et-l .et_pb_gutters4 .et_pb_column_1_6 .et_pb_module,.et-db #et-boc .et-l .et_pb_gutters4.et_pb_row .et_pb_column_1_6 .et_pb_module{margin-bottom:40%}.et-db #et-boc .et-l .et_pb_gutters4 .et_full_width_page.woocommerce-page ul.products li.product{width:19%;margin-right:8%;margin-bottom:8%}.et-db #et-boc .et-l .et_pb_gutters4.et_left_sidebar.woocommerce-page #main-content ul.products li.product,.et-db #et-boc .et-l .et_pb_gutters4.et_right_sidebar.woocommerce-page #main-content ul.products li.product{width:26.027%;margin-right:10.959%}}