<?php return array(
    'root' => array(
        'name' => 'elementor/image-optimizer',
        'pretty_version' => 'dev-main',
        'version' => 'dev-main',
        'reference' => 'ac84eab483cb6890189696d0b6cda09e6eca934c',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'elementor/image-optimizer' => array(
            'pretty_version' => 'dev-main',
            'version' => 'dev-main',
            'reference' => 'ac84eab483cb6890189696d0b6cda09e6eca934c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'elementor/wp-notifications-package' => array(
            'pretty_version' => '1.2.0',
            'version' => '1.2.0.0',
            'reference' => 'dd25ca9dd79402c3bb51fab112aa079702eb165e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../elementor/wp-notifications-package',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'elementor/wp-one-package' => array(
            'pretty_version' => '1.0.46',
            'version' => '1.0.46.0',
            'reference' => '744191f07ac0dcb266dc4a9ee49bb12616a53bb8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../elementor/wp-one-package',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'woocommerce/action-scheduler' => array(
            'pretty_version' => '3.9.0',
            'version' => '3.9.0.0',
            'reference' => '90b98e6fe97d455679b1d288f050cad8f6f79771',
            'type' => 'wordpress-plugin',
            'install_path' => __DIR__ . '/../woocommerce/action-scheduler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
