.et-db #et-boc .et-l .et_pb_with_border.et_pb_wc_images .woocommerce-product-gallery__image{border:0 solid #333}.et-db #et-boc .et-l .et_pb_wc_images .et_pb_module_inner:after{visibility:hidden;display:block;font-size:0;content:" ";clear:both;height:0}.woocommerce-page .et_builder_inner_content.product .et-db #et-boc .et-l .et_pb_wc_images div.images,.woocommerce .et_builder_inner_content.product .et-db #et-boc .et-l .et_pb_wc_images div.images,body.woocommerce-page #content .et_builder_inner_content.product .et-db #et-boc .et-l .et_pb_wc_images div.images{width:100%}.et-pb-preview.woocommerce-page .content.product .et-db #et-boc .et-l .et_pb_wc_images div.images{width:100%!important}.et-db #et-boc .et-l .et_pb_wc_images div.images ol.flex-control-thumbs.flex-control-nav{overflow:visible}.et-db #et-boc .et-l .et_pb_wc_images div.images ol.flex-control-thumbs.flex-control-nav li{border-style:solid}.et-db #et-boc .et-l .et_pb_wc_images .woocommerce-product-gallery--without-images .woocommerce-product-gallery__wrapper{border-width:0;border-style:solid}.et-db #et-boc .et-l .et_pb_wc_images .woocommerce-product-gallery.images{width:100%}.et-db #et-boc .et-l .et_pb_wc_images .woocommerce-product-gallery>.woocommerce-product-gallery__wrapper{border-width:0;border-style:solid}.et-db #et-boc .et-l .et_pb_wc_images .flex-control-nav img,.et-db #et-boc .et-l .et_pb_wc_images .flex-viewport{border-style:solid}.et-pb-preview.woocommerce-page .et-db #et-boc .et-l .et_pb_wc_images .woocommerce-product-gallery{opacity:1!important}.et-db #et-boc .et-l .et_pb_wc_images span.onsale{border-style:solid}