"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["2386"],{82587:function(a){a.exports=JSON.parse('{"copyClipboard":"Panoya kopyala","copyClipboardSuccess":"Kopyaland\u0131!","noDataToDisplay":"G\xf6r\xfcnt\xfclenecek veri yok","search":"Ara","sort":"S\u0131rala","pagination":{"rowsPerPage":"Sayfa ba\u015F\u0131na sat\u0131r:","displayedRows":"{from}-{to} / {count}"}}')}}]);