__( 'The next generation of web creation', 'elementor' );
__( 'Beta', 'elementor' );
__( 'Welcome to version 4 of Elementor\'s Editor. It’s faster, more flexible, and built on a fully atomic approach to structure & styling.', 'elementor' );
__( 'Here’s what’s inside the beta version:', 'elementor' );
__( 'Unparalleled performance - Cleaner code & a lighter CSS footprint with single-div wrappers.', 'elementor' );
__( 'Professional tools at your fingertips - Variables, Classes and States.', 'elementor' );
__( 'Consistent styling experience - A unified Style tab for all atomic elements.', 'elementor' );
__( 'Fully responsive design - Customize any style property per screen.', 'elementor' );
__( 'And much more!', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'We’d love your feedback!', 'elementor' );
__( 'Head over to Github', 'elementor' );
__( 'Tell us why', 'elementor' );
__( 'Editor V4', 'elementor' );
__( 'Try out the new experience', 'elementor' );
__( 'Activate the new experience', 'elementor' );
__( 'Deactivate V4', 'elementor' );
__( 'Welcome! You’ve got the newest version of the editor.', 'elementor' );
__( 'You’ve deactivated the new Editor. Have feedback?', 'elementor' );
__( 'Ouch, there was a glitch. Try activating V4 again soon.', 'elementor' );
__( 'Version 4', 'elementor' );
__( 'Beta', 'elementor' );
__( 'I’ve read and understood.', 'elementor' );
__( 'You are about to enable version 4 features!', 'elementor' );
__( 'By activating, you’ll get early access to the next generation of Elementor’s Editor. This is your chance to explore new capabilities and help shape the future of Elementor! ', 'elementor' );
__( ' Important notes:', 'elementor' );
__( 'Features are still in development, but the beta is safe to use in production.', 'elementor' );
__( 'When you activate, you’ll also be activating Containers and Nested Elements. You can turn them back off by going to: WP Admin > Elementor > Settings > Features.', 'elementor' );
__( 'Activate', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'You\'re about to lose all content created with version 4', 'elementor' );
__( 'By deactivating, you’ll lose all Atomic Elements, Classes and Variables. Any content you created with these features will no longer be available or appear on your site.', 'elementor' );
__( 'Containers and Nested Elements will stay in their current status.', 'elementor' );
__( 'Deactivate', 'elementor' );
__( 'Cancel', 'elementor' );