@font-face{font-family:ETmodules;font-display:block;src:url(#dynamic-product-dir/core/admin/fonts/modules/base/modules.eot);src:url(#dynamic-product-dir/core/admin/fonts/modules/base/modules.eot?#iefix) format("embedded-opentype"),url(#dynamic-product-dir/core/admin/fonts/modules/base/modules.woff) format("woff"),url(#dynamic-product-dir/core/admin/fonts/modules/base/modules.ttf) format("truetype"),url(#dynamic-product-dir/core/admin/fonts/modules/base/modules.svg#ETmodules) format("svg");font-weight:400;font-style:normal}