.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart form.cart .button,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart form.cart div.quantity{float:none!important;display:inline-block;vertical-align:middle}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart form.cart{margin-top:0!important;margin-bottom:0!important}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart form.cart .variations td .label{font-weight:700}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart form.cart .variations td select{border-style:solid!important;border-width:0;-moz-appearance:none;-webkit-appearance:none;width:100%}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart form.cart .variations td.value{position:relative}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart form.cart .variations td.value span:after{border:6px solid transparent;border-top-color:#666;content:"";display:block;height:0;margin-top:3px;pointer-events:none;position:absolute;right:10px;transform:translateY(-145%);width:0}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart form.cart .variations td.value .reset_variations{float:right;margin-top:1em}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart.et_pb_hide_input_quantity .quantity,.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart.et_pb_hide_input_quantity .woocommerce-grouped-product-list-item__quantity{display:none!important}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart.et_pb_hide_stock .stock{display:none}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart .quantity input.qty{border:0 solid #333!important;width:auto;max-width:4.3em}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart.et_pb_fields_label_position_stacked form.cart .variations td{display:block}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart.et_pb_fields_label_position_stacked form.cart .variations td.label{padding-bottom:.6em!important}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart.et_pb_fields_label_position_stacked form.cart div.quantity{display:block;margin:0 0 20px!important}.et-db #et-boc .et-l .et-db #et-boc .et-l .et_pb_wc_add_to_cart{word-wrap:break-word}.et-db #et-boc .et-l .et-db #et-boc .et-l .et-dynamic-content-woo--product_additional_information.woocommerce h2{color:inherit!important;font-family:inherit;font-weight:inherit;font-style:inherit;font-size:inherit;letter-spacing:inherit;line-height:inherit;text-align:inherit;text-shadow:inherit}