.et-db #et-boc .et-l .et_parallax_bg.et_parallax_bg__sticky,.et-db #et-boc .et-l .et_pb_sticky.et_pb_section_parallax_sticky .et_parallax_bg:not(.et_parallax_bg__sticky),.et-db #et-boc .et-l .et_pb_sticky .et_pb_section_parallax_sticky .et_parallax_bg:not(.et_parallax_bg__sticky){display:none}.et-db #et-boc .et-l .et_pb_sticky.et_pb_section_parallax_sticky .et_parallax_bg.et_parallax_bg__sticky,.et-db #et-boc .et-l .et_pb_sticky .et_pb_section_parallax_sticky .et_parallax_bg.et_parallax_bg__sticky{display:block}.et-db #et-boc .et-l .et_builder_inner_content.has_et_pb_sticky{z-index:inherit}.et-db #et-boc .et-l .et-db #et-boc .et-l #et-fb-app .et_pb_column.has_et_pb_sticky,.et-db #et-boc .et-l .et_pb_column.has_et_pb_sticky{z-index:20}.et-l--header .et-db #et-boc .et-l .et-db #et-boc .et-l #et-fb-app .et_pb_column.has_et_pb_sticky,.et-l--header .et-db #et-boc .et-l .et_pb_column.has_et_pb_sticky{z-index:30}.et-l--footer .et-db #et-boc .et-l .et-db #et-boc .et-l #et-fb-app .et_pb_column.has_et_pb_sticky,.et-l--footer .et-db #et-boc .et-l .et_pb_column.has_et_pb_sticky{z-index:10}.et-db #et-boc .et-l .et_pb_sticky_placeholder{opacity:0!important}.et-db #et-boc .et-l .et_pb_sticky .et_overlay.et_pb_inline_icon_sticky:before,.et-db #et-boc .et-l .et_pb_sticky .et_pb_inline_icon_sticky:before{content:attr(data-icon-sticky)!important}.et-db #et-boc .et-l body .et-script-temporary-measurement{opacity:0}