<?php
/* THIS IS A GENERATED FILE. DO NOT EDIT DIRECTLY. */
$generated_i18n_strings = array(
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( '1', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( '2', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( '3', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( '4', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( '5', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( '6', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( '7', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( '8', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( '9', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( '10', 'coming-soon' ),

	// Reference: src/App.vue
	// Reference: src/views/Setup.vue
	__( 'Changes not saved, are you sure you want to leave?', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( '&larr; Go Back', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( '&larr; Go to Dashboard', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Choose a New Page Template', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'All Templates', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Favorite Templates', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Saved Templates', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'No Favorited Templates Found', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'No Saved Templates Found', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Filter:', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'All', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/views/SectionTemplateOptions-Pro.vue
	// Reference: src/views/SectionTemplateOptions-Lite.vue
	__( 'No Templates Found', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Choose This Template', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Enter your new page details', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'You can always change it later in Page Settings.', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Page Name:', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/views/SettingsGeneral.vue
	__( 'Page URL:', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Save and Start Editing the Page', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	__( 'First Page', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	__( 'Prev', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	__( 'Next', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	__( 'Last Page', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Search templates...', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'My Landing Page name goes here', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'You can favorite any template by clicking the heart icon under the page template.', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'You can save pages as templates in the builder. Any saved pages will be shown here.', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/BuilderView.vue
	__( 'Your license key is invalid', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/BuilderView.vue
	__( 'Click Here to Enter Your License Key', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	__( 'Template Dev Mode - Select the Blank Template to Create a New Template or Select an Existing Template to Edit', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/views/SectionTemplateOptions-Pro.vue
	// Reference: src/views/SectionTemplateOptions-Lite.vue
	// Reference: src/mixins/helpers.js
	__( 'Are you sure you want to delete?', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/views/SectionTemplateOptions-Pro.vue
	// Reference: src/views/SectionTemplateOptions-Lite.vue
	// Reference: src/mixins/helpers.js
	__( 'Yes, delete it!', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/views/Setup.vue
	// Reference: src/views/SectionTemplateOptions-Pro.vue
	// Reference: src/views/SectionTemplateOptions-Lite.vue
	// Reference: src/views/Layoutnav.vue
	// Reference: src/mixins/helpers.js
	// Reference: src/components/Section.vue
	// Reference: src/components/Row.vue
	// Reference: src/components/OpenAIImageControl.vue
	// Reference: src/components/OpenAIControl.vue
	// Reference: src/components/DynamicTextControl.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Cancel', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	// Reference: src/views/SectionTemplateOptions-Pro.vue
	// Reference: src/views/SectionTemplateOptions-Lite.vue
	__( 'Deleted!', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Blank Template', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'This page url already exisits. Please choose a unique page url.', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Pro.vue
	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Could not be saved. Please contact Support if you continue to experience this issue.', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Send Us Your Email and Get 10 Free Templates', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'Get <strong>FREE</strong> Templates', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'PRO', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'SUBSCRIBE ABOVE TO UNLOCK', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue
	__( 'You now have access to 10 FREE templates.', 'coming-soon' ),

	// Reference: src/views/SetupSettings.vue
	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Access Control', 'coming-soon' ),

	// Reference: src/views/SetupSettings.vue
	// Reference: src/views/SettingsSEO.vue
	__( 'SEO', 'coming-soon' ),

	// Reference: src/views/SetupSettings.vue
	// Reference: src/views/SettingsAnalytics.vue
	// Reference: src/components/PushNotificationOptions.vue
	__( 'Analytics', 'coming-soon' ),

	// Reference: src/views/SetupSettings.vue
	// Reference: src/views/SettingsScripts.vue
	__( 'Scripts', 'coming-soon' ),

	// Reference: src/views/SetupSettings.vue
	// Reference: src/views/SettingsDomain.vue
	__( 'Custom Domain', 'coming-soon' ),

	// Reference: src/views/SetupSettings.vue
	// Reference: src/views/SettingsGeneral.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'General', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/SetupBlockOptions-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Editing:', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/Setup.vue
	__( 'Global Settings', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Header Font', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Body Text Font', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Dim Background', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Use Video Background', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	__( 'YouTube URL', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'The video background will not be displayed on mobile devices or in the editor preview.', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Play on auto-loop', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Enter your custom css below', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Edit Custom CSS', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/Setup.vue
	// Reference: src/views/InlineHelpView.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/TypographyControl.vue
	// Reference: src/components/CustomHTMLOptions.vue
	// Reference: src/components/ColorPicker.vue
	__( 'Close', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Color Palettes', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Font Themes Library', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Search colors...', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Search fonts...', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Headers', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WpWidgetBlockOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Text', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Buttons', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Links', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/PostcommentsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Background', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Font Themes', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/CustomHTMLOptions.vue
	__( 'Expand Editor', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Fonts', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/LoginOptions.vue
	__( 'Colors', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Custom CSS', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'All Palettes', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'All Themes', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Serif', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Sans Serif', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Background Slideshow', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Slideshow Images', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Add New Slide', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/views/SetupDesign-Lite.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'The background slideshow will not be shown in the editor preview. The slides will only be displayed in the live preview.', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Pro.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Overlay Color', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Lite.vue
	__( 'Video Background', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/SetupBlockOptions-Lite.vue
	// Reference: src/views/SectionTemplates-Pro.vue
	// Reference: src/views/SectionTemplates-Lite.vue
	__( 'Blocks', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/SetupBlockOptions-Lite.vue
	// Reference: src/views/SectionTemplates-Pro.vue
	// Reference: src/views/SectionTemplates-Lite.vue
	__( 'Sections', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/SetupBlockOptions-Lite.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	__( 'Standard', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/SetupBlockOptions-Lite.vue
	// Reference: src/components/WpWidgetBlockOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TemplatetagOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/StarRatingOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShortcodeOptions.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductPriceOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostnavigationOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/PostcommentsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/MenuCartOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/FormOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EnviraGalleryOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadPriceOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/CustomHTMLOptions.vue
	// Reference: src/components/CounterOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ContactFormOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AdditionalInformationOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Advanced', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/SetupBlockOptions-Lite.vue
	__( 'Saved Blocks', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/SetupBlockOptions-Lite.vue
	__( 'Search blocks...', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/SetupBlockOptions-Lite.vue
	__( 'WooCommerce', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/SetupBlockOptions-Lite.vue
	__( 'Widgets', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	__( 'Template Tags', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	__( 'WooCommerce Template Tags', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/SetupBlockOptions-Lite.vue
	__( 'Easy Digital Downloads', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	__( 'EDD Template Tags', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/SetupBlockOptions-Lite.vue
	__( 'Square Payments', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/Layoutnav.vue
	__( 'Section', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Row', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Pro.vue
	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Column', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Design', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Connect', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/FacebookSettings.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Page Settings', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'You have unsaved changes. Are you sure you want to lose these changes?', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Exit Without Saving', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'template has been saved!', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'You can find it in your template library when you create a new landing page.', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Enter a new template name:', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Your page has been published!', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	// Reference: src/views/SettingsGeneral.vue
	__( 'Publish', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Unpublish', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Schedule', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Save as Template', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Return to Page Editor', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/Section.vue
	// Reference: src/components/Row.vue
	__( 'Save Template', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'See Live Page', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Save and Exit', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Help', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Save', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	// Reference: src/views/Setup.vue
	__( 'Saved!', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	// Reference: src/views/Preview.vue
	__( 'Preview', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'You are about to leave this page and go to the Global CSS page. Continue?', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'This page is not active. Would you like to activate it now?', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Yes, Activate', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'No, Close', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Coming Soon Mode is not active. Would you like to activate it now and show this page to visitors?', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Maintenance Mode is not active. Would you like to activate it now and show this page to visitors?', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Note: This page will only be shown to users who are logged out. If you logged out and and do not see the correct page you may need to clear your site cache.', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'This page is not published. Would you like to publish it now?', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Yes, Publish', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	// Reference: src/views/GlobalCSS.vue
	__( 'Global CSS Settings', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Layout Navigation', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Revision History', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Undo', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Redo', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Hide Sidebar', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Show Sidebar', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Desktop Preview', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Tablet Preview', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Mobile Preview', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Please make sure to perform a Save before saving as a global template. Click OK to proceed. NOTE: You are about to update a live template, updating this template will deactivate it until it is reviewed and made live again.', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Please make sure to perform a Save before saving as a global template. Click OK to proceed.', 'coming-soon' ),

	// Reference: src/views/Setup.vue
	__( 'Something has prevented the page from being saved. Please make sure you are at least an Editor and have the unfiltered_html capability.', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'Header Scripts:', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'This code will be rendered before the closing &lt;/head&gt; tag.', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'Footer Scripts:', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'The code will be rendered before the closing &lt;/body&gt; tag.', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'Body Scripts:', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'The code will be rendered after the &lt;body&gt; tag.', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'You do not have the proper WordPress permissions to add scripts.', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'Pro Tip:', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'Need to add tracking scripts or comply with privacy laws?', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'WPCode', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'lets you safely manage code snippets site-wide without editing theme files, while', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'WPConsent', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue
	__( 'keeps you GDPR/CCPA compliant with customizable cookie consent banners. Get both free!', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	// Reference: src/views/SettingsAnalytics.vue
	__( 'Your SEO settings are being managed by:', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	// Reference: src/views/SettingsSEO.vue
	__( 'Yoast SEO', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	// Reference: src/views/SettingsSEO.vue
	__( 'Install SEO plugin:', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	__( 'Install All in One SEO', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	__( 'Activate All in One SEO', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	__( 'SEO Title', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	__( 'SEO Description', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	__( 'Favicon', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	__( 'Social Media Thumbnail', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	__( 'Enable No Index', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	__( 'Rank Math', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	__( 'The SEO Framework', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	__( 'All in One SEO', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	__( 'All in One SEO Pro', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	// Reference: src/views/SettingsAnalytics.vue
	__( 'Install', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue
	// Reference: src/views/SettingsAnalytics.vue
	__( 'Activate', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Page Title:', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Page Status:', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Draft', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Link', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/EnviraGalleryOptions.vue
	// Reference: src/components/ContactFormOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Show', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Choose New Template:', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Redirect Mode', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Redirect URL: A temporary redirect (302 status) will be created to the url entered.', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Enable', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Redirect URL: A permanent redirect (301 status) will be created to the url entered.', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'SeedProd Link', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Enter Your Affiliate URL and Make Money with SeedProd', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Join our affiliate program', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'and get a 20% commission on all sales generated from your powered by link.', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Isolation Mode', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Redirect the Default Login Page', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Facebook App ID:', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Isolation Mode prevents two WordPress hooks from running called wp_head and wp_footer. This will prevent conflicts with your theme or other plugins. While it prevents conflicts, it also means other plugins would not run on the page such as SEO and analytics plugins. You can manually set these under the SEO and Scripts menus on the left.', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'The Redirect the Default Login Page option should redirect all calls to the default login page which is located at', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'however it does not prevent it from being accessed as that default login page will still be used for password resets, login errors, and registration if that is enabled.', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'Choose Template', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Warning', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue
	__( 'This will delete the current template and content.', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue
	__( 'Custom Domain:', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue
	__( 'OFF', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue
	__( 'ON', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue
	__( 'Domain Name:', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue
	__( 'Please enter your domain.', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue
	__( 'Click here to learn more', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue
	__( 'how to map your custom domain.', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue
	__( 'Force HTTPS', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue
	__( 'Only enable this if you have an SSL certificate installed and you wish to redirect users to https://', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue
	__( 'Please enter a valid URL that will be pointed to this landing page, such as', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue
	__( 'Your Analytics settings are being managed by:', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue
	__( 'Edit Analytics Settings', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue
	__( 'Install Google Analytics plugin:', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue
	__( 'Install MonsterInsights', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue
	__( 'Activate MonsterInsights', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue
	__( 'Pro', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue
	__( 'Installing', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue
	__( 'Install Analytics plugin:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Exclude Default:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ContentToggle-Pro.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Yes', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ContentToggle-Pro.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'No', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'By default we exclude urls with the terms: login, admin, dashboard and account to prevent lockouts.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Bypass Cookie:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	__( 'Use cookies instead of creating a WordPress user for the bypass. Note: this may not work on sites that are cached. Learn More', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Bypass URL:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Bypass URL Expires:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Access by IP:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Access by Role:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'By default anyone logged in will see the regular website and not the coming soon page. To override this select Roles that will be given access to see the regular website.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Include/Exclude URLs:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Show on the Entire Website', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Show on the Entire Website except for the Blog', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Show on the Home Page Only', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Include URLs', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Exclude URLs', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Enter a phrase above and give your visitors a secret url that will allow them to bypass the Coming Soon page.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'After the bypass url expires the user will need to revisit the bypass url to regain access.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'One IP Address per line', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Add Role', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Include certain urls to display the Coming Soon or Maintenance Page.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'One per line. You may also enter a page or post id.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Exclude certain urls to display the Coming Soon or Maintenance Page.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Pro.vue
	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Example: /about-us/', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue
	__( 'Use cookies instead of creating a WordPress user for the bypass. Note: this may not work on sites that are cached. Learn More.', 'coming-soon' ),

	// Reference: src/views/SectionTemplates-Pro.vue
	// Reference: src/views/SectionTemplates-Lite.vue
	__( 'All Sections', 'coming-soon' ),

	// Reference: src/views/SectionTemplates-Pro.vue
	// Reference: src/views/SectionTemplates-Lite.vue
	__( 'Favorites', 'coming-soon' ),

	// Reference: src/views/SectionTemplates-Pro.vue
	// Reference: src/views/SectionTemplates-Lite.vue
	__( 'Categories:', 'coming-soon' ),

	// Reference: src/views/SectionTemplateOptions-Pro.vue
	// Reference: src/views/SectionTemplateOptions-Lite.vue
	__( 'Choose This Section', 'coming-soon' ),

	// Reference: src/views/Revisions.vue
	__( 'Loading Revisions', 'coming-soon' ),

	// Reference: src/views/Revisions.vue
	__( 'Click to preview version:', 'coming-soon' ),

	// Reference: src/views/Revisions.vue
	__( 'Current Version', 'coming-soon' ),

	// Reference: src/views/Revisions.vue
	__( 'by', 'coming-soon' ),

	// Reference: src/views/Revisions.vue
	__( 'There are no revisions to show.', 'coming-soon' ),

	// Reference: src/views/Revisions.vue
	__( 'ago', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Expand All', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Collapse All', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/Section.vue
	__( 'Enter a new section template name:', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/views/BuilderView.vue
	// Reference: src/components/Section.vue
	// Reference: src/components/Row.vue
	__( 'Choose your layout:', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/views/BuilderView.vue
	// Reference: src/components/Section.vue
	__( 'Add Section', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/Section.vue
	__( 'Duplicate Section', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/Section.vue
	__( 'Save Section', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TemplatetagOptions.vue
	// Reference: src/components/ShortcodeOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/FormOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/CustomHTMLOptions.vue
	// Reference: src/components/CounterOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Settings', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/Section.vue
	__( 'Delete Section', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Copy Section', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Paste Section', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/Row.vue
	__( 'Add Row', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/Row.vue
	__( 'Duplicate Row', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/Row.vue
	__( 'Delete Row', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Copy Row', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Paste Row', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Add Column', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Duplicate Column', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Delete Column', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Copy Column', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Paste Column', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/Row.vue
	__( 'Duplicate Block', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	// Reference: src/components/Row.vue
	__( 'Delete Block', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Copy Block', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue
	__( 'Paste Block', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	__( 'SeedProd Logo', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	__( 'Ask a question or search the docs...', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	// Reference: src/components/ColorPicker.vue
	__( 'Clear', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	__( 'No docs found', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	__( 'View Documentation', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	__( 'Browse documentation, reference material, and tutorials for SeedProd.', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	__( 'View All Documentation', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	__( 'Get Support', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	__( 'Submit a ticket and our world class support team will be in touch soon.', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	__( 'Submit a Support Ticket', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	__( 'Upgrade to SeedProd Pro to access our world class customer support', 'coming-soon' ),

	// Reference: src/views/InlineHelpView.vue
	__( 'Upgrade to SeedProd Pro', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Add Custom Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Body Text Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Show H1 - H6 Settings', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/AdditionalInformationOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Header Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H1 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H1 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H2 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H2 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H3 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H3 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H4 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H4 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H5 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H5 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H6 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H6 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Body Text', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Desktop BG', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Mobile BG', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/TypographyControl.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Normal', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Hover', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Layout', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Row Default Max Width', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Forms', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StarRatingOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/HotspotOptions.vue
	__( 'Label', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Label Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Field', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	__( 'Field Text Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	__( 'Field Background Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	__( 'Field Border Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Field Border Style', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BorderSectionControl.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Solid', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BorderSectionControl.vue
	__( 'Dotted', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BorderSectionControl.vue
	__( 'Dashed', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	__( 'Field Border Width', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Field Padding', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Header Default Bottom Margin', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Paragraph Default Bottom Margin', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Label Default Bottom Margin', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Button', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Button Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Button Text Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/LoginOptions.vue
	__( 'Button Font', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	__( 'Button Border Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Gradient', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Button Background Style', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H1 Typography', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H2 Typography', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H3 Typography', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H4 Typography', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H5 Typography', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'H6 Typography', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Body Text Typography', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Link Typography', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Label Typography', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	__( 'Field Typography', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Gradient Type', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Radial', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Linear', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Angle', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/PositionControl.vue
	// Reference: src/components/DisplaySectionControl.vue
	// Reference: src/components/DisplaySectionControl.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Position', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Top Center', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Top Left', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Top Right', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Center Center', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Center Left', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Center Right', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Bottom Center', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Bottom Left', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Bottom Right', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'First Color Location', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Second Color Location', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'First Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Second Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/LoginOptions.vue
	__( 'Button Border Radius', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/LoginOptions.vue
	__( 'Field Border Radius', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ButtonOptions.vue
	__( 'Button Border Width', 'coming-soon' ),

	// Reference: src/views/BuilderView.vue
	// Reference: src/components/Section.vue
	// Reference: src/components/Row.vue
	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	__( 'or', 'coming-soon' ),

	// Reference: src/views/BuilderView.vue
	// Reference: src/components/Section.vue
	// Reference: src/components/Row.vue
	__( 'Drag a new block here', 'coming-soon' ),

	// Reference: src/views/BuilderView.vue
	// Reference: src/components/Section.vue
	// Reference: src/components/Row.vue
	__( 'Add Columns', 'coming-soon' ),

	// Reference: src/views/BuilderView.vue
	__( 'Header Template', 'coming-soon' ),

	// Reference: src/views/BuilderView.vue
	__( 'Footer Template', 'coming-soon' ),

	// Reference: src/views/BuilderView.vue
	__( 'Drag New Block Here', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( 'There is no content available to paste. Please try copy section first!', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	// Reference: src/mixins/helpers.js
	// Reference: src/mixins/helpers.js
	// Reference: src/mixins/helpers.js
	__( 'Image uploading will take some time.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	// Reference: src/mixins/helpers.js
	__( 'Section Uploaded successfully.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	// Reference: src/mixins/helpers.js
	// Reference: src/mixins/helpers.js
	__( 'There is no content available to paste. Please try copy row first!', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	// Reference: src/mixins/helpers.js
	__( 'Block Uploaded successfully.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	// Reference: src/mixins/helpers.js
	__( 'Column Uploaded successfully.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	// Reference: src/mixins/helpers.js
	__( 'Row Uploaded successfully.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( 'Block Copied.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( 'Column Copied.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( 'Row Copied.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( 'Section Copied.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	// Reference: src/mixins/helpers.js
	__( 'Upgrade to PRO', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	// Reference: src/mixins/helpers.js
	__( 'Increase traffic, engagement, and get more email subscribers. Click below to learn more about all our awesome features.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( ' is a PRO Feature', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( ' feature is not available on your plan. Please upgrade to the PRO plan to unlock all these awesome features.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( 'UPGRADE TO PRO', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( '<strong>Bonus:</strong>&nbsp;SeedProd Lite users get a discount off the regular price, automatically applied at checkout.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( 'Upgrade to Unlock ', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( ' feature is not available on your plan. Please upgrade your plan to unlock this feature and more!', 'coming-soon' ),

	// Reference: src/mixins/helpers.js
	__( 'Upgrade with just a click of a button!', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Heading Color', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StarRatingOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/EnviraGalleryOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/ContactFormOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AdditionalInformationOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Text Color', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue
	// Reference: src/components/ListTable.vue
	__( 'Apply', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TemplatetagOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/StarRatingOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShortcodeOptions.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductPriceOptions.vue
	// Reference: src/components/ProductPrice-Pro.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostnavigationOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/PostcommentsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/MenuCartOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/FormOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EnviraGalleryOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadPriceOptions.vue
	// Reference: src/components/EDDDownloadPrice-Pro.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/CustomHTMLOptions.vue
	// Reference: src/components/CounterOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ContactFormOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AdditionalInformationOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Content', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue
	__( 'Widget Settings', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/StarRatingOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/MenuCartOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/CounterOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Styles', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue
	__( 'Heading Bottom Margin', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Heading', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue
	__( 'Heading Typography', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Text Typography', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	__( 'Fields', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Alerts', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Cart', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Payment Section', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Choose Your Style', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Light Input Field', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'No Border Input Field', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Wide Border Input Field', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Inner Shadow Input Field', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Grey Input Field', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Dark Input Field', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Bottom Border Field', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Transparent Input Field', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'One Column', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Two Column', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Label Font', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	__( 'Row Spacing', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Button Style', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BorderSectionControl.vue
	// Reference: src/components/BorderRadiusControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Border Radius', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Flat', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( '2D', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Vintage', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Ghost', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Info Highlight Color', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Error Highlight Color', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Success Highlight Color', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Cart Border Color', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Cart Border Width', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Background Color', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/TypographyControl.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Font Family', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Header Background Color', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Header Font Family', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Query', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SpacingSectionControl.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Spacing', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Columns', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'All Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Pagination', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Show Order By', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Show Items Count', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/ShapeDividerControl.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Type', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Featured Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Sale Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Best Selling Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Recent Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Top Rated Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Include', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Exclude', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Include By', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Exclude By', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Term', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Order By', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Order', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Date', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/CounterOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Title', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Price', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Popularity', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/StarRatingOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Rating', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Random', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Menu Order', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'ASC', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'DESC', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TypographyControl.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Alignment', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Description', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Price Color', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Button Size', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Small', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Medium', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Large', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'X Large', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( '2X Large', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Image', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Shadow', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/BorderSectionControl.vue
	__( 'Border Style', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShapeDividerControl.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'None', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Hairline', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	__( 'Bottom Drop Shadow', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Image Border Color', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Image Border Width', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShapeDividerControl.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/PaddingControl.vue
	// Reference: src/components/MarginControl.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/DisplaySectionControl.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/BorderWidthControl.vue
	// Reference: src/components/BorderRadiusControl.vue
	// Reference: src/components/AnimationEffectControl.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Top', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/PaddingControl.vue
	// Reference: src/components/MarginControl.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/DisplaySectionControl.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/BorderWidthControl.vue
	// Reference: src/components/BorderRadiusControl.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Right', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShapeDividerControl.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/PaddingControl.vue
	// Reference: src/components/MarginControl.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/DisplaySectionControl.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/BorderWidthControl.vue
	// Reference: src/components/BorderRadiusControl.vue
	// Reference: src/components/AnimationEffectControl.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Bottom', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/PaddingControl.vue
	// Reference: src/components/MarginControl.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/DisplaySectionControl.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/BorderWidthControl.vue
	// Reference: src/components/BorderRadiusControl.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Left', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	__( 'Image Whitespace Padding', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	__( 'Limit', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( '- Select Options -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'ID', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	__( 'Select By SKU', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	__( '- Select SKU(s) -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Select By Category', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( '- Select Categories -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Select By Tags', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( '- Select Tags -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Select By Group', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( '- Select Group -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	__( 'On Sale', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	__( 'Best Selling', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	__( 'Top Rated', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	__( 'Query By Attribute', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	__( '- Select Attribute -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	__( '- Select Attribute Terms -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Include Selected Terms', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Exclude Selected Terms', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Include Selected Tags', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Exclude Selected Tags', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Include Selected Categories', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Exclude Selected Categories', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	__( 'Select By Visibility', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	__( '- Select Product Visibility -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/DisplaySectionControl.vue
	__( 'Visible', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Catalog', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Search', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/DisplaySectionControl.vue
	__( 'Hidden', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Featured', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Custom Query', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Select By ID', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( '- Select ID(s) -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	__( 'Sale Badge Color', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Archive Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Description Typography', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Price Typography', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue
	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Button Typography', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGrid-Pro.vue
	__( 'Products Preview Not Available', 'coming-soon' ),

	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/CounterOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Templates', 'coming-soon' ),

	// Reference: src/components/WCCheckoutOptions.vue
	// Reference: src/components/WCCartOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/FontControl.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	// Reference: src/components/CounterOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Default', 'coming-soon' ),

	// Reference: src/components/WCCart-Pro.vue
	__( 'PLACEHOLDER', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Button Text', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/ButtonOptions.vue
	__( 'Button Sub Text', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	__( 'Open In New Window', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/StarRatingOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Size', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Vertical Padding', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Horizontal Padding', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Icons', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Before Text Icon', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'After Text Icon', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Tiny', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Pill Button', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Flat Button', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Blue Button', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Light Green Button', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Green Button', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Orange Button', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Red Button', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Yellow Button', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'White Button', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Grey Button', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Black Button', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Text Shadow', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	__( 'Product ID', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	__( 'Direct To Checkout', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	__( 'Video', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Source', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	__( 'YouTube', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/StripepaymentOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/ButtonOptions.vue
	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/AddToCartOptions.vue
	__( 'Custom', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	__( 'Custom Video Code', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/VideoOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShapeDividerControl.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Width', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Vimeo URL', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Vimeo', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Start Time', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Specify a start time (in seconds)', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/CountdownOptions.vue
	__( 'End Time', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Specify an end time (in seconds)', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'External URL', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Custom Video URL', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Select Custom Video', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Video Options', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	__( 'Autoplay', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Mute', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Loop', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Show Player Controls', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Show Download Button', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Preload', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Metadata', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/DisplaySectionControl.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Auto', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Preload attribute lets you specify how the video should be loaded when the page loads.', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Learn more here.', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Poster', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Image Overlay', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Choose Image', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Image Size', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SpacerOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ShapeDividerControl.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/HeightControl.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/DividerOptions.vue
	__( 'Height', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	__( 'PX', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Show Play Icon', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Enable Lightbox', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Enable Sticky Video', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Enable Image Overlay', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Play on Mobile', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Modest Branding', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Privacy Mode', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Lazy Load', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Suggested Videos', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Current Video Channel', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Any Video', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Intro Title', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Intro Portrait', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Intro Byline', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Controls Color', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Play video inline on mobile devices instead of automatically going into fullscreen mode.', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Icon Font Size', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Icon Opacity', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	__( 'Icon Color', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Click on Preview and scroll past the video on the page to see this in action.', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Aspect Ratio', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( '1:1', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( '3:2', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( '4:3', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( '9:16', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( '16:9', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( '21:9', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Teaser Video', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Enable Teaser Video', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Show Banner', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Disabled because Teaser Video feature has been enabled.', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Disabled because Image Overlay feature has been enabled.', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Banner Text', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Banner Background Color', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Banner Text Color', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Banner Text Typography', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Banner Text Icon', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Teaser Video Play Icon', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Video must be hosted by a Starter, Standard, Advanced, Plus, Pro, Business, Premium, or Enterprise account.', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Image Src', 'coming-soon' ),

	// Reference: src/components/VideoPopUpOptions.vue
	__( 'Poster Image Src', 'coming-soon' ),

	// Reference: src/components/VideoPopUp-Pro.vue
	__( 'Select a Video or Add Video URL', 'coming-soon' ),

	// Reference: src/components/VideoControl.vue
	__( 'Choose New Video', 'coming-soon' ),

	// Reference: src/components/VideoControl.vue
	__( 'Select Video', 'coming-soon' ),

	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/CounterOptions.vue
	__( 'Title Typography', 'coming-soon' ),

	// Reference: src/components/UpsellsOptions.vue
	// Reference: src/components/ProductRelatedOptions.vue
	__( 'Posts Per Page', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Dismiss this message', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Get SeedProd Lite and Unlock all the Powerful Features', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Thanks for being a loyal SeedProd Lite user. Upgrade to
SeedProd Lite to unlock all the awesome features and
experience why SeedProd is the best WordPress landing
page plugin.', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Pro Features:', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Drag & Drop Page Builder', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( '80+ PRO Page Blocks', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'PRO Email Marketing Integrations', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Custom 404 Pages', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Page Access Controls', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( '200+ PRO Page Templates', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'PRO Smart Sections', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Email Subscriber Management', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Plus much more...', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Bonus:', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'SeedProd Lite users get', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'a discount off the regular price', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'automatically applied at checkout.', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTAUpgrade.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Get SeedProd Lite Today and Unlock all the Powerful Features »', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	__( 'is not available, upgrade to unlock', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	__( 'is not available on your plan. Please upgrade to a higher plan to access this feature.', 'coming-soon' ),

	// Reference: src/components/UpgradeCTABuilder.vue
	__( 'Upgrade Your License', 'coming-soon' ),

	// Reference: src/components/TypographyControl.vue
	__( 'Typography', 'coming-soon' ),

	// Reference: src/components/TypographyControl.vue
	__( 'Edit', 'coming-soon' ),

	// Reference: src/components/TypographyControl.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/FontSizeControl.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Font Size', 'coming-soon' ),

	// Reference: src/components/TypographyControl.vue
	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Line Height', 'coming-soon' ),

	// Reference: src/components/TypographyControl.vue
	__( 'Letter Spacing', 'coming-soon' ),

	// Reference: src/components/TypographyControl.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Style', 'coming-soon' ),

	// Reference: src/components/TypographyControl.vue
	__( 'Letter Case', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Hide Header', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Hide Footer', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Hide Borders', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Transparent', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Hide Scrollbar', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Show Replies', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Target Url', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Current Page', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'X (Twitter) Handle', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Url Format', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Plain Permalink', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Pretty Permalink', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'X (Twitter) Setting', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Facebook App Id:', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Like', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Recommend', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	__( 'Url', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	__( 'Hashtags', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	__( 'Via', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	__( 'Related', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Color Scheme', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Light', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Dark', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Language', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TextOptions.vue
	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/ShapeDividerControl.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/ProgressBarOptions.vue
	// Reference: src/components/ProductPriceOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostnavigationOptions.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/MenuCartOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/EDDDownloadPriceOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Color', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/BorderSectionControl.vue
	__( 'Border Color', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Automatic', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'English (default)', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Arabic', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Bengali', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Czech', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Danish', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'German', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Greek', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Spanish', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Persian', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Finnish', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Filipino', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'French', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Hebrew', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Hindi', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Hungarian', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Indonesian', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Italian', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Japanese', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Korean', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Malay', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Dutch', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Norwegian', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Polish', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Portuguese', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Romanian', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Russian', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Swedish', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Thai', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Turkish', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Ukrainian', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Urdu', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Vietnamese', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Chinese (Simplified)', 'coming-soon' ),

	// Reference: src/components/TwitterTweetButtonOptions.vue
	// Reference: src/components/TwitterFollowButtonOptions.vue
	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Chinese (Traditional)', 'coming-soon' ),

	// Reference: src/components/TwitterFollowButtonOptions.vue
	__( 'X (Twitter) Screen Name', 'coming-soon' ),

	// Reference: src/components/TwitterFollowButtonOptions.vue
	__( 'Show Screen Name', 'coming-soon' ),

	// Reference: src/components/TwitterFollowButtonOptions.vue
	__( 'Show Count', 'coming-soon' ),

	// Reference: src/components/TwitterEmbedTweetOptions.vue
	__( 'Hide Conversation', 'coming-soon' ),

	// Reference: src/components/TwitterEmbedTweetOptions.vue
	__( 'Hide Photos/Videos/Cards', 'coming-soon' ),

	// Reference: src/components/TwitterEmbedTweetOptions.vue
	__( 'Tweet ID', 'coming-soon' ),

	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	__( 'Button Count', 'coming-soon' ),

	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Box Count', 'coming-soon' ),

	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/FacebookSettings.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Set your Facebook App ID in the ', 'coming-soon' ),

	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/FacebookSettings.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'You are connected to Facebook App', 'coming-soon' ),

	// Reference: src/components/TwitterEmbedTweetOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Change App', 'coming-soon' ),

	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	__( 'Deprecation Notice', 'coming-soon' ),

	// Reference: src/components/TwitterEmbedTimelineOptions.vue
	// Reference: src/components/TwitterEmbedTimeline-Pro.vue
	__( 'X(Twitter) has silently deprecated the Timeline feature. This block will be deprecated in a future update.', 'coming-soon' ),

	// Reference: src/components/TwitterEmbedTimeline-Pro.vue
	__( 'Deprecated Block', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/LiteCTASubscribers.vue
	__( 'Filter by Page', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/LiteCTASubscribers.vue
	__( 'Export to a CSV File', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/LiteCTASubscribers.vue
	__( 'Premium Email Marketing Integrations', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/LiteCTASubscribers.vue
	__( 'Subscribers Over Time', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/LiteCTASubscribers.vue
	__( 'See Names and Emails', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	__( 'This Feature Is Not Available in Your Current Plan', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	__( 'Use SeedProd to Build Your Entire Website and Create Your Theme', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	__( 'Create Headers &amp; Footers', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	__( 'Create Global Parts', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	__( 'Includes Starter Theme', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	// Reference: src/components/ThemeBuilderUpsell.vue
	__( 'Create Pages and Posts', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsellPro.vue
	__( 'View Available Upgrades', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Upgrade to SeedProd PRO Now', 'coming-soon' ),

	// Reference: src/components/ThemeBuilderUpsell.vue
	// Reference: src/components/SettingsLiteCTA.vue
	// Reference: src/components/LiteCTATemplates.vue
	// Reference: src/components/LiteCTASubscribers.vue
	// Reference: src/components/LiteCTABuilder.vue
	__( 'Special Upgrade Offer - Save 50% Off', 'coming-soon' ),

	// Reference: src/components/TextOptions.vue
	// Reference: src/components/PostcommentsOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/DynamicTextControl.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Insert Dynamic Text', 'coming-soon' ),

	// Reference: src/components/TextOptions.vue
	__( 'Visual Editor', 'coming-soon' ),

	// Reference: src/components/TextOptions.vue
	__( 'Edit HTML', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SearchFormOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Icon', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	__( 'Name Color', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Add Testimonial', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/AnchorOptions.vue
	__( 'Name', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Navigation Color Mode', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'AutoPlay', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Pause On Hover', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Autoplay Speed', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	__( 'Testimonial to Show', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'seconds', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Enable Comment Bubble', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Bubble Color', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	__( 'Testimonials', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Carousel Settings', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	__( 'Name Typography', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue
	__( 'Show Image', 'coming-soon' ),

	// Reference: src/components/TemplatetagOptions.vue
	// Reference: src/components/Templatetag-Pro.vue
	__( 'Template Tag', 'coming-soon' ),

	// Reference: src/components/TemplatetagOptions.vue
	__( 'Show Template Tag Preview', 'coming-soon' ),

	// Reference: src/components/TemplatetagOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Select Type', 'coming-soon' ),

	// Reference: src/components/Templatetag-Pro.vue
	__( 'Enter Your Template Tag', 'coming-soon' ),

	// Reference: src/components/Templatetag-Pro.vue
	__( '(This template tag will be rendered on the live preview.)', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Striped Effect Template', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Divider Template', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Background Template', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Show Designation', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	__( 'Designation', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Show Description', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( '%', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/CounterOptions.vue
	__( 'Separator', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Below Name', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Below Designation', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Below Description', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Thickness', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Social Icons', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/FormOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Add New Item', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Shape', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PriceListOptions.vue
	__( 'Rounded', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Circle', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Icon Padding', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/StarRatingOptions.vue
	// Reference: src/components/SpaceBetweenControl.vue
	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ProductPriceOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/CountdownOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/AddToCartOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Space Between', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Date Align', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Time Align', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'List Layout', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Vertical', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/ColOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Horizontal', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SpacingSectionControl.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Top Margin', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Style Day/Time', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Designation Color', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Description Color', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Day Color', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Time Color', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Divider', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Divider Color', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Weight', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Day and Time', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Striped Effect', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Striped Odd Rows Color', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Striped Even Rows Color', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Image Position', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TeamMemberOptions.vue
	__( 'Separator Align', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Social Icon Align', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Separator Margin Bottom', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Designation Align', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Designation Margin Bottom', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Description Align', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Name Align', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Name Margin Bottom', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Description Margin Bottom', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PriceListOptions.vue
	__( 'Image Area', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Title Tag', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/DividerOptions.vue
	__( 'H1', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/DividerOptions.vue
	__( 'H2', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/DividerOptions.vue
	__( 'H3', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/DividerOptions.vue
	__( 'H4', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'H5', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'H6', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	__( 'div', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/DividerOptions.vue
	__( 'span', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostauthorboxOptions.vue
	__( 'p', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	__( 'Alt Text', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Designation Typography', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Image Margin Bottom', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PaddingControl.vue
	// Reference: src/components/BusinessHoursOptions.vue
	// Reference: src/components/BulletListOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Padding', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/PriceListOptions.vue
	__( 'Image Border Radius', 'coming-soon' ),

	// Reference: src/components/TeamMemberOptions.vue
	__( 'Social Icon Border Radius', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Container Padding', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Title Styles', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Link Styles', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Container Styles', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/PostsOptions.vue
	__( 'Show Title', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Title Text', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Include Headings', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Comma-separated list (e.g., h2,h3,h4)', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Content Container', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'CSS selector for the container to scan for headings', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Exclude Selectors', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'CSS selectors to exclude from TOC (comma-separated)', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Show Numbers', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Hierarchical Numbering', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Smooth Scroll', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Scroll Offset (px)', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Title Font Size', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Title Color', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Title Spacing', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Link Font Size', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Link Color', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/LoginOptions.vue
	__( 'Link Hover Color', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Link Decoration', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Link Hover Decoration', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Item Spacing', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'List Indent', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Container Width', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'List Style', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Underline', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Disc', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	__( 'Square', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Decimal', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/LoginOptions.vue
	__( 'Additional Options', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Minimize Box', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Expand Icon', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Collapse Icon', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	__( 'Collapse Subitems', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/DisplaySectionControl.vue
	__( 'Absolute', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/DisplaySectionControl.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Fixed', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/HotspotOptions.vue
	__( 'Horizontal Orientation', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/HotspotOptions.vue
	__( 'Vertical Orientation', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/DisplaySectionControl.vue
	__( 'Offset', 'coming-soon' ),

	// Reference: src/components/TableOfContentsOptions.vue
	// Reference: src/components/DisplaySectionControl.vue
	__( 'Z-Index', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Note:', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'This is a placeholder preview.The table of contents will be dynamically generated from the actual headings on your page.', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Position Notice:', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Fixed and Absolute positioning will be applied in preview and frontend only. The builder shows the default layout for easier editing.', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Loading table of contents...', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'No headings found', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Introduction', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Getting Started', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Overview', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Main Content', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Section A', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Subsection', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Section B', 'coming-soon' ),

	// Reference: src/components/TableOfContents-Pro.vue
	__( 'Conclusion', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	// Reference: src/components/FacebookPageOptions.vue
	__( 'Tabs', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Tab Layout', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Tab Name', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	__( 'Tab Color', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Hide Tab Icon', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	__( 'Tab Background Color', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Tab Border Radius', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Content Border Radius', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Content Border Style', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Content Border Color', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Content Border Width', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	// Reference: src/components/BorderWidthControl.vue
	// Reference: src/components/BorderSectionControl.vue
	__( 'Border Width', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Tab', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Active Tab Color', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Active Tab Background', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Content Background', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Delete', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Duplicate', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Tab Typography', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Content Typography', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Tab ', 'coming-soon' ),

	// Reference: src/components/TabbedLayoutOptions.vue
	__( 'Tab Content', 'coming-soon' ),

	// Reference: src/components/SuperScriptControl.vue
	__( 'SuperScript Top', 'coming-soon' ),

	// Reference: src/components/StripepaymentOptions.vue
	__( 'Connect with Stripe', 'coming-soon' ),

	// Reference: src/components/StripepaymentOptions.vue
	__( 'Connect with', 'coming-soon' ),

	// Reference: src/components/StripepaymentOptions.vue
	__( 'Reconnect', 'coming-soon' ),

	// Reference: src/components/StripepaymentOptions.vue
	__( 'Connect or Create your Stripe account to start collecting payments.', 'coming-soon' ),

	// Reference: src/components/StripepaymentOptions.vue
	__( 'Pay as you go pricing: 3% fee per-transaction + Stripe fees', 'coming-soon' ),

	// Reference: src/components/StripepaymentOptions.vue
	__( 'Payment Setup', 'coming-soon' ),

	// Reference: src/components/StripepaymentOptions.vue
	__( 'Amount', 'coming-soon' ),

	// Reference: src/components/StripepaymentOptions.vue
	__( 'Payment Description', 'coming-soon' ),

	// Reference: src/components/StripepaymentOptions.vue
	__( 'Payment Currency', 'coming-soon' ),

	// Reference: src/components/StripepaymentOptions.vue
	__( 'Success URL', 'coming-soon' ),

	// Reference: src/components/StarRatingOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Star Rating', 'coming-soon' ),

	// Reference: src/components/StarRatingOptions.vue
	// Reference: src/components/AnimationEffectControl.vue
	__( 'Scale', 'coming-soon' ),

	// Reference: src/components/StarRatingOptions.vue
	__( 'Star Color', 'coming-soon' ),

	// Reference: src/components/StarRatingOptions.vue
	__( 'Empty Star Color', 'coming-soon' ),

	// Reference: src/components/SpacerOptions.vue
	__( 'Spacer', 'coming-soon' ),

	// Reference: src/components/SocialSharingOptions.vue
	__( 'Social Sharing', 'coming-soon' ),

	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Add New Share', 'coming-soon' ),

	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Select a Type', 'coming-soon' ),

	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Facebook', 'coming-soon' ),

	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	__( 'X (Twitter)', 'coming-soon' ),

	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	__( 'LinkedIn', 'coming-soon' ),

	// Reference: src/components/SocialSharingOptions.vue
	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Pinterest', 'coming-soon' ),

	// Reference: src/components/SocialSharingOptions.vue
	__( 'Tweet Text', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Instagram', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Snapchat', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'WordPress', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Github', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'SoundCloud', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'RSS', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/Form-Pro.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Email', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'URL (Include https:// for web links)', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/ProductPriceOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	__( 'Stacked', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Icon Size', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Phone', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Discord', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Telegram', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Facebook Messenger', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Slack', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'Weibo', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'WhatsApp', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue
	__( 'TikTok', 'coming-soon' ),

	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/ImageBorderControl.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	__( 'Image Border', 'coming-soon' ),

	// Reference: src/components/SiteLogoOptions.vue
	// Reference: src/components/ProductFeaturedImageOptions.vue
	// Reference: src/components/PostfeaturedimageOptions.vue
	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/IconOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/EDDDownloadFeaturedImageOptions.vue
	__( 'No Follow', 'coming-soon' ),

	// Reference: src/components/SiteLogoOptions.vue
	__( 'Edit Site Identity', 'coming-soon' ),

	// Reference: src/components/ShortcodeOptions.vue
	// Reference: src/components/Shortcode-Pro.vue
	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Shortcode', 'coming-soon' ),

	// Reference: src/components/ShortcodeOptions.vue
	__( 'Show Shortcode Preview', 'coming-soon' ),

	// Reference: src/components/Shortcode-Pro.vue
	__( 'Enter Your Shortcode', 'coming-soon' ),

	// Reference: src/components/Shortcode-Pro.vue
	// Reference: src/components/Mypaykit.vue
	// Reference: src/components/Giveaway.vue
	// Reference: src/components/EnviraGallery.vue
	// Reference: src/components/ContactForm.vue
	__( '(This shortcode will be rendered on the live preview.)', 'coming-soon' ),

	// Reference: src/components/ShortDescription-Pro.vue
	__( 'Short Description Preview Not Available', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Shape Divider', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Mountains', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Drops', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Clouds', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Zigzag', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Pyramids', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Triangle', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Triangle Asymmetrical', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Tilt', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Tilt Opacity', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Fan Opacity', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Curve', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Curve Asymmetrical', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Waves', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Waves Brush', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Waves Pattern', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Arrow', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Split', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Book', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	// Reference: src/components/AnimationEffectControl.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Flip', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Invert', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue
	__( 'Bring to Front', 'coming-soon' ),

	// Reference: src/components/ShadowControl.vue
	// Reference: src/components/AnimationEffectControl.vue
	__( 'Blur', 'coming-soon' ),

	// Reference: src/components/ShadowControl.vue
	__( 'Spread', 'coming-soon' ),

	// Reference: src/components/ShadowControl.vue
	__( 'Outline', 'coming-soon' ),

	// Reference: src/components/ShadowControl.vue
	__( 'Inset', 'coming-soon' ),

	// Reference: src/components/SettingsLiteCTA.vue
	__( 'Powerful Page Editor', 'coming-soon' ),

	// Reference: src/components/SettingsLiteCTA.vue
	__( 'Email Marketing Integrations', 'coming-soon' ),

	// Reference: src/components/SettingsLiteCTA.vue
	__( 'Access Controls', 'coming-soon' ),

	// Reference: src/components/SettingsLiteCTA.vue
	__( 'Subscriber Management', 'coming-soon' ),

	// Reference: src/components/SettingsLiteCTA.vue
	__( 'Upgrade to SeedProd Pro<br />Today and Save', 'coming-soon' ),

	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	__( 'Template Part', 'coming-soon' ),

	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	__( 'Select Part', 'coming-soon' ),

	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	__( 'No template parts available in SeedProd', 'coming-soon' ),

	// Reference: src/components/SeedProdTemplatePartsOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	__( 'Edit This Template Part', 'coming-soon' ),

	// Reference: src/components/SeedProdTemplateParts-Pro.vue
	// Reference: src/components/ContentToggle-Pro.vue
	__( 'No template parts available.', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Caption Align', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/AdditionalInformationOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Header Typography', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Caption Color', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Add Galleries', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Gallery Images', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Background Overlay', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Slider Image Styles', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/HotspotOptions.vue
	__( 'Image Shadow', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Media File', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	__( 'Custom URL', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/ImageOptions.vue
	__( 'Custom Link', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Grid', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Justified', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Row Height', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Single', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Multiple', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Upload Images', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Thumbnail', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Caption', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Alt', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	// Reference: src/components/SeedProdGalleryOptions.vue
	__( 'Overlay', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	__( 'Tab Styles', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	__( 'Hover Color', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	__( 'Hover Background Color', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	__( 'Left Margin', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	__( 'Active Color', 'coming-soon' ),

	// Reference: src/components/SeedProdGalleryOptions.vue
	__( 'Active Background Color', 'coming-soon' ),

	// Reference: src/components/SeedProdGallery-Pro.vue
	// Reference: src/components/SeedProdBasicGallery-Pro.vue
	__( 'Gallery Not Available', 'coming-soon' ),

	// Reference: src/components/SeedProdGallery-Pro.vue
	// Reference: src/components/SeedProdBasicGallery-Pro.vue
	__( 'Please add gallery images.', 'coming-soon' ),

	// Reference: src/components/SeedProdGallery-Pro.vue
	// Reference: src/components/SeedProdBasicGallery-Pro.vue
	__( 'Loading Gallery Preview', 'coming-soon' ),

	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Attachment', 'coming-soon' ),

	// Reference: src/components/SeedProdBasicGalleryOptions.vue
	__( 'Lightbox', 'coming-soon' ),

	// Reference: src/components/SectionOptions.vue
	__( 'Section Width', 'coming-soon' ),

	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/RowOptions.vue
	__( 'Full Screen', 'coming-soon' ),

	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/RowOptions.vue
	__( 'Fixed Width', 'coming-soon' ),

	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/RowOptions.vue
	__( 'Content Width', 'coming-soon' ),

	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/EnviraGalleryOptions.vue
	// Reference: src/components/ContactFormOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Advanced Styles', 'coming-soon' ),

	// Reference: src/components/SectionOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/BorderSectionControl.vue
	__( 'Border', 'coming-soon' ),

	// Reference: src/components/Section.vue
	__( 'Move Section', 'coming-soon' ),

	// Reference: src/components/Section.vue
	__( 'Section Settings', 'coming-soon' ),

	// Reference: src/components/Section.vue
	__( 'Save Global Section', 'coming-soon' ),

	// Reference: src/components/SearchFormOptions.vue
	__( 'Search Form Setting', 'coming-soon' ),

	// Reference: src/components/SearchFormOptions.vue
	__( 'Placeholder', 'coming-soon' ),

	// Reference: src/components/SearchFormOptions.vue
	__( 'Button Type', 'coming-soon' ),

	// Reference: src/components/SearchFormOptions.vue
	__( 'Search Background', 'coming-soon' ),

	// Reference: src/components/SearchFormOptions.vue
	__( 'Search Text Color', 'coming-soon' ),

	// Reference: src/components/SearchFormOptions.vue
	__( 'Button Background', 'coming-soon' ),

	// Reference: src/components/SearchForm-Pro.vue
	// Reference: src/components/AnchorOptions.vue
	// Reference: src/components/Anchor-Pro.vue
	__( 'Anchor', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	__( 'Column Gutter', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Content Alignment', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/NavOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Simple', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Display', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Flex Direction', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Justify Content', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Align Items', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Flex Start', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Center', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Flex End', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Space Around', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Space Evenly', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Baseline', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	// Reference: src/components/ColOptions.vue
	__( 'Stretch', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue
	__( 'Row Width', 'coming-soon' ),

	// Reference: src/components/Row.vue
	__( 'Enter a new block template name:', 'coming-soon' ),

	// Reference: src/components/Row.vue
	__( 'Row Settings', 'coming-soon' ),

	// Reference: src/components/Row.vue
	__( 'Move Row', 'coming-soon' ),

	// Reference: src/components/Row.vue
	__( 'Resize Columns', 'coming-soon' ),

	// Reference: src/components/Row.vue
	__( 'Column Settings', 'coming-soon' ),

	// Reference: src/components/Row.vue
	__( 'Move Block', 'coming-soon' ),

	// Reference: src/components/Row.vue
	__( 'Block Settings', 'coming-soon' ),

	// Reference: src/components/Row.vue
	__( 'Save Block', 'coming-soon' ),

	// Reference: src/components/Row.vue
	__( 'Add Block', 'coming-soon' ),

	// Reference: src/components/PushNotificationOptions.vue
	__( 'PushEngage', 'coming-soon' ),

	// Reference: src/components/PushNotificationOptions.vue
	__( 'PushEngage allows you to send personalized campaigns to your website visitors and gives you an easy way to collect subscribers. It’s a marketing plugin that helps you get more web push notification subscribers, increase sales, and grow your business.', 'coming-soon' ),

	// Reference: src/components/PushNotificationOptions.vue
	__( 'Visit Dashboard', 'coming-soon' ),

	// Reference: src/components/PushNotificationOptions.vue
	__( 'Push Broadcasts', 'coming-soon' ),

	// Reference: src/components/PushNotificationOptions.vue
	__( 'Drip Autoresponders', 'coming-soon' ),

	// Reference: src/components/PushNotificationOptions.vue
	__( 'Audience', 'coming-soon' ),

	// Reference: src/components/PushNotificationOptions.vue
	__( 'Documentation', 'coming-soon' ),

	// Reference: src/components/PushNotification.vue
	__( 'Install Push Notifications Plugin:', 'coming-soon' ),

	// Reference: src/components/PushNotification.vue
	__( 'PushEngage Installed and Activated', 'coming-soon' ),

	// Reference: src/components/PushNotification.vue
	__( 'Install PushEngage', 'coming-soon' ),

	// Reference: src/components/PushNotification.vue
	__( 'Activate PushEngage', 'coming-soon' ),

	// Reference: src/components/PushNotification.vue
	// Reference: src/components/ContactForm.vue
	__( 'Contact Form', 'coming-soon' ),

	// Reference: src/components/ProgressBarOptions.vue
	__( 'Progress Bar', 'coming-soon' ),

	// Reference: src/components/ProgressBarOptions.vue
	__( 'Bar Text', 'coming-soon' ),

	// Reference: src/components/ProgressBarOptions.vue
	__( 'Percent', 'coming-soon' ),

	// Reference: src/components/ProgressBarOptions.vue
	__( 'My Text', 'coming-soon' ),

	// Reference: src/components/ProductTitle-Pro.vue
	__( 'Product Title Preview Not Available', 'coming-soon' ),

	// Reference: src/components/ProductStock-Pro.vue
	__( 'Product Stock Preview Not Available', 'coming-soon' ),

	// Reference: src/components/ProductRelated-Pro.vue
	__( 'Product Related Preview Not Available', 'coming-soon' ),

	// Reference: src/components/ProductRating-Pro.vue
	__( 'Product Rating Preview Not Available', 'coming-soon' ),

	// Reference: src/components/ProductPriceOptions.vue
	__( 'Sale Price', 'coming-soon' ),

	// Reference: src/components/ProductPriceOptions.vue
	__( 'Sale Price Typography', 'coming-soon' ),

	// Reference: src/components/ProductPrice-Pro.vue
	__( 'Product Price Preview Not Available', 'coming-soon' ),

	// Reference: src/components/ProductMetaOptions.vue
	__( 'View', 'coming-soon' ),

	// Reference: src/components/ProductMetaOptions.vue
	__( 'Table', 'coming-soon' ),

	// Reference: src/components/ProductMetaOptions.vue
	__( 'Inline', 'coming-soon' ),

	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	__( 'Add Item', 'coming-soon' ),

	// Reference: src/components/ProductMetaOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	__( 'Layout Settings', 'coming-soon' ),

	// Reference: src/components/ProductMetaOptions.vue
	__( 'Divider Typography', 'coming-soon' ),

	// Reference: src/components/ProductMeta-Pro.vue
	__( 'Product Meta Preview Not Available', 'coming-soon' ),

	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Panel', 'coming-soon' ),

	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Active', 'coming-soon' ),

	// Reference: src/components/ProductGalleryImagesOptions.vue
	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Panel Padding', 'coming-soon' ),

	// Reference: src/components/ProductGalleryImagesOptions.vue
	__( 'Zoom Button', 'coming-soon' ),

	// Reference: src/components/ProductGalleryImagesOptions.vue
	__( 'Position Right', 'coming-soon' ),

	// Reference: src/components/ProductGalleryImagesOptions.vue
	__( 'Position Top', 'coming-soon' ),

	// Reference: src/components/ProductGalleryImagesOptions.vue
	__( 'Thumbnails Border', 'coming-soon' ),

	// Reference: src/components/ProductGalleryImagesOptions.vue
	__( 'Thumbnails Border Radius', 'coming-soon' ),

	// Reference: src/components/ProductGalleryImagesOptions.vue
	__( 'Thumbnails Border Width', 'coming-soon' ),

	// Reference: src/components/ProductGalleryImages-Pro.vue
	__( 'Product Gallery Images Preview Not Available', 'coming-soon' ),

	// Reference: src/components/ProductFeaturedImage-Pro.vue
	__( 'Product Featured Image Preview Not Available', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Panel Typography', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Panel Header Typography', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Panel Shadow', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Panel Border Radius', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Panel Border Width', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue
	__( 'Panel Border', 'coming-soon' ),

	// Reference: src/components/ProductDataTabs-Pro.vue
	__( 'Product Data Tabs Preview Not Available', 'coming-soon' ),

	// Reference: src/components/ProductContent-Pro.vue
	__( 'Product Content Preview Not Available', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Features List', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Plan Name', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Currency Symbol', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/AdditionalInformationOptions.vue
	__( 'Header', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	__( 'Regular Price', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/PricingTableOptions.vue
	__( 'Plan Name Typography', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Plan Name Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Top Button Size', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Top Button', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Bottom Button', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Top Size', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Top Button Before Text Icon', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Top Button After Text Icon', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Regular Price Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/AccordionOptions.vue
	__( 'Header Open Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Top Button Border Radius', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Bottom Button Border Radius', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '$ Dollar', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '€ Euro', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '฿ Baht', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '₣ Franc', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'ƒ Guilder', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'kr Krona', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '₤ Lira', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '₧ Peseta', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '₱ Peso', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '£ Pound Sterling', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'R$ Real', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '₽ Ruble', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '₨ Rupee', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '₹ Rupee (Indian)', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '₪ Shekel', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '¥ Yen/Yuan', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( '₩ Won', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Custom Symbol', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Period', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Show Regular Price', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Regular Price Label', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Show Top Button', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Top Button Text', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Top Button Link', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Show Bottom Button', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Bottom Button Text', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Bottom Button Link', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Top Button Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Features List Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Bottom Button Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Bottom Button Size', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Bottom Button Before Text Icon', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Bottom Button After Text Icon', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Price Superscript', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Price Superscript Top', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Block', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Currency Symbol Position', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Before', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'After', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Regular Price Typography', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Price Superscript Typography', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue
	__( 'Features List Typography', 'coming-soon' ),

	// Reference: src/components/PricingTable-Pro.vue
	__( 'Normally', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Left Layout Template', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Right Layout Template', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'No Image Template', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Price List Items', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Date Font Size', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Time Font Size', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Overall Alignment', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/FeatureOptions.vue
	__( 'Vertical Alignment', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Enter Title', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Enter Description', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Actual Price', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Offering Discount?', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Title Price Separator', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Link Complete Box', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Price Position', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Below Heading and Description', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Right of Heading', 'coming-soon' ),

	// Reference: src/components/PriceListOptions.vue
	__( 'Discount Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Posts Query', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Query Type', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Manual', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Query By Post Type', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Include Selected Post Type(s)', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( '- Select Post Type(s) -', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Query By Category', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Query By Tag(s)', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Include Selected Tag(s)', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( '- Select Tag(s) -', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Query By Author(s)', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Include Selected Author(s)', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( '- Select Author(s) -', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Date Last Modified', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Comment Count', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Slides to Show', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Query Params', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Number Per Page', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Show Featured Image', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Show Meta', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Show Date Modified', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Show Author', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Show Date', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Show Time', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Show Comment Count', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Show Excerpt', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Excerpt Length', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Show Read More', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Read More Text', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Meta Text', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Meta Text Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Excerpt', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Excerpt Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Read More Text Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Pagination Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Space Bottom', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Meta Text Typography', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Excerpt Typography', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Read More Text Typography', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Pagination Typography', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Taxonomy Typography', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Post Shadow', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Content Shadow', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Post Padding', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Image Margin', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Skin', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Classic', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Card', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Full Content', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Badge', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Badge Taxonomy', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	__( 'Category', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Tags', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	__( 'Avatar', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Carousel', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Masonry', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Creative', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Minimal', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Business News', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Bottom Spacing', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Taxonomy', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Navigation Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Navigation Position', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Navigation', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Arrows and Dots', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Arrows', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Dots', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Image Height', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/PostsOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Post', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Post Background Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Divider Border Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Content Area', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue
	__( 'Content Area Border', 'coming-soon' ),

	// Reference: src/components/Posts-Pro.vue
	// Reference: src/components/Posts-Pro.vue
	__( 'Loading Posts Preview', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( 'Author', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Time', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( 'Comments', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/PostinfoOptions.vue
	__( 'Terms', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( 'Link to Author', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Date Format', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( 'May 14, 2021 (F j, Y)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( '2021-05-14 (Y-m-d)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( '05/14/2021 (m/d/Y)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( '14/05/2021 (d/m/Y)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Custom Date Format', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( 'Use the letters: l D d j S F m M n Y y', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/IconPicker.vue
	__( 'Choose Icon', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( 'Modified Date', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( 'Modified Time', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Time Format', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( '9:15 am (g:i a)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( '9:15 AM (g:i A)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( '09:15 (H:i)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Custom Time Format', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( 'Use the letters: g G H i a A', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue
	__( 'Show Icons', 'coming-soon' ),

	// Reference: src/components/PostcommentsOptions.vue
	__( 'Content Policy', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue
	__( 'Profile Picture', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Display Name', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue
	__( 'Biography', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/DividerOptions.vue
	__( 'HTML Tag', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Website', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue
	__( 'Archive Posts', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue
	__( 'Biography Color', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue
	__( 'Biography Typography', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue
	// Reference: src/components/NavOptions.vue
	__( 'Go to the', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue
	__( 'Profile Screen', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue
	__( 'to manage your profile.', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Enable Particle Background', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Particle Background', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Polygon', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/CounterOptions.vue
	__( 'Space', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Snow', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Snowflakes', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Christmas', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Halloween', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Opacity', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Flow Direction', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	// Reference: src/components/HotspotOptions.vue
	__( 'Advanced Settings', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Number of Particles', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Particle Size', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Move Speed', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Enable Hover Effect', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Add custom JSON for the Particle Background. Please follow below steps:', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( '- Please visit this link ', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'here', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( ' and choose required attributes for particle', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( '- Copy JSON code and paste below.', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Particle hover effect will not work in the following scenarios:', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( '- In the builder area.', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( '- Content added in the section occupies the entire space and leaves it inaccessible.', 'coming-soon' ),

	// Reference: src/components/ParticlesBackgroundControl.vue
	__( 'Note: Increasing the number of particles can slow down your page.', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	__( 'Submit Button', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	__( 'Success Action', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/ContactFormOptions.vue
	__( 'Form', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	__( 'Required', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	__( 'Input Sizes', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	__( 'Action To Take', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/CountdownOptions.vue
	__( 'Show Message', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/CountdownOptions.vue
	__( 'Redirect', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/CountdownOptions.vue
	__( 'Message', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/CountdownOptions.vue
	__( 'Redirect URL', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	__( 'Remove Inline Padding', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue
	__( 'Button text', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Edit with AI', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Add with AI', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Please wait for image to upload.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Generate Image', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Generate new image', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Your AI Result', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	// Reference: src/components/OpenAIControl.vue
	// Reference: src/components/DynamicTextControl.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Insert', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Generate image with AI', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Edit image with AI', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Generate variations of your image', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Remove the background of your image', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Describe your image prompt.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Input your prompt for image generation.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Describe your full image prompt, not just the erased area.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Provide a detailed prompt for the entire image, including specific instructions for the erased area.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Generate with a prompt', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Remove Background', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Back', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	// Reference: src/components/OpenAIControl.vue
	__( '---', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Variations', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Generate Variations', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Edit Image', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Toggle Eraser Mode', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Generate New Image', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Erase an area on the canvas and enhance it with a prompt. Simply move the mouse and click to begin erasing.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Prompt cannot be blank.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Edit prompt cannot be blank.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Suggested prompts:', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Generate a futuristic cityscape with flying cars.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Generate an abstract art piece with vibrant colors and geometric shapes.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Visualize a peaceful beach scene with palm trees and a sunset.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Generate a retro-futuristic scene reminiscent of the 1980s sci-fi movies.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Create a dreamy celestial scene with stars, galaxies, and nebulae.', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	__( 'Your patience is appreciated! Expected wait: 45 seconds', 'coming-soon' ),

	// Reference: src/components/OpenAIImageControl.vue
	// Reference: src/components/OpenAIControl.vue
	__( 'Credits:', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Generate AI Text', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Generate Text', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Write with AI', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Describe your text.', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'New Prompt', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Simple Language', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Make it longer', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Make it shorter', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Change text tone', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Translate text to', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Choose Tone', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Choose Language', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Write a catchy slogan for ', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Write a page title for ', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Suggest a 5 word headline for ', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Write an interesting title for ', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Write a section header for', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( ' ... ', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Create a list for ', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Write about us section for ', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Write a product description for', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Write a short content for ', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Write 50 words content for ', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'English', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Chinese', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Swahili', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Bulgarian', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Croatian', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Serbian', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Slovak', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Slovenian', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Estonian', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Latvian', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Lithuanian', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Tamil', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Punjabi', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Gujarati', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Telugu', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Marathi', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Kannada', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Malayalam', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Nepali', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Georgian', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Armenian', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Azerbaijani', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Kazakh', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Uzbek', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Turkmen', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Kyrgyz', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Tajik', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Professional', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Friendly', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Funny', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Serious', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Excited', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Casual', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Formal', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Analytical', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Instructional', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Sympathetic', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Enthusiastic', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Persuasive', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Optimistic', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Respectful', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Polite', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Sincere', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Encouraging', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Calm', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	// Reference: src/components/AnimationEffectControl.vue
	__( 'Direct', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Confident', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Helpful', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Informative', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Patient', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Conversational', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Empathetic', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Concise', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Courteous', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Thoughtful', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Inspirational', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'An Internal Server error occurred. Please try again later.', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'An unexpected error occurred. Please try again later.', 'coming-soon' ),

	// Reference: src/components/OpenAIControl.vue
	__( 'Your Patience is Appreciated! Expected wait: 45 seconds', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Active Text Color', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'URL Link', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Mobile Menu', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'On', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Off', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Hover Text Color', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Menu Type', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'WordPress Menu', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Sub Menu Background Color', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Sub Menu Border Radius', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Sub Menu Line Height', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Sub Menu Border Width', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Sub Menu Border Color', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Sub Menu Text Color', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Sub Menu Hover Color', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Sub Menu', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Sub Menu Shadow', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Menus', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'Menus Screen', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'to manage your menus', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue
	__( 'There are no menus in your site.', 'coming-soon' ),

	// Reference: src/components/Nav-Pro.vue
	__( 'There are no navigation menus in your site.', 'coming-soon' ),

	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/Mypaykit.vue
	__( 'Select a MyPayKit Form', 'coming-soon' ),

	// Reference: src/components/MypaykitOptions.vue
	__( 'Need to make changes?', 'coming-soon' ),

	// Reference: src/components/MypaykitOptions.vue
	__( 'Click here to edit the selected payment form.', 'coming-soon' ),

	// Reference: src/components/MypaykitOptions.vue
	__( '+ New Payment Form', 'coming-soon' ),

	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/EnviraGalleryOptions.vue
	// Reference: src/components/ContactFormOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Hide', 'coming-soon' ),

	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/ContactFormOptions.vue
	__( 'Form Name', 'coming-soon' ),

	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/ContactFormOptions.vue
	__( 'Form Description', 'coming-soon' ),

	// Reference: src/components/MypaykitOptions.vue
	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/ContactFormOptions.vue
	__( 'Display Options', 'coming-soon' ),

	// Reference: src/components/Mypaykit.vue
	__( 'Install MyPayKit Plugin:', 'coming-soon' ),

	// Reference: src/components/Mypaykit.vue
	__( 'Install MyPayKit', 'coming-soon' ),

	// Reference: src/components/Mypaykit.vue
	__( 'Activate MyPayKit', 'coming-soon' ),

	// Reference: src/components/Mypaykit.vue
	__( 'MyPayKit', 'coming-soon' ),

	// Reference: src/components/Mypaykit.vue
	__( 'You can use MyPayKit to build payment forms in minutes and collect payments.', 'coming-soon' ),

	// Reference: src/components/Modal.vue
	__( 'default header', 'coming-soon' ),

	// Reference: src/components/Modal.vue
	__( 'default body', 'coming-soon' ),

	// Reference: src/components/MenuCartOptions.vue
	__( 'Hide on Empty', 'coming-soon' ),

	// Reference: src/components/MenuCartOptions.vue
	__( 'Show Subtotal', 'coming-soon' ),

	// Reference: src/components/MenuCartOptions.vue
	__( 'Badge Color', 'coming-soon' ),

	// Reference: src/components/MenuCartOptions.vue
	__( 'Badge Text Color', 'coming-soon' ),

	// Reference: src/components/MenuCart-Pro.vue
	__( 'Menu Cart Preview Not Available', 'coming-soon' ),

	// Reference: src/components/MarginControl.vue
	__( 'Margin', 'coming-soon' ),

	// Reference: src/components/MarginControl.vue
	__( 'auto', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Label for User field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Placeholder for User field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Label for Password field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Placeholder for Password field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Label Text Color', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Button Background Color', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Field Size', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Label Spacing', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Remember User Label', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Lost Password Link Text', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Label Font Weight', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Field Font', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Field Font Weight', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Button Font Weight', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Logged In Text', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	__( 'Field Width', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue
	__( 'Label Text Size', 'coming-soon' ),

	// Reference: src/components/Login-Pro.vue
	__( 'Username or Email Address', 'coming-soon' ),

	// Reference: src/components/Login-Pro.vue
	__( 'Get New Password', 'coming-soon' ),

	// Reference: src/components/Login-Pro.vue
	__( 'New password', 'coming-soon' ),

	// Reference: src/components/Login-Pro.vue
	__( 'Hide password', 'coming-soon' ),

	// Reference: src/components/Login-Pro.vue
	__( 'Strength indicator', 'coming-soon' ),

	// Reference: src/components/Login-Pro.vue
	__( 'Confirm use of weak password', 'coming-soon' ),

	// Reference: src/components/Login-Pro.vue
	__( 'Confirm new password', 'coming-soon' ),

	// Reference: src/components/Login-Pro.vue
	__( 'Reset Password', 'coming-soon' ),

	// Reference: src/components/Login-Pro.vue
	__( 'Back to Log In', 'coming-soon' ),

	// Reference: src/components/LiteCTAUpgrade.vue
	__( 'Upgrade to get the', 'coming-soon' ),

	// Reference: src/components/LiteCTAUpgrade.vue
	__( 'is not available on your plan.<br>Please upgrade your license to unlock this feature.', 'coming-soon' ),

	// Reference: src/components/LiteCTAUpgrade.vue
	__( 'Upgrade Your SeedProd License', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue
	__( 'More Premium Blocks', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue
	__( 'Capture Emails and Leads', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue
	__( 'Marketing & CRM Integrations', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue
	__( 'Maintenance Access Controls', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue
	__( 'Growing Library of Templates', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue
	__( 'Smart Sections', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue
	__( 'More Design Controls', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue
	__( 'Coming Soon Access Controls', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue
	__( 'Templates are a PRO Feature', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue
	__( 'Not all Templates are not available on your plan. Please upgrade to the PRO version to unlock all these awesome features.', 'coming-soon' ),

	// Reference: src/components/LiteCTASubscribers.vue
	__( 'Start Collecting Emails with SeedProd Lite', 'coming-soon' ),

	// Reference: src/components/LiteCTASubscribers.vue
	__( 'Use our Optin Form Block to start collecting emails from your visitors. All collected emails will show up on this page. Integrate with any of the Email Service Providers below.', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue
	__( 'is a PRO Feature', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue
	__( 'is not available on your plan. Please upgrade to the PRO version to unlock all these awesome features.', 'coming-soon' ),

	// Reference: src/components/ListTable.vue
	__( 'Loading', 'coming-soon' ),

	// Reference: src/components/ListTable.vue
	// Reference: src/components/ListTable.vue
	// Reference: src/components/ListTable.vue
	__( 'Select bulk action', 'coming-soon' ),

	// Reference: src/components/ListTable.vue
	__( 'Bulk Actions', 'coming-soon' ),

	// Reference: src/components/ListTable.vue
	__( 'items', 'coming-soon' ),

	// Reference: src/components/ListTable.vue
	__( 'No items found.', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue
	__( 'Link Type', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue
	__( 'Media - Lightbox', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/HotspotOptions.vue
	__( 'Object Fit', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/HotspotOptions.vue
	__( 'Fill', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Cover', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue
	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Contain', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue
	__( 'Border Radius Unit', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue
	__( 'Rotate Image', 'coming-soon' ),

	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	__( 'Choose New Image', 'coming-soon' ),

	// Reference: src/components/ImageMultipleControl.vue
	__( 'Add Gallery Images', 'coming-soon' ),

	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	__( 'Own Image', 'coming-soon' ),

	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	__( 'Stock Images Library', 'coming-soon' ),

	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	__( 'Use a', 'coming-soon' ),

	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	__( 'Stock Image', 'coming-soon' ),

	// Reference: src/components/ImageMultipleControl.vue
	// Reference: src/components/ImageControl.vue
	__( 'Search images...', 'coming-soon' ),

	// Reference: src/components/ImageMultipleControl.vue
	__( 'Insert Media', 'coming-soon' ),

	// Reference: src/components/ImageControl.vue
	__( 'Use Your', 'coming-soon' ),

	// Reference: src/components/ImageControl.vue
	__( 'Select Image', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Banner Header Color', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Banner Subheader Color', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Add Images', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Carousel Images', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Show Caption', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Show Slider Navigation', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Caption Typography', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Banner Header Typography', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Banner Subheader Typography', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Banner Button Typography', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Show Button', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Sub Header', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Button Link', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Show Header Text', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Header Tag', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'h1', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'h2', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'h3', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'h4', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'h5', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'h6', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Carousel Banner Settings', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Vertical Position', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Horizontal Position', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Banner Button Radius', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Banner Button Color', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Header Text Align', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Subheader Text Align', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Carousel Button Align', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Header Animation Effects', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Sub Header Animation Effects', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Button Animation Effects', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Image Overlay Color', 'coming-soon' ),

	// Reference: src/components/ImageCarouselOptions.vue
	__( 'Image Overlay Opacity', 'coming-soon' ),

	// Reference: src/components/IconPicker.vue
	__( 'All Icons', 'coming-soon' ),

	// Reference: src/components/IconPicker.vue
	__( 'Font Awesome', 'coming-soon' ),

	// Reference: src/components/IconPicker.vue
	__( 'Search icons...', 'coming-soon' ),

	// Reference: src/components/IconPicker.vue
	__( 'Icon Library', 'coming-soon' ),

	// Reference: src/components/IconFeatureOptions.vue
	__( 'Icon Gap', 'coming-soon' ),

	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Header Text', 'coming-soon' ),

	// Reference: src/components/IconFeatureOptions.vue
	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/FeatureOptions.vue
	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AnimationEffectControl.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Level', 'coming-soon' ),

	// Reference: src/components/Icon-Pro.vue
	__( 'Select an Icon', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Tooltip Content', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Add Hotspot', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Hotspot', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Max Width', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Custom Icon Size', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Min Width', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Text Wrap', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Tooltip', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Trigger', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Click', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Animation', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Fade', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Grow', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/AnimationEffectControl.vue
	__( 'Swing', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Slide', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Duration', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Fall', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Icon Position', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Soft Beat', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Expand', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Hotspot Animation', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	__( 'Show Arrow', 'coming-soon' ),

	// Reference: src/components/HotspotOptions.vue
	// Reference: src/components/HotspotOptions.vue
	__( 'Add Your Tooltip Text Here', 'coming-soon' ),

	// Reference: src/components/HeaderOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Headline', 'coming-soon' ),

	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/GoogleMaps-Pro.vue
	__( 'Google Maps', 'coming-soon' ),

	// Reference: src/components/GoogleMapsOptions.vue
	__( 'Location', 'coming-soon' ),

	// Reference: src/components/GoogleMapsOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Zoom', 'coming-soon' ),

	// Reference: src/components/GoogleMapsOptions.vue
	__( 'Height (px)', 'coming-soon' ),

	// Reference: src/components/GoogleMapsOptions.vue
	__( 'Width (%)', 'coming-soon' ),

	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/GiveawayOptions.vue
	// Reference: src/components/Giveaway.vue
	__( 'Select a Giveaway', 'coming-soon' ),

	// Reference: src/components/GiveawayOptions.vue
	__( 'Need to make changes? Edit the selected giveaway.', 'coming-soon' ),

	// Reference: src/components/GiveawayOptions.vue
	__( '+ New Giveaway', 'coming-soon' ),

	// Reference: src/components/Giveaway.vue
	__( 'Install Giveaway plugin:', 'coming-soon' ),

	// Reference: src/components/Giveaway.vue
	__( 'Install RafflePress', 'coming-soon' ),

	// Reference: src/components/Giveaway.vue
	__( 'Activate RafflePress', 'coming-soon' ),

	// Reference: src/components/Giveaway.vue
	__( 'Giveaway', 'coming-soon' ),

	// Reference: src/components/Giveaway.vue
	__( 'You can use RafflePress to build viral giveaways in minutes and explode your email list.', 'coming-soon' ),

	// Reference: src/components/Form-Pro.vue
	__( 'Submit', 'coming-soon' ),

	// Reference: src/components/FontVariantControl.vue
	__( 'Select a Font Weight', 'coming-soon' ),

	// Reference: src/components/FontVariantControl.vue
	__( 'Normal 400', 'coming-soon' ),

	// Reference: src/components/FontVariantControl.vue
	__( 'Bold 700', 'coming-soon' ),

	// Reference: src/components/FontControl.vue
	__( 'Standard Fonts', 'coming-soon' ),

	// Reference: src/components/FontControl.vue
	__( 'Google Fonts', 'coming-soon' ),

	// Reference: src/components/FontAwesomePicker.vue
	__( 'Click to select an icon', 'coming-soon' ),

	// Reference: src/components/FontAwesomePicker.vue
	__( 'Search icons', 'coming-soon' ),

	// Reference: src/components/FacebookSettings.vue
	__( 'Change App Id', 'coming-soon' ),

	// Reference: src/components/FacebookPageOptions.vue
	__( 'Small Header', 'coming-soon' ),

	// Reference: src/components/FacebookPageOptions.vue
	__( 'Hide Cover Photo', 'coming-soon' ),

	// Reference: src/components/FacebookPageOptions.vue
	__( 'Profile Photos', 'coming-soon' ),

	// Reference: src/components/FacebookPageOptions.vue
	__( 'Hide CTA button', 'coming-soon' ),

	// Reference: src/components/FacebookPageOptions.vue
	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookEmbedOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Facebook Setting', 'coming-soon' ),

	// Reference: src/components/FacebookPageOptions.vue
	__( 'Timeline', 'coming-soon' ),

	// Reference: src/components/FacebookPageOptions.vue
	__( 'Events', 'coming-soon' ),

	// Reference: src/components/FacebookPageOptions.vue
	__( 'Messages', 'coming-soon' ),

	// Reference: src/components/FacebookLikeOptions.vue
	__( 'Share Button', 'coming-soon' ),

	// Reference: src/components/FacebookLikeOptions.vue
	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Faces', 'coming-soon' ),

	// Reference: src/components/FacebookEmbedOptions.vue
	__( 'Include full post', 'coming-soon' ),

	// Reference: src/components/FacebookEmbedOptions.vue
	__( 'Allow Full Screen', 'coming-soon' ),

	// Reference: src/components/FacebookEmbedOptions.vue
	__( 'Captions', 'coming-soon' ),

	// Reference: src/components/FacebookEmbedOptions.vue
	__( 'Parent Comment', 'coming-soon' ),

	// Reference: src/components/FacebookEmbedOptions.vue
	__( 'Post Link', 'coming-soon' ),

	// Reference: src/components/FacebookEmbedOptions.vue
	__( 'Video Link', 'coming-soon' ),

	// Reference: src/components/FacebookEmbedOptions.vue
	__( 'Comment Link', 'coming-soon' ),

	// Reference: src/components/FacebookEmbedOptions.vue
	__( 'Comment', 'coming-soon' ),

	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Lazy Loading', 'coming-soon' ),

	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Social', 'coming-soon' ),

	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Reverse Time', 'coming-soon' ),

	// Reference: src/components/FacebookCommentsOptions.vue
	__( 'Number of Comments', 'coming-soon' ),

	// Reference: src/components/EnviraGalleryOptions.vue
	__( 'Select Gallery', 'coming-soon' ),

	// Reference: src/components/EnviraGalleryOptions.vue
	// Reference: src/components/ContactFormOptions.vue
	__( 'Select', 'coming-soon' ),

	// Reference: src/components/EnviraGalleryOptions.vue
	__( '+ New Gallery', 'coming-soon' ),

	// Reference: src/components/EnviraGalleryOptions.vue
	__( 'Image Limit', 'coming-soon' ),

	// Reference: src/components/EnviraGalleryOptions.vue
	__( 'Gallery', 'coming-soon' ),

	// Reference: src/components/EnviraGalleryOptions.vue
	__( 'Image Options', 'coming-soon' ),

	// Reference: src/components/EnviraGallery.vue
	__( 'Install Envira Gallery plugin:', 'coming-soon' ),

	// Reference: src/components/EnviraGallery.vue
	__( 'Install Envira', 'coming-soon' ),

	// Reference: src/components/EnviraGallery.vue
	__( 'Activate Envira', 'coming-soon' ),

	// Reference: src/components/EnviraGallery.vue
	__( 'Select a gallery', 'coming-soon' ),

	// Reference: src/components/EnviraGallery.vue
	__( 'You can use your Envira gallery from this block.', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'If orderby is set to random, pagination will be disabled to prevent subsequent pages from showing already-displayed products.', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Number', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Post Date(Default)', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Current Page Color', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Relation', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( '- Select Relation -', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'OR', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'AND', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Specify whether the downloads displayed have to be in ALL the categories/tags provided, or just in at least one.', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	__( 'Show Price', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Show Full Content', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Show Buy Button', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGridOptions.vue
	__( 'Show Thumbnails', 'coming-soon' ),

	// Reference: src/components/EDDDownloadsGrid-Pro.vue
	__( 'Downloads Preview Not Available', 'coming-soon' ),

	// Reference: src/components/EDDDownloadTitle-Pro.vue
	__( 'EDD Download Title Preview Not Available', 'coming-soon' ),

	// Reference: src/components/EDDDownloadPrice-Pro.vue
	__( 'Download Price Preview Not Available', 'coming-soon' ),

	// Reference: src/components/EDDDownloadInstructions-Pro.vue
	__( 'Download Instructions Preview Not Available', 'coming-soon' ),

	// Reference: src/components/EDDDownloadFeaturedImage-Pro.vue
	__( 'EDD Download Featured Image Preview Not Available', 'coming-soon' ),

	// Reference: src/components/EDDDownloadExcerpt-Pro.vue
	__( 'Download Excerpt Preview Not Available', 'coming-soon' ),

	// Reference: src/components/EDDDownloadContent-Pro.vue
	__( 'Download Content Preview Not Available', 'coming-soon' ),

	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Total Color', 'coming-soon' ),

	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Cart Item Color', 'coming-soon' ),

	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Cart Links Color', 'coming-soon' ),

	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Payments Border Color', 'coming-soon' ),

	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Payments Border Radius', 'coming-soon' ),

	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Item Typography', 'coming-soon' ),

	// Reference: src/components/EDDCheckoutOptions.vue
	// Reference: src/components/EDDCartOptions.vue
	__( 'Total Typography', 'coming-soon' ),

	// Reference: src/components/EDDCheckoutOptions.vue
	__( 'Payments Border Width', 'coming-soon' ),

	// Reference: src/components/EDDCheckout-Pro.vue
	__( 'Download Checkout Preview Not Available', 'coming-soon' ),

	// Reference: src/components/EDDCartOptions.vue
	__( 'Product Text Color', 'coming-soon' ),

	// Reference: src/components/EDDCartOptions.vue
	__( 'Price Text Color', 'coming-soon' ),

	// Reference: src/components/EDDCartOptions.vue
	__( 'Total Text Color', 'coming-soon' ),

	// Reference: src/components/EDDCartOptions.vue
	__( 'Links Color', 'coming-soon' ),

	// Reference: src/components/EDDCartOptions.vue
	__( 'Product Typography', 'coming-soon' ),

	// Reference: src/components/EDDCart-Pro.vue
	__( 'Download Cart Preview Not Available', 'coming-soon' ),

	// Reference: src/components/EDDBuyNowButtonOptions.vue
	// Reference: src/components/EDDAddToCartOptions.vue
	__( '- Select ID -', 'coming-soon' ),

	// Reference: src/components/EDDBuyNowButton-Pro.vue
	__( 'Buy Now Button Preview Not Available. Please Select Product.', 'coming-soon' ),

	// Reference: src/components/EDDAddToCart-Pro.vue
	__( 'Download Add To Cart Preview Not Available. Please Select Product.', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	// Reference: src/components/DynamicTextControl.vue
	__( 'Please enter parameter name', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Please enter date/time format', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Please select date/time format', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Dynamic Text Replacement', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'DateTime', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Query Parameter', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Today', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Tomorrow', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Today Date', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Tomorrow Date', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Month', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Next Month', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Year', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Select Date Time Format', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Query Parameters', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'Parameter Name', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue
	__( 'Default Value', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Insert Dynamic Tags', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Add Dynamic Tags', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Select Tag', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Select Key', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Custom Key', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( '- Select -', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Please select a tag', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/Archivetitle-Pro.vue
	__( 'Archive Title', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'ACF Field', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Archive', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Categories', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Select Taxonomy', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'e.g. ,', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Show Advanced Settings', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Fallback', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Post Published', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Post Modified', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Format', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'F j, Y', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Y-m-d', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'm/d/Y', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'd/m/Y', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'e.g. Y-m-d', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Meta Key', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Include Context', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Show Home Title', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'g:i a', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'g:i A', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	// Reference: src/components/DynamicTagsControl.vue
	__( 'H:i', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Custom Format', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'e.g. Y-m-d g:i a', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Get', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Query Var', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Username', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'First Name', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Last Name', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Bio', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'User Meta', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Data', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'File URL', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Attachment URL', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'No Comments Format', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'One Comment Format', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Many Comments Format', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Comments Link', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'e.g. g:i a', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Post ID', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Post Date', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Post Time', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Post Title', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Post Excerpt', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Post Terms', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Post Custom Field', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Archive Meta', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Archive Description', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Page Title', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Site Tagline', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Site Title', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Site Logo', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Current Date Time', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Request Parameter', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'User Info', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Featured Image Data', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Author Info', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Author Meta', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Author Name', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Author Profile Picture', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'User Profile Picture', 'coming-soon' ),

	// Reference: src/components/DynamicTagsControl.vue
	__( 'Comments Number', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue
	__( 'Solid Line', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Double', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue
	__( 'Add Element', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue
	__( 'Static', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Relative', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue
	__( 'Sticky', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue
	__( 'Overflow', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Scroll', 'coming-soon' ),

	// Reference: src/components/DeviceVisibilityControl.vue
	__( 'Device Visibility', 'coming-soon' ),

	// Reference: src/components/DeviceVisibilityControl.vue
	__( 'Hide on Desktop', 'coming-soon' ),

	// Reference: src/components/DeviceVisibilityControl.vue
	__( 'Hide on Mobile', 'coming-soon' ),

	// Reference: src/components/DeviceVisibilityControl.vue
	__( 'Hide on Tablet', 'coming-soon' ),

	// Reference: src/components/CustomHTMLOptions.vue
	__( 'Custom Code', 'coming-soon' ),

	// Reference: src/components/CustomHTMLOptions.vue
	__( 'Edit Custom HTML', 'coming-soon' ),

	// Reference: src/components/CustomHTML.vue
	__( 'Enter Your HTML', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Starting Number', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Ending Number', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Number Prefix', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Number Suffix', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Animation Duration', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Thousands Separator', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Dot', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Title Text Color', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Number Text Color', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Number Align', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	// Reference: src/components/AlertBoxOptions.vue
	__( 'Title Align', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Number Shadow', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Title Shadow', 'coming-soon' ),

	// Reference: src/components/CounterOptions.vue
	__( 'Number Typography', 'coming-soon' ),

	// Reference: src/components/Counter-Pro.vue
	__( 'Counter Block', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Countdown Type', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Visitor Timer (Evergreen)', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'DateTime Countdown', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Set Timer For', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'End Date', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Timezone', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Action To Take On Expires', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Customize Labels', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Day Label', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Hour Label', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Minute Label', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Second Label', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Hours', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Minutes', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Seconds', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Highlight Color', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Restart', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue
	__( 'Select Date', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Heading 1', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Heading 2', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Content Area 1', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Content Area 2', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Toggle', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Content 1', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Content 2', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Before Label', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'After Label', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Templates Parts', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Section Content', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	// Reference: src/components/AlignControl.vue
	__( 'Align', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'First Background Color', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Second Background Color', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Switcher Color', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Heading 1 Color', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Heading 2 Color', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Content 1 Color', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Content 2 Color', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Orientation', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Slider Orientation', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Move on Hover', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Comparison Handle', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Handle Initial Offset', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Handle Color', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Handle Thickness', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Circle Width', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Circle Radius', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Triangle Size', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Heading / Content', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Switcher', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Switch Style', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Round', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Label Box', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Switch Size', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Mini', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Loading Template Parts...', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Header 1 Typography', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Header 2 Typography', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Content 1 Typography', 'coming-soon' ),

	// Reference: src/components/ContentToggleOptions.vue
	__( 'Content 2 Typography', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue
	// Reference: src/components/ContactForm.vue
	__( 'Select a Form', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue
	__( 'Need to make changes? Edit the selected form.', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue
	__( '+ New Form', 'coming-soon' ),

	// Reference: src/components/ContactForm.vue
	__( 'Install Contact Form plugin:', 'coming-soon' ),

	// Reference: src/components/ContactForm.vue
	__( 'Install WPForms', 'coming-soon' ),

	// Reference: src/components/ContactForm.vue
	__( 'Activate WPForms', 'coming-soon' ),

	// Reference: src/components/ContactForm.vue
	__( 'You can use WPForms to build contact forms, surveys, payment forms, and more with just a few clicks.', 'coming-soon' ),

	// Reference: src/components/ColorPicker.vue
	__( 'Global Colors', 'coming-soon' ),

	// Reference: src/components/ColorPicker.vue
	__( 'Common Colors', 'coming-soon' ),

	// Reference: src/components/ColorPicker.vue
	__( 'Recently Used', 'coming-soon' ),

	// Reference: src/components/ColorPicker.vue
	__( 'Global Theme Colors', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue
	__( 'Column Width', 'coming-soon' ),

	// Reference: src/components/ButtonOptions.vue
	__( 'The border color is required for the border width to take effect.', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Review Source', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Google Places', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Yelp', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Google & Yelp', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Google Place ID', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Yelp Business ID', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Language Code', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Reload Reviews', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Hour', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Day', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Week', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Filters', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Filter By', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'No Filter', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Review Date', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Minimum Rating', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( '2 star', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( '3 star', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( '4 star', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( '5 star', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'No Minimum Rating', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Reviewer Info', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Reviewer Image', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Above Name', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Left of Name', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Left of all content', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Reviewer Name', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Link Name', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Review Date Color', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Numeric', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Reviewer Name Color', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Unmasked Icon Color', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Review Text', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Text Length', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Read More Color', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Date Color', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Content Color', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'No of Reviews', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Select Layout', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Please add Google Places API Key ', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'You are connected to Google Places API Key', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Please add Yelp API Key ', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( ' here ', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'You are connected to Yelp API Key', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Google allows maximum 5 reviews.', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Yelp allows maximum 3 reviews.', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Google + Yelp allows maximum 8 reviews total.', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Click here', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( ' to find your Google Place ID.', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( ' to check your Language code.', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( ' to find your Yelp Business ID.', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Reviewer Name Typography', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Review Date Typography', 'coming-soon' ),

	// Reference: src/components/BusinessReviewsOptions.vue
	__( 'Loading Business Review.', 'coming-soon' ),

	// Reference: src/components/BusinessReviews-Pro.vue
	__( 'Review Not Available', 'coming-soon' ),

	// Reference: src/components/BusinessReviews-Pro.vue
	// Reference: src/components/BusinessReviews-Pro.vue
	__( 'Loading Reviews...', 'coming-soon' ),

	// Reference: src/components/BusinessReviews-Pro.vue
	__( ' Please add Google Places API Key. ', 'coming-soon' ),

	// Reference: src/components/BusinessReviews-Pro.vue
	__( ' Please add Google Places Id. ', 'coming-soon' ),

	// Reference: src/components/BusinessReviews-Pro.vue
	__( ' Please add Yelp API Key. ', 'coming-soon' ),

	// Reference: src/components/BusinessReviews-Pro.vue
	__( ' Please add Yelp Business Id. ', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Business Days and Timing', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Enter Day', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Enter Time', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue
	__( 'Time Typography', 'coming-soon' ),

	// Reference: src/components/BulletListOptions.vue
	__( 'List', 'coming-soon' ),

	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Before Image', 'coming-soon' ),

	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'After Image', 'coming-soon' ),

	// Reference: src/components/BeforeAfterToggleOptions.vue
	__( 'Before / After Label Styles', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Background Style', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Background Position', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Full Screen Cover - Fixed', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( '100% Width Top', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	// Reference: src/components/BackgroundControl.vue
	__( 'Repeat', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Repeat Horizontal Top', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Repeat Horizontal Bottom', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Repeat Vertical Center', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( '100% Width Bottom', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Custom Position', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Background Image', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Full Screen Contain - Fixed', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Full Screen Cover', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Full Screen Contain', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'X Position', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Y Position', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'No-repeat', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Repeat-x', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue
	__( 'Repeat-y', 'coming-soon' ),

	// Reference: src/components/AttributeSectionControl.vue
	__( 'Attributes', 'coming-soon' ),

	// Reference: src/components/AttributeSectionControl.vue
	__( 'Custom Class', 'coming-soon' ),

	// Reference: src/components/AttributeSectionControl.vue
	__( 'CSS ID', 'coming-soon' ),

	// Reference: src/components/AttributeSectionControl.vue
	__( 'Custom Attributes', 'coming-soon' ),

	// Reference: src/components/AttributeSectionControl.vue
	__( 'Add custom attributes to the wrapper element. Enter each attribute on a new line. Use the | character to separate the attribute key and value.', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Animation Effects', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Scrolling Effect', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Mouse Effect', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Vertical Scroll', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	// Reference: src/components/AnimationEffectControl.vue
	__( 'Direction', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Speed', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Viewport', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Viewport Top %', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Up', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Down', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Horizontal Scroll', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'To Left', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'To Right', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Transparency', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade Out', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Rotate', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Scale Up', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Scale Down', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Mouse Track', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Opposite', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( '3D Tilt', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Entrance Animation', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Select Animation', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fading', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Down', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Left', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Right', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Up', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Zooming', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Zoom In', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Zoom In Down', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Zoom In Left', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Zoom In Right', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Zoom In Up', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Rotating', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Rotate In', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Rotate In Down Left', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Rotate In Down Right', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Rotate In Up Left', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Rotate In Up Right', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Attention Seekers', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Bounce', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Flash', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Pulse', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Rubber Band', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Shake X', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Shake Y', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Head Shake', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Tada', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Wobble', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Jello', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Heart Beat', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Back In Down', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Back In Left', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Back In Right', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Back In Up', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	// Reference: src/components/AnimationEffectControl.vue
	__( 'Bounce In', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Bounce In Down', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Bounce In Left', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Bounce In Right', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Bounce In Up', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Down Big', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Left Big', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Right Big', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Up Big', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Top Left', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Top Right', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Bottom Left', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Fade In Bottom Right', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Flip In X', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Flip In Y', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Light Speed In Left', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Light Speed In Right', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Roll In', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Back In', 'coming-soon' ),

	// Reference: src/components/AnimationEffectControl.vue
	__( 'Note: In the preview the animation is applied when you select it. On the live page the animation will be applied when the element is scrolled into view.', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Before Headline', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'After Headline', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Highlighted', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Curly', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Double Underline', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Underline Zigzag', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Diagonal', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Strikethrough', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'X', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Typing', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Clip', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Roll', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Light Speed', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Slide Down', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Infinite Loop', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Duration (ms)', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Delay (ms)', 'coming-soon' ),

	// Reference: src/components/AnimatedHeadlineOptions.vue
	__( 'Stroke Color', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Alert', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Description Font Size', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Title Background', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Dismiss Color', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Show Icon', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Info', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Success', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Danger', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Dismiss Button', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Style 1', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Style 2', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Style 3', 'coming-soon' ),

	// Reference: src/components/AlertBoxOptions.vue
	__( 'Style 4', 'coming-soon' ),

	// Reference: src/components/AdditionalInformation-Pro.vue
	__( 'Additional Information Preview Not Available', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue
	__( 'Quantity Typography', 'coming-soon' ),

	// Reference: src/components/AddToCart-Pro.vue
	__( 'Add To Cart Preview Not Available', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue
	__( 'Accordion', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue
	__( 'Closed Icon Color', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue
	__( 'Closed Icon', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue
	__( 'Open Icon Color', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue
	__( 'Open Icon', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue
	__( 'Accordion ', 'coming-soon' )
);
/* THIS IS THE END OF THE GENERATED FILE */
